@@ -4,12 +4,16 @@ This module defines descriptor classes for aperture attribute
 validation.
 """
 
+import warnings
+
 from astropy.coordinates import SkyCoord
 import astropy.units as u
+from astropy.utils.exceptions import AstropyDeprecationWarning
 import numpy as np
 
 __all__ = ['ApertureAttribute', 'PixelPositions', 'SkyCoordPositions',
-           'Scalar', 'PositiveScalar', 'AngleOrPixelScalarQuantity']
+           'PositiveScalar', 'ScalarAngle', 'ScalarAngleOrValue',
+           'ScalarAngleOrPixel']
 
 
 class ApertureAttribute:
@@ -18,21 +22,20 @@ class ApertureAttribute:
 
     Parameters
     ----------
-    name : str
-        The name of the attribute.
-
-    description : str, optional
-        The description of the attribute, which will be used as the
-        attribute documentation.
+    doc : str, optional
+        The description string for the attribute.
     """
 
-    def __init__(self, name, description=''):
+    def __init__(self, doc=''):
+        self.__doc__ = doc
+        self.name = ''
+
+    def __set_name__(self, owner, name):
         self.name = name
-        self.__doc__ = description
 
     def __get__(self, instance, owner):
         if instance is None:
-            return self
+            return self  # pragma: no cover
         return instance.__dict__[self.name]
 
     def __set__(self, instance, value):
@@ -42,7 +45,7 @@ class ApertureAttribute:
         instance.__dict__[self.name] = value
 
     def __delete__(self, instance):
-        del instance.__dict__[self.name]
+        del instance.__dict__[self.name]  # pragma: no cover
 
     def _validate(self, value):
         """
@@ -50,7 +53,7 @@ class ApertureAttribute:
 
         An exception is raised if the value is invalid.
         """
-        raise NotImplementedError
+        raise NotImplementedError  # pragma: no cover
 
 
 class PixelPositions(ApertureAttribute):
@@ -71,6 +74,13 @@ class PixelPositions(ApertureAttribute):
         self._validate(value)
 
         if isinstance(value, u.Quantity):
+            # deprecated in version 1.4.0
+            warnings.warn('Inputing positions as a Quantity is deprecated '
+                          'and will be removed in a future version.',
+                          AstropyDeprecationWarning)
+
+            if value.unit != u.pixel:
+                raise ValueError('Input positions must have pixel units')
             value = value.value
 
         if value.ndim == 2 and value.shape[1] != 2 and value.shape[0] == 2:
@@ -91,7 +101,7 @@ class PixelPositions(ApertureAttribute):
 
         value = np.atleast_2d(value)
         if (value.shape[1] != 2 and value.shape[0] != 2) or value.ndim > 2:
-            raise TypeError(f'{self.name} must be a (x, y) pixel position '
+            raise TypeError(f'{self.name!r} must be a (x, y) pixel position '
                             'or a list or array of (x, y) pixel positions.')
 
 
@@ -102,17 +112,7 @@ class SkyCoordPositions(ApertureAttribute):
 
     def _validate(self, value):
         if not isinstance(value, SkyCoord):
-            raise ValueError(f'{self.name} must be a SkyCoord instance')
-
-
-class Scalar(ApertureAttribute):
-    """
-    Check that value is a scalar.
-    """
-
-    def _validate(self, value):
-        if not np.isscalar(value):
-            raise ValueError(f'{self.name} must be a scalar')
+            raise ValueError(f'{self.name!r} must be a SkyCoord instance')
 
 
 class PositiveScalar(ApertureAttribute):
@@ -122,42 +122,84 @@ class PositiveScalar(ApertureAttribute):
 
     def _validate(self, value):
         if not np.isscalar(value) or value <= 0:
-            raise ValueError(f'{self.name} must be a positive scalar')
+            raise ValueError(f'{self.name!r} must be a positive scalar')
 
 
-class AngleScalarQuantity(ApertureAttribute):
+class ScalarAngle(ApertureAttribute):
     """
-    Check that value is either an angular scalar
-    `~astropy.units.Quantity`.
+    Check that value is a scalar angle, either as an astropy Angle or
+    Quantity with angular units.
     """
 
     def _validate(self, value):
         if isinstance(value, u.Quantity):
             if not value.isscalar:
-                raise ValueError(f'{self.name} must be a scalar')
+                raise ValueError(f'{self.name!r} must be a scalar')
 
             if not value.unit.physical_type == 'angle':
-                raise ValueError(f'{self.name} must have angular units')
+                raise ValueError(f'{self.name!r} must have angular units')
         else:
-            raise TypeError(f'{self.name} must be an astropy Quantity '
-                            'instance')
+            raise TypeError(f'{self.name!r} must be a scalar angle')
 
 
-class AngleOrPixelScalarQuantity(ApertureAttribute):
+class ScalarAngleOrValue(ApertureAttribute):
     """
-    Check that value is either an angular or a pixel scalar
-    `~astropy.units.Quantity`.
+    Check that value is a scalar angle, either as a
+    `~astropy.coordinates.Angle` or `~astropy.units.Quantity` with
+    angular units, or a scalar float.
+    """
+
+    def __set__(self, instance, value):
+        self._validate(value)
+        instance.__dict__[self.name] = value
+
+        # also store the angle in radians as a float
+        if isinstance(value, u.Quantity):
+            value = value.to(u.radian).value
+        name = f'_{self.name}_radians'
+        instance.__dict__[name] = value
+
+    def _validate(self, value):
+        if isinstance(value, u.Quantity):
+            if not value.isscalar:
+                raise ValueError(f'{self.name!r} must be a scalar')
+
+            if not (value.unit.physical_type == 'angle'
+                    or value.unit == u.pixel):
+                raise ValueError(f'{self.name!r} must have angular or pixel '
+                                 'units')
+        else:
+            if not np.isscalar(value):
+                raise TypeError(f'{self.name!r} must be a scalar float in '
+                                'radians')
+
+
+class ScalarAngleOrPixel(ApertureAttribute):
+    """
+    Check that value is a scalar angle, either as a
+    `~astropy.coordinates.Angle` or `~astropy.units.Quantity` with
+    angular units, or a scalar `~astropy.units.Quantity` in pixel units.
+
+    The value must be strictly positive (> 0).
     """
 
     def _validate(self, value):
         if isinstance(value, u.Quantity):
             if not value.isscalar:
-                raise ValueError(f'{self.name} must be a scalar')
+                raise ValueError(f'{self.name!r} must be a scalar')
 
-            if not (value.unit.physical_type == 'angle' or
-                    value.unit == u.pixel):
-                raise ValueError(f'{self.name} must have angular or pixel '
+            if not (value.unit.physical_type == 'angle'
+                    or value.unit == u.pixel):
+                raise ValueError(f'{self.name!r} must have angular or pixel '
                                  'units')
+
+            if value.unit == u.pixel:
+                warnings.warn('Inputing sky aperture quantities in pixel '
+                              'units is deprecated and will be removed in '
+                              'a future version.', AstropyDeprecationWarning)
+
+            if not value > 0:
+                raise ValueError(f'{self.name!r} must be strictly positive')
         else:
-            raise TypeError(f'{self.name} must be an astropy Quantity '
-                            'instance')
+            raise TypeError(f'{self.name!r} must be a scalar angle or pixel '
+                            'Quantity')
