@@ -8,8 +8,8 @@ import math
 
 import numpy as np
 
-from .attributes import (AngleOrPixelScalarQuantity, PixelPositions,
-                         PositiveScalar, SkyCoordPositions)
+from .attributes import (PixelPositions, PositiveScalar, SkyCoordPositions,
+                         ScalarAngleOrPixel)
 from .core import PixelAperture, SkyAperture
 from .mask import ApertureMask
 from ..geometry import circular_overlap_grid
@@ -38,28 +38,29 @@ class CircularMaskMixin:
 
                 * ``'exact'`` (default):
                   The the exact fractional overlap of the aperture and
-                  each pixel is calculated.  The returned mask will
+                  each pixel is calculated. The aperture weights will
                   contain values between 0 and 1.
 
                 * ``'center'``:
                   A pixel is considered to be entirely in or out of the
                   aperture depending on whether its center is in or out
-                  of the aperture.  The returned mask will contain
+                  of the aperture. The aperture weights will contain
                   values only of 0 (out) and 1 (in).
 
                 * ``'subpixel'``:
                   A pixel is divided into subpixels (see the
                   ``subpixels`` keyword), each of which are considered
-                  to be entirely in or out of the aperture depending on
-                  whether its center is in or out of the aperture.  If
-                  ``subpixels=1``, this method is equivalent to
-                  ``'center'``.  The returned mask will contain values
+                  to be entirely in or out of the aperture depending
+                  on whether its center is in or out of the aperture.
+                  If ``subpixels=1``, this method is equivalent to
+                  ``'center'``. The aperture weights will contain values
                   between 0 and 1.
 
         subpixels : int, optional
-            For the ``'subpixel'`` method, resample pixels by this factor
-            in each dimension.  That is, each pixel is divided into
-            ``subpixels ** 2`` subpixels.
+            For the ``'subpixel'`` method, resample pixels by this
+            factor in each dimension. That is, each pixel is divided
+            into ``subpixels ** 2`` subpixels. This keyword is ignored
+            unless ``method='subpixel'``.
 
         Returns
         -------
@@ -109,14 +110,15 @@ class CircularAperture(CircularMaskMixin, PixelAperture):
 
     Parameters
     ----------
-    positions : array_like or `~astropy.units.Quantity`
+    positions : array_like
         The pixel coordinates of the aperture center(s) in one of the
         following formats:
 
             * single ``(x, y)`` pair as a tuple, list, or `~numpy.ndarray`
             * tuple, list, or `~numpy.ndarray` of ``(x, y)`` pairs
             * `~astropy.units.Quantity` instance of ``(x, y)`` pairs in
-              pixel units
+              pixel units (this is Deprecated and will be removed in a
+              future version)
 
     r : float
         The radius of the circle in pixels.
@@ -139,10 +141,9 @@ class CircularAperture(CircularMaskMixin, PixelAperture):
     >>> aper = CircularAperture((pos1, pos2, pos3), 3.)
     """
 
-    _shape_params = ('r',)
-    positions = PixelPositions('positions',
-                               description='The center pixel position(s).')
-    r = PositiveScalar('r', description='The radius in pixels.')
+    _params = ('positions', 'r')
+    positions = PixelPositions('The center pixel position(s).')
+    r = PositiveScalar('The radius in pixels.')
 
     def __init__(self, positions, r):
         self.positions = positions
@@ -192,6 +193,10 @@ class CircularAperture(CircularMaskMixin, PixelAperture):
         else:
             return patches
 
+    def to_mask(self, method='exact', subpixels=5):
+        return CircularMaskMixin.to_mask(self, method=method,
+                                         subpixels=subpixels)
+
     def to_sky(self, wcs):
         """
         Convert the aperture to a `SkyCircularAperture` object defined
@@ -222,14 +227,15 @@ class CircularAnnulus(CircularMaskMixin, PixelAperture):
 
     Parameters
     ----------
-    positions : array_like or `~astropy.units.Quantity`
+    positions : array_like
         The pixel coordinates of the aperture center(s) in one of the
         following formats:
 
             * single ``(x, y)`` pair as a tuple, list, or `~numpy.ndarray`
             * tuple, list, or `~numpy.ndarray` of ``(x, y)`` pairs
             * `~astropy.units.Quantity` instance of ``(x, y)`` pairs in
-              pixel units
+              pixel units (this is Deprecated and will be removed in a
+              future version)
 
     r_in : float
         The inner radius of the circular annulus in pixels.
@@ -258,13 +264,10 @@ class CircularAnnulus(CircularMaskMixin, PixelAperture):
     >>> aper = CircularAnnulus((pos1, pos2, pos3), 3., 5.)
     """
 
-    _shape_params = ('r_in', 'r_out')
-    positions = PixelPositions('positions',
-                               description='The center pixel position(s).')
-    r_in = PositiveScalar('r_in',
-                          description='The inner radius in pixels.')
-    r_out = PositiveScalar('r_out',
-                           description='The outer radius in pixels.')
+    _params = ('positions', 'r_in', 'r_out')
+    positions = PixelPositions('The center pixel position(s).')
+    r_in = PositiveScalar('The inner radius in pixels.')
+    r_out = PositiveScalar('The outer radius in pixels.')
 
     def __init__(self, positions, r_in, r_out):
         if not r_out > r_in:
@@ -320,6 +323,10 @@ class CircularAnnulus(CircularMaskMixin, PixelAperture):
         else:
             return patches
 
+    def to_mask(self, method='exact', subpixels=5):
+        return CircularMaskMixin.to_mask(self, method=method,
+                                         subpixels=subpixels)
+
     def to_sky(self, wcs):
         """
         Convert the aperture to a `SkyCircularAnnulus` object defined
@@ -355,7 +362,8 @@ class SkyCircularAperture(SkyAperture):
         either scalar coordinates or an array of coordinates.
 
     r : scalar `~astropy.units.Quantity`
-        The radius of the circle, either in angular or pixel units.
+        The radius of the circle in angular units. Pixel units are now
+        deprecated.
 
     Examples
     --------
@@ -366,13 +374,9 @@ class SkyCircularAperture(SkyAperture):
     >>> aper = SkyCircularAperture(positions, 0.5*u.arcsec)
     """
 
-    _shape_params = ('r',)
-    positions = SkyCoordPositions(
-        'positions',
-        description='The center position(s) in sky coordinates.')
-    r = AngleOrPixelScalarQuantity(
-        'r',
-        description='The radius, in angular or pixel units.')
+    _params = ('positions', 'r',)
+    positions = SkyCoordPositions('The center position(s) in sky coordinates.')
+    r = ScalarAngleOrPixel('The radius in angular units.')
 
     def __init__(self, positions, r):
         self.positions = positions
@@ -413,12 +417,12 @@ class SkyCircularAnnulus(SkyAperture):
         either scalar coordinates or an array of coordinates.
 
     r_in : scalar `~astropy.units.Quantity`
-        The inner radius of the circular annulus, either in angular or
-        pixel units.
+        The inner radius of the circular annulus in angular units. Pixel
+        units are now deprecated.
 
     r_out : scalar `~astropy.units.Quantity`
-        The outer radius of the circular annulus, either in angular or
-        pixel units.
+        The outer radius of the circular annulus in angular units. Pixel
+        units are now deprecated.
 
     Examples
     --------
@@ -429,16 +433,10 @@ class SkyCircularAnnulus(SkyAperture):
     >>> aper = SkyCircularAnnulus(positions, 0.5*u.arcsec, 1.0*u.arcsec)
     """
 
-    _shape_params = ('r_in', 'r_out')
-    positions = SkyCoordPositions(
-        'positions',
-        description='The center position(s) in sky coordinates.')
-    r_in = AngleOrPixelScalarQuantity(
-        'r_in',
-        description='The inner radius, in angular or pixel units.')
-    r_out = AngleOrPixelScalarQuantity(
-        'r_out',
-        description='The outer radius, in angular or pixel units.')
+    _params = ('positions', 'r_in', 'r_out')
+    positions = SkyCoordPositions('The center position(s) in sky coordinates.')
+    r_in = ScalarAngleOrPixel('The inner radius in angular units.')
+    r_out = ScalarAngleOrPixel('The outer radius in angular units.')
 
     def __init__(self, positions, r_in, r_out):
         if r_in.unit.physical_type != r_out.unit.physical_type:
