@@ -9,9 +9,9 @@ import math
 import astropy.units as u
 import numpy as np
 
-from .attributes import (AngleOrPixelScalarQuantity, AngleScalarQuantity,
-                         PixelPositions, PositiveScalar, Scalar,
-                         SkyCoordPositions)
+from .attributes import (ScalarAngle, PixelPositions, PositiveScalar,
+                         SkyCoordPositions, ScalarAngleOrPixel,
+                         ScalarAngleOrValue)
 from .core import PixelAperture, SkyAperture
 from .mask import ApertureMask
 from ..geometry import elliptical_overlap_grid
@@ -40,28 +40,29 @@ class EllipticalMaskMixin:
 
                 * ``'exact'`` (default):
                   The the exact fractional overlap of the aperture and
-                  each pixel is calculated.  The returned mask will
+                  each pixel is calculated. The aperture weights will
                   contain values between 0 and 1.
 
                 * ``'center'``:
                   A pixel is considered to be entirely in or out of the
                   aperture depending on whether its center is in or out
-                  of the aperture.  The returned mask will contain
+                  of the aperture. The aperture weights will contain
                   values only of 0 (out) and 1 (in).
 
                 * ``'subpixel'``:
                   A pixel is divided into subpixels (see the
                   ``subpixels`` keyword), each of which are considered
-                  to be entirely in or out of the aperture depending on
-                  whether its center is in or out of the aperture.  If
-                  ``subpixels=1``, this method is equivalent to
-                  ``'center'``.  The returned mask will contain values
+                  to be entirely in or out of the aperture depending
+                  on whether its center is in or out of the aperture.
+                  If ``subpixels=1``, this method is equivalent to
+                  ``'center'``. The aperture weights will contain values
                   between 0 and 1.
 
         subpixels : int, optional
-            For the ``'subpixel'`` method, resample pixels by this factor
-            in each dimension.  That is, each pixel is divided into
-            ``subpixels ** 2`` subpixels.
+            For the ``'subpixel'`` method, resample pixels by this
+            factor in each dimension. That is, each pixel is divided
+            into ``subpixels ** 2`` subpixels. This keyword is ignored
+            unless ``method='subpixel'``.
 
         Returns
         -------
@@ -87,14 +88,15 @@ class EllipticalMaskMixin:
                                self._centered_edges):
             ny, nx = bbox.shape
             mask = elliptical_overlap_grid(edges[0], edges[1], edges[2],
-                                           edges[3], nx, ny, a, b, self.theta,
+                                           edges[3], nx, ny, a, b,
+                                           self._theta_radians,
                                            use_exact, subpixels)
 
             # subtract the inner ellipse for an annulus
             if hasattr(self, 'a_in'):
                 mask -= elliptical_overlap_grid(edges[0], edges[1], edges[2],
                                                 edges[3], nx, ny, self.a_in,
-                                                self.b_in, self.theta,
+                                                self.b_in, self._theta_radians,
                                                 use_exact, subpixels)
 
             masks.append(ApertureMask(mask, bbox))
@@ -130,14 +132,15 @@ class EllipticalAperture(EllipticalMaskMixin, PixelAperture):
 
     Parameters
     ----------
-    positions : array_like or `~astropy.units.Quantity`
+    positions : array_like
         The pixel coordinates of the aperture center(s) in one of the
         following formats:
 
             * single ``(x, y)`` pair as a tuple, list, or `~numpy.ndarray`
             * tuple, list, or `~numpy.ndarray` of ``(x, y)`` pairs
             * `~astropy.units.Quantity` instance of ``(x, y)`` pairs in
-              pixel units
+              pixel units (this is Deprecated and will be removed in a
+              future version)
 
     a : float
         The semimajor axis of the ellipse in pixels.
@@ -145,10 +148,11 @@ class EllipticalAperture(EllipticalMaskMixin, PixelAperture):
     b : float
         The semiminor axis of the ellipse in pixels.
 
-    theta : float, optional
-        The rotation angle in radians of the ellipse semimajor axis from
-        the positive ``x`` axis.  The rotation angle increases
-        counterclockwise.  The default is 0.
+    theta : float or `~astropy.units.Quantity`, optional
+        The rotation angle as an angular quantity
+        (`~astropy.units.Quantity` or `~astropy.coordinates.Angle`) or
+        value in radians (as a float) from the positive ``x`` axis. The
+        rotation angle increases counterclockwise.
 
     Raises
     ------
@@ -157,36 +161,38 @@ class EllipticalAperture(EllipticalMaskMixin, PixelAperture):
 
     Examples
     --------
+    >>> from astropy.coordinates import Angle
     >>> from photutils.aperture import EllipticalAperture
+
+    >>> theta = Angle(80, 'deg')
     >>> aper = EllipticalAperture([10., 20.], 5., 3.)
-    >>> aper = EllipticalAperture((10., 20.), 5., 3., theta=np.pi)
+    >>> aper = EllipticalAperture((10., 20.), 5., 3., theta=theta)
 
     >>> pos1 = (10., 20.)  # (x, y)
     >>> pos2 = (30., 40.)
     >>> pos3 = (50., 60.)
     >>> aper = EllipticalAperture([pos1, pos2, pos3], 5., 3.)
-    >>> aper = EllipticalAperture((pos1, pos2, pos3), 5., 3., theta=np.pi)
+    >>> aper = EllipticalAperture((pos1, pos2, pos3), 5., 3., theta=theta)
     """
 
-    _shape_params = ('a', 'b', 'theta')
-    positions = PixelPositions('positions',
-                               description='The center pixel position(s).')
-    a = PositiveScalar('a', description='The semimajor axis in pixels.')
-    b = PositiveScalar('b', description='The semiminor axis in pixels.')
-    theta = Scalar('theta',
-                   description=('The counterclockwise rotation angle in '
-                                'radians of the ellipse semimajor axis from '
-                                'the positive x axis.'))
+    _params = ('positions', 'a', 'b', 'theta')
+    positions = PixelPositions('The center pixel position(s).')
+    a = PositiveScalar('The semimajor axis in pixels.')
+    b = PositiveScalar('The semiminor axis in pixels.')
+    theta = ScalarAngleOrValue('The counterclockwise rotation angle as an '
+                               'angular Quantity or value in radians from '
+                               'the positive x axis.')
 
     def __init__(self, positions, a, b, theta=0.):
         self.positions = positions
         self.a = a
         self.b = b
+        self._theta_radians = 0.0  # defined by theta setter
         self.theta = theta
 
     @property
     def _xy_extents(self):
-        return self._calc_extents(self.a, self.b, self.theta)
+        return self._calc_extents(self.a, self.b, self._theta_radians)
 
     @property
     def area(self):
@@ -219,16 +225,21 @@ class EllipticalAperture(EllipticalMaskMixin, PixelAperture):
                                                                **kwargs)
 
         patches = []
-        theta_deg = self.theta * 180. / np.pi
+        theta_deg = self._theta_radians * 180. / np.pi
         for xy_position in xy_positions:
-            patches.append(mpatches.Ellipse(xy_position, 2.*self.a, 2.*self.b,
-                                            theta_deg, **patch_kwargs))
+            patches.append(mpatches.Ellipse(xy_position, 2. * self.a,
+                                            2. * self.b, theta_deg,
+                                            **patch_kwargs))
 
         if self.isscalar:
             return patches[0]
         else:
             return patches
 
+    def to_mask(self, method='exact', subpixels=5):
+        return EllipticalMaskMixin.to_mask(self, method=method,
+                                           subpixels=subpixels)
+
     def to_sky(self, wcs):
         """
         Convert the aperture to a `SkyEllipticalAperture` object defined
@@ -259,14 +270,15 @@ class EllipticalAnnulus(EllipticalMaskMixin, PixelAperture):
 
     Parameters
     ----------
-    positions : array_like or `~astropy.units.Quantity`
+    positions : array_like
         The pixel coordinates of the aperture center(s) in one of the
         following formats:
 
             * single ``(x, y)`` pair as a tuple, list, or `~numpy.ndarray`
             * tuple, list, or `~numpy.ndarray` of ``(x, y)`` pairs
             * `~astropy.units.Quantity` instance of ``(x, y)`` pairs in
-              pixel units
+              pixel units (this is Deprecated and will be removed in a
+              future version)
 
     a_in : float
         The inner semimajor axis of the elliptical annulus in pixels.
@@ -284,10 +296,11 @@ class EllipticalAnnulus(EllipticalMaskMixin, PixelAperture):
             .. math:: b_{in} = b_{out}
                 \left(\frac{a_{in}}{a_{out}}\right)
 
-    theta : float, optional
-        The rotation angle in radians of the ellipse semimajor axis from
-        the positive ``x`` axis.  The rotation angle increases
-        counterclockwise.  The default is 0.
+    theta : float or `~astropy.units.Quantity`, optional
+        The rotation angle as an angular quantity
+        (`~astropy.units.Quantity` or `~astropy.coordinates.Angle`) or
+        value in radians (as a float) from the positive ``x`` axis. The
+        rotation angle increases counterclockwise.
 
     Raises
     ------
@@ -301,32 +314,29 @@ class EllipticalAnnulus(EllipticalMaskMixin, PixelAperture):
 
     Examples
     --------
+    >>> from astropy.coordinates import Angle
     >>> from photutils.aperture import EllipticalAnnulus
+
+    >>> theta = Angle(80, 'deg')
     >>> aper = EllipticalAnnulus([10., 20.], 3., 8., 5.)
-    >>> aper = EllipticalAnnulus((10., 20.), 3., 8., 5., theta=np.pi)
+    >>> aper = EllipticalAnnulus((10., 20.), 3., 8., 5., theta=theta)
 
     >>> pos1 = (10., 20.)  # (x, y)
     >>> pos2 = (30., 40.)
     >>> pos3 = (50., 60.)
     >>> aper = EllipticalAnnulus([pos1, pos2, pos3], 3., 8., 5.)
-    >>> aper = EllipticalAnnulus((pos1, pos2, pos3), 3., 8., 5., theta=np.pi)
+    >>> aper = EllipticalAnnulus((pos1, pos2, pos3), 3., 8., 5., theta=theta)
     """
 
-    _shape_params = ('a_in', 'a_out', 'b_in', 'b_out', 'theta')
-    positions = PixelPositions('positions',
-                               description='The center pixel position(s).')
-    a_in = PositiveScalar('a_in',
-                          description='The inner semimajor axis in pixels.')
-    a_out = PositiveScalar('a_out',
-                           description='The outer semimajor axis in pixels.')
-    b_in = PositiveScalar('b_in',
-                          description='The inner semiminor axis in pixels.')
-    b_out = PositiveScalar('b_out',
-                           description='The outer semiminor axis in pixels.')
-    theta = Scalar('theta',
-                   description=('The counterclockwise rotation angle in '
-                                'radians of the ellipse semimajor axis from '
-                                'the positive x axis.'))
+    _params = ('positions', 'a_in', 'a_out', 'b_in', 'b_out', 'theta')
+    positions = PixelPositions('The center pixel position(s).')
+    a_in = PositiveScalar('The inner semimajor axis in pixels.')
+    a_out = PositiveScalar('The outer semimajor axis in pixels.')
+    b_in = PositiveScalar('The inner semiminor axis in pixels.')
+    b_out = PositiveScalar('The outer semiminor axis in pixels.')
+    theta = ScalarAngleOrValue('The counterclockwise rotation angle as an '
+                               'angular Quantity or value in radians from '
+                               'the positive x axis.')
 
     def __init__(self, positions, a_in, a_out, b_out, b_in=None, theta=0.):
         if not a_out > a_in:
@@ -344,11 +354,12 @@ class EllipticalAnnulus(EllipticalMaskMixin, PixelAperture):
                 raise ValueError('"b_out" must be greater than "b_in".')
         self.b_in = b_in
 
+        self._theta_radians = 0.0  # defined by theta setter
         self.theta = theta
 
     @property
     def _xy_extents(self):
-        return self._calc_extents(self.a_out, self.b_out, self.theta)
+        return self._calc_extents(self.a_out, self.b_out, self._theta_radians)
 
     @property
     def area(self):
@@ -381,12 +392,12 @@ class EllipticalAnnulus(EllipticalMaskMixin, PixelAperture):
                                                                **kwargs)
 
         patches = []
-        theta_deg = self.theta * 180. / np.pi
+        theta_deg = self._theta_radians * 180. / np.pi
         for xy_position in xy_positions:
-            patch_inner = mpatches.Ellipse(xy_position, 2.*self.a_in,
-                                           2.*self.b_in, theta_deg)
-            patch_outer = mpatches.Ellipse(xy_position, 2.*self.a_out,
-                                           2.*self.b_out, theta_deg)
+            patch_inner = mpatches.Ellipse(xy_position, 2. * self.a_in,
+                                           2. * self.b_in, theta_deg)
+            patch_outer = mpatches.Ellipse(xy_position, 2. * self.a_out,
+                                           2. * self.b_out, theta_deg)
             path = self._make_annulus_path(patch_inner, patch_outer)
             patches.append(mpatches.PathPatch(path, **patch_kwargs))
 
@@ -395,6 +406,10 @@ class EllipticalAnnulus(EllipticalMaskMixin, PixelAperture):
         else:
             return patches
 
+    def to_mask(self, method='exact', subpixels=5):
+        return EllipticalMaskMixin.to_mask(self, method=method,
+                                           subpixels=subpixels)
+
     def to_sky(self, wcs):
         """
         Convert the aperture to a `SkyEllipticalAnnulus` object defined
@@ -430,18 +445,17 @@ class SkyEllipticalAperture(SkyAperture):
         either scalar coordinates or an array of coordinates.
 
     a : scalar `~astropy.units.Quantity`
-        The semimajor axis of the ellipse, either in angular or pixel
-        units.
+        The semimajor axis of the ellipse in angular units. Pixel units
+        are now deprecated.
 
     b : scalar `~astropy.units.Quantity`
-        The semiminor axis of the ellipse, either in angular or pixel
-        units.
+        The semiminor axis of the ellipse in angular units. Pixel units
+        are now deprecated.
 
     theta : scalar `~astropy.units.Quantity`, optional
         The position angle (in angular units) of the ellipse semimajor
         axis.  For a right-handed world coordinate system, the position
-        angle increases counterclockwise from North (PA=0).  The default
-        is 0 degrees.
+        angle increases counterclockwise from North (PA=0).
 
     Examples
     --------
@@ -452,22 +466,14 @@ class SkyEllipticalAperture(SkyAperture):
     >>> aper = SkyEllipticalAperture(positions, 1.0*u.arcsec, 0.5*u.arcsec)
     """
 
-    _shape_params = ('a', 'b', 'theta')
-    positions = SkyCoordPositions(
-        'positions',
-        description='The center position(s) in sky coordinates.')
-    a = AngleOrPixelScalarQuantity(
-        'a',
-        description='The semimajor axis, in angular or pixel units.')
-    b = AngleOrPixelScalarQuantity(
-        'b',
-        description='The semiminor axis, in angular or pixel units.')
-    theta = AngleScalarQuantity(
-        'theta',
-        description=('The position angle in angular units of the ellipse '
-                     'semimajor axis.'))
+    _params = ('positions', 'a', 'b', 'theta')
+    positions = SkyCoordPositions('The center position(s) in sky coordinates.')
+    a = ScalarAngleOrPixel('The semimajor axis in angular units.')
+    b = ScalarAngleOrPixel('The semiminor axis in angular units.')
+    theta = ScalarAngle('The position angle in angular units of the ellipse '
+                        'semimajor axis.')
 
-    def __init__(self, positions, a, b, theta=0.*u.deg):
+    def __init__(self, positions, a, b, theta=0. * u.deg):
         if a.unit.physical_type != b.unit.physical_type:
             raise ValueError('a and b should either both be angles '
                              'or in pixels')
@@ -512,17 +518,21 @@ class SkyEllipticalAnnulus(SkyAperture):
         either scalar coordinates or an array of coordinates.
 
     a_in : scalar `~astropy.units.Quantity`
-        The inner semimajor axis, either in angular or pixel units.
+        The inner semimajor axis in angular units. Pixel units are now
+        deprecated.
 
     a_out : scalar `~astropy.units.Quantity`
-        The outer semimajor axis, either in angular or pixel units.
+        The outer semimajor axis in angular units. Pixel units are now
+        deprecated.
 
     b_out : scalar `~astropy.units.Quantity`
-        The outer semiminor axis, either in angular or pixel units.
+        The outer semiminor axis in angular units. Pixel units are now
+        deprecated.
 
     b_in : `None` or scalar `~astropy.units.Quantity`
-        The inner semiminor axis, either in angular or pixel units.
-        If `None`, then the inner semiminor axis is calculated as:
+        The inner semiminor axis in angular units. Pixel units are
+        now deprecated. If `None`, then the inner semiminor axis is
+        calculated as:
 
             .. math:: b_{in} = b_{out}
                 \left(\frac{a_{in}}{a_{out}}\right)
@@ -530,8 +540,7 @@ class SkyEllipticalAnnulus(SkyAperture):
     theta : scalar `~astropy.units.Quantity`, optional
         The position angle (in angular units) of the ellipse semimajor
         axis.  For a right-handed world coordinate system, the position
-        angle increases counterclockwise from North (PA=0).  The default
-        is 0 degrees.
+        angle increases counterclockwise from North (PA=0).
 
     Examples
     --------
@@ -543,29 +552,17 @@ class SkyEllipticalAnnulus(SkyAperture):
     ...                             1.0*u.arcsec)
     """
 
-    _shape_params = ('a_in', 'a_out', 'b_in', 'b_out', 'theta')
-    positions = SkyCoordPositions(
-        'positions',
-        description='The center position(s) in sky coordinates.')
-    a_in = AngleOrPixelScalarQuantity(
-        'a_in',
-        description='The inner semimajor axis, in angular or pixel units.')
-    a_out = AngleOrPixelScalarQuantity(
-        'a_out',
-        description='The outer semimajor axis, in angular or pixel units.')
-    b_in = AngleOrPixelScalarQuantity(
-        'b_in',
-        description='The inner semiminor axis, in angular or pixel units.')
-    b_out = AngleOrPixelScalarQuantity(
-        'b_out',
-        description='The outer semiminor axis, in angular or pixel units.')
-    theta = AngleScalarQuantity(
-        'theta',
-        description=('The position angle in angular units of the ellipse '
-                     'semimajor axis.'))
+    _params = ('positions', 'a_in', 'a_out', 'b_in', 'b_out', 'theta')
+    positions = SkyCoordPositions('The center position(s) in sky coordinates.')
+    a_in = ScalarAngleOrPixel('The inner semimajor axis in angular units.')
+    a_out = ScalarAngleOrPixel('The outer semimajor axis in angular units.')
+    b_in = ScalarAngleOrPixel('The inner semiminor axis in angular units.')
+    b_out = ScalarAngleOrPixel('The outer semiminor axis in angular units.')
+    theta = ScalarAngle('The position angle in angular units of the ellipse '
+                        'semimajor axis.')
 
     def __init__(self, positions, a_in, a_out, b_out, b_in=None,
-                 theta=0.*u.deg):
+                 theta=0. * u.deg):
         if a_in.unit.physical_type != a_out.unit.physical_type:
             raise ValueError('a_in and a_out should either both be angles '
                              'or in pixels')
