@@ -62,27 +62,28 @@ def aperture_photometry(data, apertures, error=None, mask=None,
 
             * ``'exact'`` (default):
                 The the exact fractional overlap of the aperture and
-                each pixel is calculated.  The returned mask will
+                each pixel is calculated. The aperture weights will
                 contain values between 0 and 1.
 
             * ``'center'``:
                 A pixel is considered to be entirely in or out of the
                 aperture depending on whether its center is in or out of
-                the aperture.  The returned mask will contain values
+                the aperture. The aperture weights will contain values
                 only of 0 (out) and 1 (in).
 
             * ``'subpixel'``:
                 A pixel is divided into subpixels (see the ``subpixels``
                 keyword), each of which are considered to be entirely in
                 or out of the aperture depending on whether its center
-                is in or out of the aperture.  If ``subpixels=1``, this
-                method is equivalent to ``'center'``.  The returned mask
-                will contain values between 0 and 1.
+                is in or out of the aperture. If ``subpixels=1``, this
+                method is equivalent to ``'center'``. The aperture
+                weights will contain values between 0 and 1.
 
     subpixels : int, optional
-        For the ``'subpixel'`` method, resample pixels by this factor in
-        each dimension.  That is, each pixel is divided into ``subpixels
-        ** 2`` subpixels.
+        For the ``'subpixel'`` method, resample pixels by this factor
+        in each dimension. That is, each pixel is divided into
+        ``subpixels ** 2`` subpixels. This keyword is ignored unless
+        ``method='subpixel'``.
 
     wcs : WCS object, optional
         A world coordinate system (WCS) transformation that
@@ -142,9 +143,9 @@ def aperture_photometry(data, apertures, error=None, mask=None,
         nddata_attr = {'error': error, 'mask': mask, 'wcs': wcs}
         for key, value in nddata_attr.items():
             if value is not None:
-                warnings.warn('The {0!r} keyword is be ignored.  Its value '
-                              'is obtained from the input NDData object.'
-                              .format(key), AstropyUserWarning)
+                warnings.warn(f'The {key!r} keyword is be ignored. Its value '
+                              'is obtained from the input NDData object.',
+                              AstropyUserWarning)
 
         mask = data.mask
         wcs = data.wcs
