@@ -9,9 +9,9 @@ import math
 import astropy.units as u
 import numpy as np
 
-from .attributes import (AngleOrPixelScalarQuantity, AngleScalarQuantity,
-                         PixelPositions, PositiveScalar, Scalar,
-                         SkyCoordPositions)
+from .attributes import (ScalarAngle, PixelPositions, PositiveScalar,
+                         SkyCoordPositions, ScalarAngleOrPixel,
+                         ScalarAngleOrValue)
 from .core import PixelAperture, SkyAperture
 from .mask import ApertureMask
 from ..geometry import rectangular_overlap_grid
@@ -41,28 +41,29 @@ class RectangularMaskMixin:
 
                 * ``'exact'`` (default):
                   The the exact fractional overlap of the aperture and
-                  each pixel is calculated.  The returned mask will
+                  each pixel is calculated. The aperture weights will
                   contain values between 0 and 1.
 
                 * ``'center'``:
                   A pixel is considered to be entirely in or out of the
                   aperture depending on whether its center is in or out
-                  of the aperture.  The returned mask will contain
+                  of the aperture. The aperture weights will contain
                   values only of 0 (out) and 1 (in).
 
                 * ``'subpixel'``:
                   A pixel is divided into subpixels (see the
                   ``subpixels`` keyword), each of which are considered
-                  to be entirely in or out of the aperture depending on
-                  whether its center is in or out of the aperture.  If
-                  ``subpixels=1``, this method is equivalent to
-                  ``'center'``.  The returned mask will contain values
+                  to be entirely in or out of the aperture depending
+                  on whether its center is in or out of the aperture.
+                  If ``subpixels=1``, this method is equivalent to
+                  ``'center'``. The aperture weights will contain values
                   between 0 and 1.
 
         subpixels : int, optional
-            For the ``'subpixel'`` method, resample pixels by this factor
-            in each dimension.  That is, each pixel is divided into
-            ``subpixels ** 2`` subpixels.
+            For the ``'subpixel'`` method, resample pixels by this
+            factor in each dimension. That is, each pixel is divided
+            into ``subpixels ** 2`` subpixels. This keyword is ignored
+            unless ``method='subpixel'``.
 
         Returns
         -------
@@ -90,13 +91,14 @@ class RectangularMaskMixin:
             ny, nx = bbox.shape
             mask = rectangular_overlap_grid(edges[0], edges[1], edges[2],
                                             edges[3], nx, ny, w, h,
-                                            self.theta, 0, subpixels)
+                                            self._theta_radians, 0, subpixels)
 
             # subtract the inner circle for an annulus
             if hasattr(self, 'w_in'):
                 mask -= rectangular_overlap_grid(edges[0], edges[1], edges[2],
                                                  edges[3], nx, ny, self.w_in,
-                                                 self.h_in, self.theta, 0,
+                                                 self.h_in,
+                                                 self._theta_radians, 0,
                                                  subpixels)
 
             masks.append(ApertureMask(mask, bbox))
@@ -151,14 +153,15 @@ class RectangularAperture(RectangularMaskMixin, PixelAperture):
 
     Parameters
     ----------
-    positions : array_like or `~astropy.units.Quantity`
+    positions : array_like
         The pixel coordinates of the aperture center(s) in one of the
         following formats:
 
             * single ``(x, y)`` pair as a tuple, list, or `~numpy.ndarray`
             * tuple, list, or `~numpy.ndarray` of ``(x, y)`` pairs
             * `~astropy.units.Quantity` instance of ``(x, y)`` pairs in
-              pixel units
+              pixel units (this is Deprecated and will be removed in a
+              future version)
 
     w : float
         The full width of the rectangle in pixels.  For ``theta=0`` the
@@ -168,10 +171,11 @@ class RectangularAperture(RectangularMaskMixin, PixelAperture):
         The full height of the rectangle in pixels.  For ``theta=0`` the
         height side is along the ``y`` axis.
 
-    theta : float, optional
-        The rotation angle in radians of the rectangle "width" side from
-        the positive ``x`` axis.  The rotation angle increases
-        counterclockwise.  The default is 0.
+    theta : float or `~astropy.units.Quantity`, optional
+        The rotation angle as an angular quantity
+        (`~astropy.units.Quantity` or `~astropy.coordinates.Angle`) or
+        value in radians (as a float) from the positive ``x`` axis. The
+        rotation angle increases counterclockwise.
 
     Raises
     ------
@@ -180,36 +184,38 @@ class RectangularAperture(RectangularMaskMixin, PixelAperture):
 
     Examples
     --------
+    >>> from astropy.coordinates import Angle
     >>> from photutils.aperture import RectangularAperture
+
+    >>> theta = Angle(80, 'deg')
     >>> aper = RectangularAperture([10., 20.], 5., 3.)
-    >>> aper = RectangularAperture((10., 20.), 5., 3., theta=np.pi)
+    >>> aper = RectangularAperture((10., 20.), 5., 3., theta=theta)
 
     >>> pos1 = (10., 20.)  # (x, y)
     >>> pos2 = (30., 40.)
     >>> pos3 = (50., 60.)
     >>> aper = RectangularAperture([pos1, pos2, pos3], 5., 3.)
-    >>> aper = RectangularAperture((pos1, pos2, pos3), 5., 3., theta=np.pi)
+    >>> aper = RectangularAperture((pos1, pos2, pos3), 5., 3., theta=theta)
     """
 
-    _shape_params = ('w', 'h', 'theta')
-    positions = PixelPositions('positions',
-                               description='The center pixel position(s).')
-    w = PositiveScalar('w', description='The full width in pixels.')
-    h = PositiveScalar('h', description='The full height in pixels.')
-    theta = Scalar('theta',
-                   description=('The counterclockwise rotation angle in '
-                                'radians of the rectangle "width" side from '
-                                'the positive x axis.'))
+    _params = ('positions', 'w', 'h', 'theta')
+    positions = PixelPositions('The center pixel position(s).')
+    w = PositiveScalar('The full width in pixels.')
+    h = PositiveScalar('The full height in pixels.')
+    theta = ScalarAngleOrValue('The counterclockwise rotation angle as an '
+                               'angular Quantity or value in radians from '
+                               'the positive x axis.')
 
     def __init__(self, positions, w, h, theta=0.):
         self.positions = positions
         self.w = w
         self.h = h
+        self._theta_radians = 0.0  # defined by theta setter
         self.theta = theta
 
     @property
     def _xy_extents(self):
-        return self._calc_extents(self.w, self.h, self.theta)
+        return self._calc_extents(self.w, self.h, self._theta_radians)
 
     @property
     def area(self):
@@ -241,10 +247,10 @@ class RectangularAperture(RectangularMaskMixin, PixelAperture):
         xy_positions, patch_kwargs = self._define_patch_params(origin=origin,
                                                                **kwargs)
         xy_positions = self._lower_left_positions(xy_positions, self.w,
-                                                  self.h, self.theta)
+                                                  self.h, self._theta_radians)
 
         patches = []
-        theta_deg = self.theta * 180. / np.pi
+        theta_deg = self._theta_radians * 180. / np.pi
         for xy_position in xy_positions:
             patches.append(mpatches.Rectangle(xy_position, self.w, self.h,
                                               theta_deg, **patch_kwargs))
@@ -254,6 +260,10 @@ class RectangularAperture(RectangularMaskMixin, PixelAperture):
         else:
             return patches
 
+    def to_mask(self, method='exact', subpixels=5):
+        return RectangularMaskMixin.to_mask(self, method=method,
+                                            subpixels=subpixels)
+
     def to_sky(self, wcs):
         """
         Convert the aperture to a `SkyRectangularAperture` object
@@ -284,14 +294,15 @@ class RectangularAnnulus(RectangularMaskMixin, PixelAperture):
 
     Parameters
     ----------
-    positions : array_like or `~astropy.units.Quantity`
+    positions : array_like
         The pixel coordinates of the aperture center(s) in one of the
         following formats:
 
             * single ``(x, y)`` pair as a tuple, list, or `~numpy.ndarray`
             * tuple, list, or `~numpy.ndarray` of ``(x, y)`` pairs
             * `~astropy.units.Quantity` instance of ``(x, y)`` pairs in
-              pixel units
+              pixel units (this is Deprecated and will be removed in a
+              future version)
 
     w_in : float
         The inner full width of the rectangular annulus in pixels.  For
@@ -313,10 +324,11 @@ class RectangularAnnulus(RectangularMaskMixin, PixelAperture):
 
         For ``theta=0`` the height side is along the ``y`` axis.
 
-    theta : float, optional
-        The rotation angle in radians of the rectangle "width" side from
-        the positive ``x`` axis.  The rotation angle increases
-        counterclockwise.  The default is 0.
+    theta : float or `~astropy.units.Quantity`, optional
+        The rotation angle as an angular quantity
+        (`~astropy.units.Quantity` or `~astropy.coordinates.Angle`) or
+        value in radians (as a float) from the positive ``x`` axis. The
+        rotation angle increases counterclockwise.
 
     Raises
     ------
@@ -330,32 +342,29 @@ class RectangularAnnulus(RectangularMaskMixin, PixelAperture):
 
     Examples
     --------
+    >>> from astropy.coordinates import Angle
     >>> from photutils.aperture import RectangularAnnulus
+
+    >>> theta = Angle(80, 'deg')
     >>> aper = RectangularAnnulus([10., 20.], 3., 8., 5.)
-    >>> aper = RectangularAnnulus((10., 20.), 3., 8., 5., theta=np.pi)
+    >>> aper = RectangularAnnulus((10., 20.), 3., 8., 5., theta=theta)
 
     >>> pos1 = (10., 20.)  # (x, y)
     >>> pos2 = (30., 40.)
     >>> pos3 = (50., 60.)
     >>> aper = RectangularAnnulus([pos1, pos2, pos3], 3., 8., 5.)
-    >>> aper = RectangularAnnulus((pos1, pos2, pos3), 3., 8., 5., theta=np.pi)
+    >>> aper = RectangularAnnulus((pos1, pos2, pos3), 3., 8., 5., theta=theta)
     """
 
-    _shape_params = ('w_in', 'w_out', 'h_in', 'h_out', 'theta')
-    positions = PixelPositions('positions',
-                               description='The center pixel position(s).')
-    w_in = PositiveScalar('w_in',
-                          description='The inner full width in pixels.')
-    w_out = PositiveScalar('w_out',
-                           description='The outer full width in pixels.')
-    h_in = PositiveScalar('h_in',
-                          description='The inner full height in pixels.')
-    h_out = PositiveScalar('h_out',
-                           description='The outer full height in pixels.')
-    theta = Scalar('theta',
-                   description=('The counterclockwise rotation angle in '
-                                'radians of the rectangle "width" side from '
-                                'the positive x axis.'))
+    _params = ('positions', 'w_in', 'w_out', 'h_in', 'h_out', 'theta')
+    positions = PixelPositions('The center pixel position(s).')
+    w_in = PositiveScalar('The inner full width in pixels.')
+    w_out = PositiveScalar('The outer full width in pixels.')
+    h_in = PositiveScalar('The inner full height in pixels.')
+    h_out = PositiveScalar('The outer full height in pixels.')
+    theta = ScalarAngleOrValue('The counterclockwise rotation angle as an '
+                               'angular Quantity or value in radians from '
+                               'the positive x axis.')
 
     def __init__(self, positions, w_in, w_out, h_out, h_in=None, theta=0.):
         if not w_out > w_in:
@@ -373,11 +382,12 @@ class RectangularAnnulus(RectangularMaskMixin, PixelAperture):
                 raise ValueError('"h_out" must be greater than "h_in"')
         self.h_in = h_in
 
+        self._theta_radians = 0.0  # defined by theta setter
         self.theta = theta
 
     @property
     def _xy_extents(self):
-        return self._calc_extents(self.w_out, self.h_out, self.theta)
+        return self._calc_extents(self.w_out, self.h_out, self._theta_radians)
 
     @property
     def area(self):
@@ -410,14 +420,14 @@ class RectangularAnnulus(RectangularMaskMixin, PixelAperture):
                                                                **kwargs)
         inner_xy_positions = self._lower_left_positions(xy_positions,
                                                         self.w_in, self.h_in,
-                                                        self.theta)
+                                                        self._theta_radians)
         outer_xy_positions = self._lower_left_positions(xy_positions,
                                                         self.w_out,
                                                         self.h_out,
-                                                        self.theta)
+                                                        self._theta_radians)
 
         patches = []
-        theta_deg = self.theta * 180. / np.pi
+        theta_deg = self._theta_radians * 180. / np.pi
         for xy_in, xy_out in zip(inner_xy_positions, outer_xy_positions):
             patch_inner = mpatches.Rectangle(xy_in, self.w_in, self.h_in,
                                              theta_deg)
@@ -431,6 +441,10 @@ class RectangularAnnulus(RectangularMaskMixin, PixelAperture):
         else:
             return patches
 
+    def to_mask(self, method='exact', subpixels=5):
+        return RectangularMaskMixin.to_mask(self, method=method,
+                                            subpixels=subpixels)
+
     def to_sky(self, wcs):
         """
         Convert the aperture to a `SkyRectangularAnnulus` object
@@ -466,20 +480,19 @@ class SkyRectangularAperture(SkyAperture):
         either scalar coordinates or an array of coordinates.
 
     w : scalar `~astropy.units.Quantity`
-        The full width of the rectangle, either in angular or pixel
-        units.  For ``theta=0`` the width side is along the North-South
-        axis.
+        The full width of the rectangle in angular units. Pixel units
+        are now deprecated. For ``theta=0`` the width side is along the
+        North-South axis.
 
     h :  scalar `~astropy.units.Quantity`
-        The full height of the rectangle, either in angular or pixel
-        units.  For ``theta=0`` the height side is along the East-West
-        axis.
+        The full height of the rectangle in angular units. Pixel units
+        are now deprecated. For ``theta=0`` the height side is along the
+        East-West axis.
 
     theta : scalar `~astropy.units.Quantity`, optional
         The position angle (in angular units) of the rectangle "width"
         side.  For a right-handed world coordinate system, the position
-        angle increases counterclockwise from North (PA=0).  The default
-        is 0 degrees.
+        angle increases counterclockwise from North (PA=0).
 
     Examples
     --------
@@ -490,22 +503,14 @@ class SkyRectangularAperture(SkyAperture):
     >>> aper = SkyRectangularAperture(positions, 1.0*u.arcsec, 0.5*u.arcsec)
     """
 
-    _shape_params = ('w', 'h', 'theta')
-    positions = SkyCoordPositions(
-        'positions',
-        description='The center position(s) in sky coordinates.')
-    w = AngleOrPixelScalarQuantity(
-        'w',
-        description='The full width, in angular or pixel units.')
-    h = AngleOrPixelScalarQuantity(
-        'h',
-        description='The full height, in angular or pixel units.')
-    theta = AngleScalarQuantity(
-        'theta',
-        description=('The position angle (in angular units) of the '
-                     'rectangle "width" side.'))
+    _params = ('positions', 'w', 'h', 'theta')
+    positions = SkyCoordPositions('The center position(s) in sky coordinates.')
+    w = ScalarAngleOrPixel('The full width in angular units.')
+    h = ScalarAngleOrPixel('The full height in angular units.')
+    theta = ScalarAngle('The position angle (in angular units) of the '
+                        'rectangle "width" side.')
 
-    def __init__(self, positions, w, h, theta=0.*u.deg):
+    def __init__(self, positions, w, h, theta=0. * u.deg):
         if w.unit.physical_type != h.unit.physical_type:
             raise ValueError('"w" and "h" should either both be angles or '
                              'in pixels')
@@ -550,23 +555,23 @@ class SkyRectangularAnnulus(SkyAperture):
         either scalar coordinates or an array of coordinates.
 
     w_in : scalar `~astropy.units.Quantity`
-        The inner full width of the rectangular annulus, either in
-        angular or pixel units.  For ``theta=0`` the width side is along
-        the North-South axis.
+        The inner full width of the rectangular annulus in angular
+        units. Pixel units are now deprecated. For ``theta=0`` the width
+        side is along the North-South axis.
 
     w_out : scalar `~astropy.units.Quantity`
-        The outer full width of the rectangular annulus, either in
-        angular or pixel units.  For ``theta=0`` the width side is along
-        the North-South axis.
+        The outer full width of the rectangular annulus in angular
+        units. Pixel units are now deprecated. For ``theta=0`` the width
+        side is along the North-South axis.
 
     h_out : scalar `~astropy.units.Quantity`
-        The outer full height of the rectangular annulus, either in
-        angular or pixel units.
+        The outer full height of the rectangular annulus in angular
+        units. Pixel units are now deprecated.
 
     h_in : `None` or scalar `~astropy.units.Quantity`
-        The outer full height of the rectangular annulus, either in
-        angular or pixel units.  If `None`, then the inner full height
-        is calculated as:
+        The outer full height of the rectangular annulus in angular
+        units. Pixel units are now deprecated. If `None`, then the inner
+        full height is calculated as:
 
             .. math:: h_{in} = h_{out}
                 \left(\frac{w_{in}}{w_{out}}\right)
@@ -576,8 +581,7 @@ class SkyRectangularAnnulus(SkyAperture):
     theta : scalar `~astropy.units.Quantity`, optional
         The position angle (in angular units) of the rectangle "width"
         side.  For a right-handed world coordinate system, the position
-        angle increases counterclockwise from North (PA=0).  The default
-        is 0 degrees.
+        angle increases counterclockwise from North (PA=0).
 
     Examples
     --------
@@ -589,29 +593,17 @@ class SkyRectangularAnnulus(SkyAperture):
     ...                              5.0*u.arcsec)
     """
 
-    _shape_params = ('w_in', 'w_out', 'h_in', 'h_out', 'theta')
-    positions = SkyCoordPositions(
-        'positions',
-        description='The center position(s) in sky coordinates.')
-    w_in = AngleOrPixelScalarQuantity(
-        'w_in',
-        description='The inner full width, in angular or pixel units.')
-    w_out = AngleOrPixelScalarQuantity(
-        'w_out',
-        description='The outer full width, in angular or pixel units.')
-    h_in = AngleOrPixelScalarQuantity(
-        'h_in',
-        description='The inner full height, in angular or pixel units.')
-    h_out = AngleOrPixelScalarQuantity(
-        'h_out',
-        description='The outer full height, in angular or pixel units.')
-    theta = AngleScalarQuantity(
-        'theta',
-        description=('The position angle (in angular units) of the '
-                     'rectangle "width" side.'))
+    _params = ('positions', 'w_in', 'w_out', 'h_in', 'h_out', 'theta')
+    positions = SkyCoordPositions('The center position(s) in sky coordinates.')
+    w_in = ScalarAngleOrPixel('The inner full width in angular units.')
+    w_out = ScalarAngleOrPixel('The outer full width in angular units.')
+    h_in = ScalarAngleOrPixel('The inner full height in angular units.')
+    h_out = ScalarAngleOrPixel('The outer full height in angular units.')
+    theta = ScalarAngle('The position angle (in angular units) of the '
+                        'rectangle "width" side.')
 
     def __init__(self, positions, w_in, w_out, h_out, h_in=None,
-                 theta=0.*u.deg):
+                 theta=0. * u.deg):
         if w_in.unit.physical_type != w_out.unit.physical_type:
             raise ValueError('w_in and w_out should either both be angles or '
                              'in pixels')
