@@ -109,6 +109,14 @@ def test_bounding_box_as_artist():
     assert_allclose(patch.get_height(), 18)
 
 
+@pytest.mark.skipif('not HAS_MATPLOTLIB')
+def test_bounding_box_plot():
+    from matplotlib.patches import Rectangle
+    bbox = BoundingBox(1, 10, 2, 20)
+    patch = bbox.plot()
+    assert isinstance(patch, Rectangle)
+
+
 @pytest.mark.skipif('not HAS_MATPLOTLIB')
 def test_bounding_box_to_aperture():
     bbox = BoundingBox(1, 10, 2, 20)
@@ -121,13 +129,6 @@ def test_bounding_box_to_aperture():
     assert bbox_aper.theta == aper.theta
 
 
-@pytest.mark.skipif('not HAS_MATPLOTLIB')
-def test_bounding_box_plot():
-    # TODO: check the content of the plot
-    bbox = BoundingBox(1, 10, 2, 20)
-    bbox.plot()
-
-
 def test_bounding_box_union():
     bbox1 = BoundingBox(1, 10, 2, 20)
     bbox2 = BoundingBox(5, 21, 7, 32)
