@@ -13,8 +13,8 @@ from astropy.io import fits
 from astropy.nddata import NDData, StdDevUncertainty
 from astropy.table import Table
 import astropy.units as u
+from astropy.utils.exceptions import AstropyDeprecationWarning
 from astropy.wcs import WCS
-from astropy.wcs.utils import pixel_to_skycoord
 
 from ..photometry import aperture_photometry
 from ..circle import (CircularAperture, CircularAnnulus, SkyCircularAperture,
@@ -37,9 +37,9 @@ APERTURE_CL = [CircularAperture,
 TEST_APERTURES = list(zip(APERTURE_CL, ((3.,),
                                         (3., 5.),
                                         (3., 5., 1.),
-                                        (3., 5., 4., 12./5., 1.),
+                                        (3., 5., 4., 12. / 5., 1.),
                                         (5, 8, np.pi / 4),
-                                        (8, 12, 8, 16./3., np.pi / 8))))
+                                        (8, 12, 8, 16. / 3., np.pi / 8))))
 
 
 @pytest.mark.parametrize(('aperture_class', 'params'), TEST_APERTURES)
@@ -82,18 +82,10 @@ def test_aperture_plots(aperture_class, params):
 def test_aperture_pixel_positions():
     pos1 = (10, 20)
     pos2 = [(10, 20)]
-    pos3 = u.Quantity((10, 20), unit=u.pixel)
-    pos4 = u.Quantity([(10, 20)], unit=u.pixel)
-
     r = 3
     ap1 = CircularAperture(pos1, r)
     ap2 = CircularAperture(pos2, r)
-    ap3 = CircularAperture(pos3, r)
-    ap4 = CircularAperture(pos4, r)
-
     assert not np.array_equal(ap1.positions, ap2.positions)
-    assert_allclose(ap1.positions, ap3.positions)
-    assert_allclose(ap2.positions, ap4.positions)
 
 
 class BaseTestAperturePhotometry:
@@ -207,8 +199,8 @@ class TestEllipticalAnnulus(BaseTestAperturePhotometry):
         theta = -np.pi / 4.
         self.aperture = EllipticalAnnulus(position, a_in, a_out, b_out,
                                           theta=theta)
-        self.area = (np.pi * (a_out * b_out) -
-                     np.pi * (a_in * b_out * a_in / a_out))
+        self.area = (np.pi * (a_out * b_out)
+                     - np.pi * (a_in * b_out * a_in / a_out))
         self.true_flux = self.area
 
 
@@ -264,10 +256,10 @@ class BaseTestDifferentData:
         assert_allclose(table['aperture_sum'].value, self.true_flux)
         assert table['aperture_sum'].unit, self.fluxunit
 
-        assert np.all(table['xcenter'].value ==
-                      np.transpose(self.position)[0])
-        assert np.all(table['ycenter'].value ==
-                      np.transpose(self.position)[1])
+        assert np.all(table['xcenter'].value
+                      == np.transpose(self.position)[0])
+        assert np.all(table['ycenter'].value
+                      == np.transpose(self.position)[1])
 
 
 class TestInputNDData(BaseTestDifferentData):
@@ -288,7 +280,6 @@ def test_wcs_based_photometry_to_catalogue():
     hdu = fits.open(pathhdu)
     data = u.Quantity(hdu[0].data, unit=hdu[0].header['BUNIT'])
     wcs = WCS(hdu[0].header)
-    scale = hdu[0].header['PIXSCAL1']
 
     catalog = Table.read(pathcat)
 
@@ -297,17 +288,10 @@ def test_wcs_based_photometry_to_catalogue():
     photometry_skycoord = aperture_photometry(
         data, SkyCircularAperture(pos_skycoord, 4 * u.arcsec), wcs=wcs)
 
-    photometry_skycoord_pix = aperture_photometry(
-        data, SkyCircularAperture(pos_skycoord, 4. / scale * u.pixel),
-        wcs=wcs)
-
-    assert_allclose(photometry_skycoord['aperture_sum'],
-                    photometry_skycoord_pix['aperture_sum'])
-
     # Photometric unit conversion is needed to match the catalogue
     factor = (1.2 * u.arcsec) ** 2 / u.pixel
-    converted_aperture_sum = (photometry_skycoord['aperture_sum'] *
-                              factor).to(u.mJy / u.pixel)
+    converted_aperture_sum = (photometry_skycoord['aperture_sum']
+                              * factor).to(u.mJy / u.pixel)
 
     fluxes_catalog = catalog['f4_5'].filled()
 
@@ -315,8 +299,8 @@ def test_wcs_based_photometry_to_catalogue():
     # fluxes_catalog is based on PSF photometry, etc.
     assert_allclose(fluxes_catalog, converted_aperture_sum.value, rtol=1e0)
 
-    assert(np.mean(np.fabs(((fluxes_catalog - converted_aperture_sum.value) /
-                            fluxes_catalog))) < 0.1)
+    assert(np.mean(np.fabs((fluxes_catalog - converted_aperture_sum.value)
+                           / fluxes_catalog)) < 0.1)
 
     # close the file
     hdu.close()
@@ -330,14 +314,7 @@ def test_wcs_based_photometry():
     pos_orig_pixel = u.Quantity(([160., 25., 150., 90.],
                                  [70., 40., 25., 60.]), unit=u.pixel)
 
-    try:
-        pos_skycoord = wcs.pixel_to_world(pos_orig_pixel[0],
-                                          pos_orig_pixel[1])
-    except AttributeError:
-        # for Astropy < 3.1
-        pos_skycoord = pixel_to_skycoord(pos_orig_pixel[0],
-                                         pos_orig_pixel[1], wcs)
-
+    pos_skycoord = wcs.pixel_to_world(pos_orig_pixel[0], pos_orig_pixel[1])
     pos_skycoord_s = pos_skycoord[2]
 
     photometry_skycoord_circ = aperture_photometry(
@@ -361,8 +338,8 @@ def test_wcs_based_photometry():
                     photometry_skycoord_circ_ann_s['aperture_sum'])
 
     assert_allclose(photometry_skycoord_circ_ann['aperture_sum'],
-                    photometry_skycoord_circ['aperture_sum'] -
-                    photometry_skycoord_circ_2['aperture_sum'])
+                    photometry_skycoord_circ['aperture_sum']
+                    - photometry_skycoord_circ_2['aperture_sum'])
 
     photometry_skycoord_ell = aperture_photometry(
         data, SkyEllipticalAperture(pos_skycoord, 3 * u.arcsec,
@@ -395,8 +372,8 @@ def test_wcs_based_photometry():
                     photometry_skycoord_circ['aperture_sum'], rtol=5e-3)
 
     assert_allclose(photometry_skycoord_ell_ann['aperture_sum'],
-                    photometry_skycoord_ell['aperture_sum'] -
-                    photometry_skycoord_ell_2['aperture_sum'], rtol=1e-4)
+                    photometry_skycoord_ell['aperture_sum']
+                    - photometry_skycoord_ell_2['aperture_sum'], rtol=1e-4)
 
     photometry_skycoord_rec = aperture_photometry(
         data, SkyRectangularAperture(pos_skycoord,
@@ -426,33 +403,42 @@ def test_wcs_based_photometry():
     assert_allclose(photometry_skycoord_rec['aperture_sum'][2],
                     photometry_skycoord_rec_s['aperture_sum'])
 
-    assert np.all(photometry_skycoord_rec['aperture_sum'] >
-                  photometry_skycoord_circ['aperture_sum'])
+    assert np.all(photometry_skycoord_rec['aperture_sum']
+                  > photometry_skycoord_circ['aperture_sum'])
 
     assert_allclose(photometry_skycoord_rec_ann['aperture_sum'][2],
                     photometry_skycoord_rec_ann_s['aperture_sum'])
 
     assert_allclose(photometry_skycoord_rec_ann['aperture_sum'],
-                    photometry_skycoord_rec['aperture_sum'] -
-                    photometry_skycoord_rec_4['aperture_sum'], rtol=1e-4)
+                    photometry_skycoord_rec['aperture_sum']
+                    - photometry_skycoord_rec_4['aperture_sum'], rtol=1e-4)
 
 
 def test_basic_circular_aperture_photometry_unit():
-    data1 = np.ones((40, 40), dtype=float)
-    data2 = u.Quantity(data1*u.adu)
-
     radius = 3
-    position = (20, 20)
     true_flux = np.pi * radius * radius
-    unit = u.adu
-
-    table1 = aperture_photometry(data1, CircularAperture(position, radius))
-    table2 = aperture_photometry(data2, CircularAperture(position, radius))
+    aper = CircularAperture((12, 12), radius)
 
+    data1 = np.ones((25, 25), dtype=float)
+    table1 = aperture_photometry(data1, aper)
     assert_allclose(table1['aperture_sum'], true_flux)
+
+    unit = u.adu
+    data2 = u.Quantity(data1 * unit)
+    table2 = aperture_photometry(data2, aper)
     assert_allclose(table2['aperture_sum'].value, true_flux)
     assert table2['aperture_sum'].unit == data2.unit == unit
 
+    error1 = np.ones((25, 25))
+    with pytest.raises(ValueError):
+        # data has unit, but error does not
+        aperture_photometry(data2, aper, error=error1)
+
+    error2 = u.Quantity(error1 * u.Jy)
+    with pytest.raises(ValueError):
+        # data and error have different units
+        aperture_photometry(data2, aper, error=error2)
+
 
 def test_aperture_photometry_with_error_units():
     """Test aperture_photometry when error has units (see #176)."""
@@ -580,79 +566,80 @@ def test_pixel_aperture_repr():
 def test_sky_aperture_repr():
     s = SkyCoord([1, 2], [3, 4], unit='deg')
 
-    aper = SkyCircularAperture(s, r=3*u.pix)
+    aper = SkyCircularAperture(s, r=3 * u.deg)
     a_repr = ('<SkyCircularAperture(<SkyCoord (ICRS): (ra, dec) in deg\n'
-              '    [(1., 3.), (2., 4.)]>, r=3.0 pix)>')
+              '    [(1., 3.), (2., 4.)]>, r=3.0 deg)>')
     a_str = ('Aperture: SkyCircularAperture\npositions: <SkyCoord '
              '(ICRS): (ra, dec) in deg\n    [(1., 3.), (2., 4.)]>\n'
-             'r: 3.0 pix')
+             'r: 3.0 deg')
 
     assert repr(aper) == a_repr
     assert str(aper) == a_str
 
-    aper = SkyCircularAnnulus(s, r_in=3.*u.pix, r_out=5*u.pix)
+    aper = SkyCircularAnnulus(s, r_in=3. * u.deg, r_out=5 * u.deg)
     a_repr = ('<SkyCircularAnnulus(<SkyCoord (ICRS): (ra, dec) in deg\n'
-              '    [(1., 3.), (2., 4.)]>, r_in=3.0 pix, r_out=5.0 pix)>')
+              '    [(1., 3.), (2., 4.)]>, r_in=3.0 deg, r_out=5.0 deg)>')
     a_str = ('Aperture: SkyCircularAnnulus\npositions: <SkyCoord '
              '(ICRS): (ra, dec) in deg\n    [(1., 3.), (2., 4.)]>\n'
-             'r_in: 3.0 pix\nr_out: 5.0 pix')
+             'r_in: 3.0 deg\nr_out: 5.0 deg')
 
     assert repr(aper) == a_repr
     assert str(aper) == a_str
 
-    aper = SkyEllipticalAperture(s, a=3*u.pix, b=5*u.pix, theta=15*u.deg)
+    aper = SkyEllipticalAperture(s, a=3 * u.deg, b=5 * u.deg, theta=15 * u.deg)
     a_repr = ('<SkyEllipticalAperture(<SkyCoord (ICRS): (ra, dec) in '
-              'deg\n    [(1., 3.), (2., 4.)]>, a=3.0 pix, b=5.0 pix,'
-              ' theta=15.0 deg)>')
+              'deg\n    [(1., 3.), (2., 4.)]>, a=3.0 deg, b=5.0 deg, '
+              'theta=15.0 deg)>')
     a_str = ('Aperture: SkyEllipticalAperture\npositions: <SkyCoord '
              '(ICRS): (ra, dec) in deg\n    [(1., 3.), (2., 4.)]>\n'
-             'a: 3.0 pix\nb: 5.0 pix\ntheta: 15.0 deg')
+             'a: 3.0 deg\nb: 5.0 deg\ntheta: 15.0 deg')
 
     assert repr(aper) == a_repr
     assert str(aper) == a_str
 
-    aper = SkyEllipticalAnnulus(s, a_in=3*u.pix, a_out=5*u.pix, b_out=3*u.pix,
-                                theta=15*u.deg)
+    aper = SkyEllipticalAnnulus(s, a_in=3 * u.deg, a_out=5 * u.deg,
+                                b_out=3 * u.deg, theta=15 * u.deg)
     a_repr = ('<SkyEllipticalAnnulus(<SkyCoord (ICRS): (ra, dec) in '
-              'deg\n    [(1., 3.), (2., 4.)]>, a_in=3.0 pix, '
-              'a_out=5.0 pix, b_in=1.8 pix, b_out=3.0 pix, '
+              'deg\n    [(1., 3.), (2., 4.)]>, a_in=3.0 deg, '
+              'a_out=5.0 deg, b_in=1.8 deg, b_out=3.0 deg, '
               'theta=15.0 deg)>')
     a_str = ('Aperture: SkyEllipticalAnnulus\npositions: <SkyCoord '
              '(ICRS): (ra, dec) in deg\n    [(1., 3.), (2., 4.)]>\n'
-             'a_in: 3.0 pix\na_out: 5.0 pix\nb_in: 1.8 pix\n'
-             'b_out: 3.0 pix\ntheta: 15.0 deg')
+             'a_in: 3.0 deg\na_out: 5.0 deg\nb_in: 1.8 deg\n'
+             'b_out: 3.0 deg\ntheta: 15.0 deg')
 
     assert repr(aper) == a_repr
     assert str(aper) == a_str
 
-    aper = SkyRectangularAperture(s, w=3*u.pix, h=5*u.pix, theta=15*u.deg)
+    aper = SkyRectangularAperture(s, w=3 * u.deg, h=5 * u.deg,
+                                  theta=15 * u.deg)
     a_repr = ('<SkyRectangularAperture(<SkyCoord (ICRS): (ra, dec) in '
-              'deg\n    [(1., 3.), (2., 4.)]>, w=3.0 pix, h=5.0 pix'
+              'deg\n    [(1., 3.), (2., 4.)]>, w=3.0 deg, h=5.0 deg'
               ', theta=15.0 deg)>')
     a_str = ('Aperture: SkyRectangularAperture\npositions: <SkyCoord '
              '(ICRS): (ra, dec) in deg\n    [(1., 3.), (2., 4.)]>\n'
-             'w: 3.0 pix\nh: 5.0 pix\ntheta: 15.0 deg')
+             'w: 3.0 deg\nh: 5.0 deg\ntheta: 15.0 deg')
 
     assert repr(aper) == a_repr
     assert str(aper) == a_str
 
-    aper = SkyRectangularAnnulus(s, w_in=5*u.pix, w_out=10*u.pix,
-                                 h_out=6*u.pix, theta=15*u.deg)
+    aper = SkyRectangularAnnulus(s, w_in=5 * u.deg, w_out=10 * u.deg,
+                                 h_out=6 * u.deg, theta=15 * u.deg)
     a_repr = ('<SkyRectangularAnnulus(<SkyCoord (ICRS): (ra, dec) in deg'
-              '\n    [(1., 3.), (2., 4.)]>, w_in=5.0 pix, '
-              'w_out=10.0 pix, h_in=3.0 pix, h_out=6.0 pix, '
+              '\n    [(1., 3.), (2., 4.)]>, w_in=5.0 deg, '
+              'w_out=10.0 deg, h_in=3.0 deg, h_out=6.0 deg, '
               'theta=15.0 deg)>')
     a_str = ('Aperture: SkyRectangularAnnulus\npositions: <SkyCoord '
              '(ICRS): (ra, dec) in deg\n    [(1., 3.), (2., 4.)]>\n'
-             'w_in: 5.0 pix\nw_out: 10.0 pix\nh_in: 3.0 pix\n'
-             'h_out: 6.0 pix\ntheta: 15.0 deg')
+             'w_in: 5.0 deg\nw_out: 10.0 deg\nh_in: 3.0 deg\n'
+             'h_out: 6.0 deg\ntheta: 15.0 deg')
 
     assert repr(aper) == a_repr
     assert str(aper) == a_str
 
 
 def test_rectangular_bbox():
-    # odd sizes
+    # test odd sizes
     width = 7
     height = 3
     a = RectangularAperture((50, 50), w=width, h=height, theta=0)
@@ -661,10 +648,11 @@ def test_rectangular_bbox():
     a = RectangularAperture((50.5, 50.5), w=width, h=height, theta=0)
     assert a.bbox.shape == (height + 1, width + 1)
 
-    a = RectangularAperture((50, 50), w=width, h=height, theta=90.*np.pi/180.)
+    a = RectangularAperture((50, 50), w=width, h=height,
+                            theta=90. * np.pi / 180.)
     assert a.bbox.shape == (width, height)
 
-    # even sizes
+    # test even sizes
     width = 8
     height = 4
     a = RectangularAperture((50, 50), w=width, h=height, theta=0)
@@ -674,7 +662,7 @@ def test_rectangular_bbox():
     assert a.bbox.shape == (height, width)
 
     a = RectangularAperture((50.5, 50.5), w=width, h=height,
-                            theta=90.*np.pi/180.)
+                            theta=90. * np.pi / 180.)
     assert a.bbox.shape == (width, height)
 
 
@@ -683,25 +671,25 @@ def test_elliptical_bbox():
     a = 7
     b = 3
     ap = EllipticalAperture((50, 50), a=a, b=b, theta=0)
-    assert ap.bbox.shape == (2*b + 1, 2*a + 1)
+    assert ap.bbox.shape == (2 * b + 1, 2 * a + 1)
 
     ap = EllipticalAperture((50.5, 50.5), a=a, b=b, theta=0)
-    assert ap.bbox.shape == (2*b, 2*a)
+    assert ap.bbox.shape == (2 * b, 2 * a)
 
-    ap = EllipticalAperture((50, 50), a=a, b=b, theta=90.*np.pi/180.)
-    assert ap.bbox.shape == (2*a + 1, 2*b + 1)
+    ap = EllipticalAperture((50, 50), a=a, b=b, theta=90. * np.pi / 180.)
+    assert ap.bbox.shape == (2 * a + 1, 2 * b + 1)
 
     # fractional axes
     a = 7.5
     b = 4.5
     ap = EllipticalAperture((50, 50), a=a, b=b, theta=0)
-    assert ap.bbox.shape == (2*b, 2*a)
+    assert ap.bbox.shape == (2 * b, 2 * a)
 
     ap = EllipticalAperture((50.5, 50.5), a=a, b=b, theta=0)
-    assert ap.bbox.shape == (2*b + 1, 2*a + 1)
+    assert ap.bbox.shape == (2 * b + 1, 2 * a + 1)
 
-    ap = EllipticalAperture((50, 50), a=a, b=b, theta=90.*np.pi/180.)
-    assert ap.bbox.shape == (2*a, 2*b)
+    ap = EllipticalAperture((50, 50), a=a, b=b, theta=90. * np.pi / 180.)
+    assert ap.bbox.shape == (2 * a, 2 * b)
 
 
 @pytest.mark.skipif('not HAS_GWCS')
@@ -727,7 +715,7 @@ def test_to_sky_pixel(wcs_type):
     assert_allclose(ap.r_out, ap2.r_out)
 
     ap = EllipticalAperture(((12.3, 15.7), (48.19, 98.14)), a=3.14, b=5.32,
-                            theta=103.*np.pi/180.)
+                            theta=103. * np.pi / 180.)
     ap2 = ap.to_sky(wcs).to_pixel(wcs)
     assert_allclose(ap.positions, ap2.positions)
     assert_allclose(ap.a, ap2.a)
@@ -735,7 +723,7 @@ def test_to_sky_pixel(wcs_type):
     assert_allclose(ap.theta, ap2.theta)
 
     ap = EllipticalAnnulus(((12.3, 15.7), (48.19, 98.14)), a_in=3.14,
-                           a_out=15.32, b_out=4.89, theta=103.*np.pi/180.)
+                           a_out=15.32, b_out=4.89, theta=103. * np.pi / 180.)
     ap2 = ap.to_sky(wcs).to_pixel(wcs)
     assert_allclose(ap.positions, ap2.positions)
     assert_allclose(ap.a_in, ap2.a_in)
@@ -744,7 +732,7 @@ def test_to_sky_pixel(wcs_type):
     assert_allclose(ap.theta, ap2.theta)
 
     ap = RectangularAperture(((12.3, 15.7), (48.19, 98.14)), w=3.14, h=5.32,
-                             theta=103.*np.pi/180.)
+                             theta=103. * np.pi / 180.)
     ap2 = ap.to_sky(wcs).to_pixel(wcs)
     assert_allclose(ap.positions, ap2.positions)
     assert_allclose(ap.w, ap2.w)
@@ -752,7 +740,7 @@ def test_to_sky_pixel(wcs_type):
     assert_allclose(ap.theta, ap2.theta)
 
     ap = RectangularAnnulus(((12.3, 15.7), (48.19, 98.14)), w_in=3.14,
-                            w_out=15.32, h_out=4.89, theta=103.*np.pi/180.)
+                            w_out=15.32, h_out=4.89, theta=103. * np.pi / 180.)
     ap2 = ap.to_sky(wcs).to_pixel(wcs)
     assert_allclose(ap.positions, ap2.positions)
     assert_allclose(ap.w_in, ap2.w_in)
@@ -765,18 +753,22 @@ def test_position_units():
     """Regression test for unit check."""
     pos = (10, 10) * u.pix
     pos = np.sqrt(pos**2)
-    ap = CircularAperture(pos, r=3.)
-    assert_allclose(ap.positions, np.array([10, 10]))
+    with pytest.warns(AstropyDeprecationWarning,
+                      match='Inputing positions as a Quantity'):
+        ap = CircularAperture(pos, r=3.)
+        assert_allclose(ap.positions, np.array([10, 10]))
 
 
 def test_radius_units():
     """Regression test for unit check."""
     pos = SkyCoord(10, 10, unit='deg')
-    r = 3.*u.pix
+    r = 3. * u.pix
     r = np.sqrt(r**2)
-    ap = SkyCircularAperture(pos, r=r)
-    assert ap.r.value == 3.0
-    assert ap.r.unit == u.pix
+    with pytest.warns(AstropyDeprecationWarning, match='Inputing sky '
+                      'aperture quantities in pixel units'):
+        ap = SkyCircularAperture(pos, r=r)
+        assert ap.r.value == 3.0
+        assert ap.r.unit == u.pix
 
 
 def test_scalar_aperture():
@@ -839,14 +831,8 @@ def test_scalar_skycoord():
 
     data = make_4gaussians_image()
     wcs = make_wcs(data.shape)
-
-    try:
-        skycoord = wcs.pixel_to_world(90, 60)
-    except AttributeError:
-        # for Astropy < 3.1
-        skycoord = pixel_to_skycoord(90, 60, wcs)
-
-    aper = SkyCircularAperture(skycoord, r=0.1*u.arcsec)
+    skycoord = wcs.pixel_to_world(90, 60)
+    aper = SkyCircularAperture(skycoord, r=0.1 * u.arcsec)
     tbl = aperture_photometry(data, aper, wcs=wcs)
     assert isinstance(tbl['sky_center'], SkyCoord)
 
@@ -858,16 +844,11 @@ def test_nddata_input():
     mask[8:13, 8:13] = True
     unit = 'adu'
     wcs = make_wcs(data.shape)
-    try:
-        skycoord = wcs.pixel_to_world(10, 10)
-    except AttributeError:
-        # for Astropy < 3.1
-        skycoord = pixel_to_skycoord(10, 10, wcs)
+    skycoord = wcs.pixel_to_world(10, 10)
+    aper = SkyCircularAperture(skycoord, r=0.7 * u.arcsec)
 
-    aper = SkyCircularAperture(skycoord, r=0.7*u.arcsec)
-
-    tbl1 = aperture_photometry(data*u.adu, aper, error=error*u.adu, mask=mask,
-                               wcs=wcs)
+    tbl1 = aperture_photometry(data * u.adu, aper, error=error * u.adu,
+                               mask=mask, wcs=wcs)
 
     uncertainty = StdDevUncertainty(error)
     nddata = NDData(data, uncertainty=uncertainty, mask=mask, wcs=wcs,
