@@ -10,15 +10,15 @@ from astropy.nddata import NDData
 from astropy.stats import SigmaClip
 import astropy.units as u
 from astropy.utils import lazyproperty
-from astropy.utils.decorators import deprecated
 from astropy.utils.exceptions import AstropyUserWarning
 import numpy as np
 from numpy.lib.index_tricks import index_exp
 
 from .core import SExtractorBackground, StdBackgroundRMS
 from .interpolators import BkgZoomInterpolator
-from ._utils import nanmedian
 from ..utils import ShepardIDWInterpolator
+from ..utils._parameters import as_pair
+from ..utils._stats import nanmedian
 
 __all__ = ['Background2D']
 
@@ -46,13 +46,13 @@ class Background2D:
         background RMS map.
 
     box_size : int or array_like (int)
-        The box size along each axis.  If ``box_size`` is a scalar then
-        a square box of size ``box_size`` will be used.  If ``box_size``
-        has two elements, they should be in ``(ny, nx)`` order.  For
-        best results, the box shape should be chosen such that the
-        ``data`` are covered by an integer number of boxes in both
-        dimensions.  When this is not the case, see the ``edge_method``
-        keyword for more options.
+        The box size along each axis. If ``box_size`` is a scalar then
+        a square box of size ``box_size`` will be used. If ``box_size``
+        has two elements, they must be in ``(ny, nx)`` order. For best
+        results, the box shape should be chosen such that the ``data``
+        are covered by an integer number of boxes in both dimensions.
+        When this is not the case, see the ``edge_method`` keyword for
+        more options.
 
     mask : array_like (bool), optional
         A boolean mask, with the same shape as ``data``, where a `True`
@@ -94,11 +94,11 @@ class Background2D:
 
     filter_size : int or array_like (int), optional
         The window size of the 2D median filter to apply to the
-        low-resolution background map.  If ``filter_size`` is a scalar
-        then a square box of size ``filter_size`` will be used.  If
-        ``filter_size`` has two elements, they should be in ``(ny, nx)``
-        order.  A filter size of ``1`` (or ``(1, 1)``) means no
-        filtering.
+        low-resolution background map. If ``filter_size`` is a scalar
+        then a square box of size ``filter_size`` will be used. If
+        ``filter_size`` has two elements, they must be in ``(ny, nx)``
+        order. ``filter_size`` must be odd along both axes. A filter
+        size of ``1`` (or ``(1, 1)``) means no filtering.
 
     filter_threshold : int, optional
         The threshold value for used for selective median filtering of
@@ -109,9 +109,10 @@ class Background2D:
 
     edge_method : {'pad', 'crop'}, optional
         The method used to determine how to handle the case where the
-        image size is not an integer multiple of the ``box_size`` in
-        either dimension.  Both options will resize the image to give an
-        exact multiple of ``box_size`` in both dimensions.
+        image size is not an integer multiple of the ``box_size``
+        in either dimension. Both options will resize the image for
+        internal calculations to give an exact multiple of ``box_size``
+        in both dimensions.
 
         * ``'pad'``: pad the image along the top and/or right edges.
           This is the default and recommended method. Ideally, the
@@ -197,17 +198,17 @@ class Background2D:
                                                   'coverage_mask')
         self.total_mask = self._combine_masks()
 
-        box_size = self._process_size_input(box_size)
         # box_size cannot be larger than the data array size
-        self.box_size = np.array((min(box_size[0], data.shape[0]),
-                                  min(box_size[1], data.shape[1])))
+        self.box_size = as_pair('box_size', box_size, lower_bound=(0, 1),
+                                upper_bound=data.shape)
 
         self.fill_value = fill_value
         if exclude_percentile < 0 or exclude_percentile > 100:
             raise ValueError('exclude_percentile must be between 0 and 100 '
                              '(inclusive).')
         self.exclude_percentile = exclude_percentile
-        self.filter_size = self._process_size_input(filter_size)
+        self.filter_size = as_pair('filter_size', filter_size,
+                                   lower_bound=(0, 1), check_odd=True)
         self.filter_threshold = filter_threshold
         self.edge_method = edge_method
         self.sigma_clip = sigma_clip
@@ -228,16 +229,6 @@ class Background2D:
 
         self._prepare_box_data()
 
-    @staticmethod
-    def _process_size_input(array):
-        array = np.atleast_1d(array).astype(int)
-        if len(array) == 1:
-            array = np.repeat(array, 2)
-        if len(array) != 2:
-            raise ValueError('box_size and filter_size inputs must have only '
-                             '1 or 2 elements')
-        return array
-
     def _validate_array(self, array, name, shape=True):
         if name in ('mask', 'coverage_mask') and array is np.ma.nomask:
             array = None
@@ -305,7 +296,9 @@ class Background2D:
         if np.sum(extra_size) != 0:
             # pad or crop the data
             if self.edge_method == 'pad':
-                pad_size = self.box_size - extra_size
+                pad_size = (np.ceil(self.data.shape
+                                    / self.box_size).astype(int)
+                            * self.box_size) - self.data.shape
                 pad_width = ((0, pad_size[0]), (0, pad_size[1]))
                 data = np.pad(self.data, pad_width, mode='constant',
                               constant_values=np.nan)
@@ -362,13 +355,13 @@ class Background2D:
         box_idx = np.where(nmasked <= self._box_npixels_threshold)[0]
 
         if box_idx.size == 0:
-            raise ValueError('All boxes contain > {0} ({1} percent per '
+            raise ValueError('All boxes contain > '
+                             f'{self._box_npixels_threshold} '
+                             f'({self.exclude_percentile} percent per '
                              'box) masked pixels (or all are completely '
                              'masked). Please check your data or increase '
                              '"exclude_percentile" to allow more boxes to '
-                             'be included.'
-                             .format(self._box_npixels_threshold,
-                                     self.exclude_percentile))
+                             'be included.')
 
         return box_idx
 
@@ -596,16 +589,6 @@ class Background2D:
         data[self._mesh_idx] = self.background_rms_mesh[self._mesh_idx]
         return data
 
-    @lazyproperty
-    @deprecated('1.2', alternative='background_mesh_masked')
-    def background_mesh_ma(self):
-        return self.background_mesh_masked  # pragma: no cover
-
-    @lazyproperty
-    @deprecated('1.2', alternative='background_rms_mesh_masked')
-    def background_rms_mesh_ma(self):
-        return self.background_rms_mesh_masked  # pragma: no cover
-
     @lazyproperty
     def _mesh_yxpos(self):
         box_cen = (self.box_size - 1) / 2.
@@ -671,7 +654,7 @@ class Background2D:
         return bkg_rms
 
     def plot_meshes(self, *, axes=None, marker='+', markersize=None,
-                    color='blue', outlines=False, **kwargs):
+                    color='blue', alpha=None, outlines=False, **kwargs):
         """
         Plot the low-resolution mesh boxes on a matplotlib Axes
         instance.
@@ -695,6 +678,11 @@ class Background2D:
             The color for the markers and the box outlines.  Default is
             'blue'.
 
+        alpha : float, optional
+            The alpha blending value, between 0 (transparent) and 1
+            (opaque). The blending applies to both the box center
+            markers and the outlines.
+
         outlines : bool, optional
             Whether or not to plot the box outlines in addition to the
             box centers.
@@ -709,11 +697,13 @@ class Background2D:
         kwargs['color'] = color
         if axes is None:
             axes = plt.gca()
+
         axes.scatter(*self._mesh_xypos, s=markersize, marker=marker,
-                     color=color)
+                     color=color, alpha=alpha)
+
         if outlines:
             from ..aperture import RectangularAperture
             xypos = np.column_stack(self._mesh_xypos)
             apers = RectangularAperture(xypos, self.box_size[1],
                                         self.box_size[0], 0.)
-            apers.plot(axes=axes, **kwargs)
+            apers.plot(axes=axes, alpha=alpha, **kwargs)
