@@ -6,7 +6,6 @@ Tests for the background_2d module.
 import itertools
 
 from astropy.nddata import NDData, CCDData
-from astropy.tests.helper import catch_warnings
 import astropy.units as u
 from astropy.utils.exceptions import AstropyUserWarning
 import numpy as np
@@ -116,6 +115,18 @@ class TestBackground2D:
         assert_allclose(bkg1.background, bkg2.background, rtol=2e-6)
         assert_allclose(bkg1.background_rms, bkg2.background_rms)
 
+        shape1 = (128, 256)
+        shape2 = (129, 256)
+        box_size = (16, 16)
+        data1 = np.ones(shape1)
+        data2 = np.ones(shape2)
+        bkg1 = Background2D(data1, box_size)
+        bkg2 = Background2D(data2, box_size)
+        assert bkg1.background_mesh.shape == (8, 16)
+        assert bkg2.background_mesh.shape == (9, 16)
+        assert bkg1.background.shape == shape1
+        assert bkg2.background.shape == shape2
+
     @pytest.mark.parametrize('box_size', ([(25, 25), (23, 22)]))
     def test_background_mask(self, box_size):
         """
@@ -163,7 +174,8 @@ class TestBackground2D:
         data[:50, :50] = np.nan
         mask = np.isnan(data)
 
-        with catch_warnings(AstropyUserWarning):
+        with pytest.warns(AstropyUserWarning,
+                          match='Input data contains invalid values'):
             bkg1 = Background2D(data, (25, 25), filter_size=(1, 1),
                                 coverage_mask=mask, fill_value=fill_value,
                                 bkg_estimator=MeanBackground())
@@ -175,16 +187,20 @@ class TestBackground2D:
         coverage_mask = np.zeros(DATA.shape, dtype=bool)
         mask[:50, :25] = True
         coverage_mask[:50, 25:50] = True
-        bkg2 = Background2D(data, (25, 25), filter_size=(1, 1), mask=mask,
-                            coverage_mask=mask, fill_value=0.0,
-                            bkg_estimator=MeanBackground())
+        with pytest.warns(AstropyUserWarning,
+                          match='Input data contains invalid values'):
+            bkg2 = Background2D(data, (25, 25), filter_size=(1, 1), mask=mask,
+                                coverage_mask=mask, fill_value=0.0,
+                                bkg_estimator=MeanBackground())
         assert_equal(bkg1.background_mesh, bkg2.background_mesh)
         assert_equal(bkg1.background_rms_mesh, bkg2.background_rms_mesh)
 
     def test_mask_nonfinite(self):
         data = DATA.copy()
         data[0, 0:50] = np.nan
-        bkg = Background2D(data, (25, 25), filter_size=(1, 1))
+        with pytest.warns(AstropyUserWarning,
+                          match='Input data contains invalid values'):
+            bkg = Background2D(data, (25, 25), filter_size=(1, 1))
         assert_allclose(bkg.background, DATA, rtol=1e-5)
 
     def test_masked_array(self):
@@ -218,8 +234,10 @@ class TestBackground2D:
         """Only meshes greater than filter_threshold are filtered."""
         data = np.copy(DATA)
         data[0:50, 0:50] = np.nan
-        bkg = Background2D(data, (25, 25), filter_size=(1, 1),
-                           exclude_percentile=100.)
+        with pytest.warns(AstropyUserWarning,
+                          match='Input data contains invalid values'):
+            bkg = Background2D(data, (25, 25), filter_size=(1, 1),
+                               exclude_percentile=100.)
         assert len(bkg._box_idx) == 12
 
     def test_filter_threshold(self):
@@ -327,3 +345,24 @@ class TestBackground2D:
         assert_allclose(bkg.background_median, 1.0)
         assert_allclose(bkg.background_rms_median, 0.0)
         assert_allclose(bkg.background_mesh.shape, (4, 5))
+
+
+@pytest.mark.skipif('not HAS_SCIPY')
+def test_bkgzoominterp_clip():
+    bkg = Background2D(np.ones((300, 300)), 100)
+    mesh = np.array([[0.01, 0.01, 0.02],
+                     [0.01, 0.02, 0.03],
+                     [0.03, 0.03, 12.9]])
+
+    interp1 = BkgZoomInterpolator(clip=False)
+    zoom1 = interp1(mesh, bkg)
+
+    interp2 = BkgZoomInterpolator(clip=True)
+    zoom2 = interp2(mesh, bkg)
+
+    minval = np.min(mesh)
+    maxval = np.max(mesh)
+    assert np.min(zoom1) < minval
+    assert np.max(zoom1) > maxval
+    assert np.min(zoom2) == minval
+    assert np.max(zoom2) == maxval
