@@ -7,16 +7,17 @@ import inspect
 import warnings
 
 from astropy.nddata.utils import overlap_slices
-from astropy.utils.decorators import deprecated
+from astropy.utils.decorators import deprecated_renamed_argument
 from astropy.utils.exceptions import AstropyUserWarning
 import numpy as np
 
 from ..utils._round import _py2intround
+from ..utils._parameters import as_pair
 
-__all__ = ['centroid_com', 'centroid_quadratic', 'centroid_sources',
-           'centroid_epsf']
+__all__ = ['centroid_com', 'centroid_quadratic', 'centroid_sources']
 
 
+@deprecated_renamed_argument('oversampling', None, '1.5')
 def centroid_com(data, mask=None, oversampling=1):
     """
     Calculate the centroid of an n-dimensional array as its "center of
@@ -34,11 +35,11 @@ def centroid_com(data, mask=None, oversampling=1):
         A boolean mask, with the same shape as ``data``, where a `True`
         value indicates the corresponding element of ``data`` is masked.
 
-    oversampling : int or tuple of two int, optional
-        Oversampling factors of pixel indices. If ``oversampling`` is
-        a scalar this is treated as both x and y directions having
-        the same oversampling factor; otherwise it is treated as
-        ``(x_oversamp, y_oversamp)``.
+    oversampling : int or array_like (int)
+        Deprecated.
+        The integer oversampling factor(s). If ``oversampling`` is a
+        scalar then it will be used for both axes. If ``oversampling``
+        has two elements, they must be in ``(y, x)`` order.
 
     Returns
     -------
@@ -54,12 +55,7 @@ def centroid_com(data, mask=None, oversampling=1):
             raise ValueError('data and mask must have the same shape.')
         data[mask] = 0.
 
-    oversampling = np.atleast_1d(oversampling)
-    if len(oversampling) == 1:
-        oversampling = np.repeat(oversampling, 2)
-    oversampling = oversampling[::-1]  # reverse to (y, x) order
-    if np.any(oversampling <= 0):
-        raise ValueError('Oversampling factors must all be positive numbers.')
+    oversampling = as_pair('oversampling', oversampling, lower_bound=(0, 1))
 
     badmask = ~np.isfinite(data)
     if np.any(badmask):
@@ -69,7 +65,10 @@ def centroid_com(data, mask=None, oversampling=1):
         data[badmask] = 0.
 
     total = np.sum(data)
-    indices = np.ogrid[[slice(0, i) for i in data.shape]]
+    if total == 0:
+        return np.array((np.nan, np.nan))
+
+    indices = np.ogrid[tuple(slice(0, i) for i in data.shape)]
 
     # note the output array is reversed to give (x, y) order
     return np.array([np.sum(indices[axis] * data) / total / oversampling[axis]
@@ -113,18 +112,20 @@ def centroid_quadratic(data, xpeak=None, ypeak=None, fit_boxsize=5,
 
     fit_boxsize : int or tuple of int, optional
         The size (in pixels) of the box used to define the fitting
-        region. If ``fit_boxsize`` has two elements, they should be in
+        region. If ``fit_boxsize`` has two elements, they must be in
         ``(ny, nx)`` order. If ``fit_boxsize`` is a scalar then a square
-        box of size ``fit_boxsize`` will be used.
+        box of size ``fit_boxsize`` will be used. ``fit_boxsize`` must
+        have odd values for both axes.
 
     search_boxsize : int or tuple of int, optional
         The size (in pixels) of the box used to search for the maximum
         pixel value if ``xpeak`` and ``ypeak`` are both specified. If
-        ``fit_boxsize`` has two elements, they should be in ``(ny,
-        nx)`` order. If ``fit_boxsize`` is a scalar then a square box
-        of size ``fit_boxsize`` will be used. This parameter is ignored
+        ``fit_boxsize`` has two elements, they must be in ``(ny,
+        nx)`` order. If ``search_boxsize`` is a scalar then a square
+        box of size ``search_boxsize`` will be used. ``search_boxsize``
+        must have odd values for both axes. This parameter is ignored
         if either ``xpeak`` or ``ypeak`` is `None`. In that case, the
-        entire array is search for the maximum value.
+        entire array is searched for the maximum value.
 
     mask : bool `~numpy.ndarray`, optional
         A boolean mask, with the same shape as ``data``, where a `True`
@@ -156,7 +157,7 @@ def centroid_quadratic(data, xpeak=None, ypeak=None, fit_boxsize=5,
     if ypeak is not None and ((ypeak < 0) or (ypeak > data.shape[0] - 1)):
         raise ValueError('ypeak is outside of the input data')
 
-    data = np.asanyarray(data, dtype=float)
+    data = np.asanyarray(data, dtype=float).copy()
     ny, nx = data.shape
 
     badmask = ~np.isfinite(data)
@@ -171,7 +172,8 @@ def centroid_quadratic(data, xpeak=None, ypeak=None, fit_boxsize=5,
             raise ValueError('data and mask must have the same shape.')
         data[mask] = np.nan
 
-    fit_boxsize = _process_boxsize(fit_boxsize, data.shape)
+    fit_boxsize = as_pair('fit_boxsize', fit_boxsize, lower_bound=(0, 1),
+                          upper_bound=data.shape, check_odd=True)
 
     if np.product(fit_boxsize) < 6:
         raise ValueError('fit_boxsize is too small.  6 values are required '
@@ -184,7 +186,9 @@ def centroid_quadratic(data, xpeak=None, ypeak=None, fit_boxsize=5,
         yidx = _py2intround(ypeak)
 
         if search_boxsize is not None:
-            search_boxsize = _process_boxsize(search_boxsize, data.shape)
+            search_boxsize = as_pair('search_boxsize', search_boxsize,
+                                     lower_bound=(0, 1),
+                                     upper_bound=data.shape, check_odd=True)
 
             slc_data, _ = overlap_slices(data.shape, search_boxsize,
                                          (yidx, xidx), mode='trim')
@@ -259,20 +263,6 @@ def centroid_quadratic(data, xpeak=None, ypeak=None, fit_boxsize=5,
     return xycen
 
 
-def _process_boxsize(box_size, data_shape):
-    box_size = np.round(np.atleast_1d(box_size)).astype(int)
-    if len(box_size) == 1:
-        box_size = np.repeat(box_size, 2)
-    if len(box_size) > 2:
-        raise ValueError('box size must contain only 1 or 2 values')
-    if np.any(box_size < 0):
-        raise ValueError('box size must be >= 0')
-    # box_size cannot be larger than the data shape
-    box_size = (min(box_size[0], data_shape[0]),
-                min(box_size[1], data_shape[1]))
-    return box_size
-
-
 def centroid_sources(data, xpos, ypos, box_size=11, footprint=None, mask=None,
                      centroid_func=centroid_com, **kwargs):
     """
@@ -294,14 +284,14 @@ def centroid_sources(data, xpos, ypos, box_size=11, footprint=None, mask=None,
         calculate the centroid.
 
     box_size : int or array-like of int, optional
-        The size of the cutout image along each axis. If ``box_size``
-        is a number, then a square cutout of ``box_size`` will be
-        created. If ``box_size`` has two elements, they should be in
-        ``(ny, nx)`` order. Either ``box_size`` or ``footprint`` must be
-        defined. If they are both defined, then ``footprint`` overrides
-        ``box_size``.
+        The size of the cutout image along each axis. If ``box_size`` is
+        a number, then a square cutout of ``box_size`` will be created.
+        If ``box_size`` has two elements, they must be in ``(ny, nx)``
+        order. ``box_size`` must have odd values for both axes. Either
+        ``box_size`` or ``footprint`` must be defined. If they are both
+        defined, then ``footprint`` overrides ``box_size``.
 
-    footprint : `~numpy.ndarray` of bools, optional
+    footprint : bool `~numpy.ndarray`, optional
         A 2D boolean array where `True` values describe the local
         footprint region to cutout. ``footprint`` can be used to create
         a non-rectangular cutout image, in which case the input ``xpos``
@@ -358,28 +348,23 @@ def centroid_sources(data, xpos, ypos, box_size=11, footprint=None, mask=None,
     if footprint is None:
         if box_size is None:
             raise ValueError('box_size or footprint must be defined.')
-
-        box_size = np.atleast_1d(box_size)
-        if len(box_size) == 1:
-            box_size = np.repeat(box_size, 2)
-        if len(box_size) != 2:
-            raise ValueError('box_size must have 1 or 2 elements.')
-
+        box_size = as_pair('box_size', box_size, lower_bound=(0, 1),
+                           check_odd=True)
         footprint = np.ones(box_size, dtype=bool)
     else:
         footprint = np.asanyarray(footprint, dtype=bool)
         if footprint.ndim != 2:
             raise ValueError('footprint must be a 2D array.')
 
-    spec = inspect.getfullargspec(centroid_func)
-    if 'mask' not in spec.args:
+    spec = inspect.signature(centroid_func)
+    if 'mask' not in spec.parameters:
         raise ValueError('The input "centroid_func" must have a "mask" '
                          'keyword.')
 
     # drop any **kwargs not supported by the centroid_func
     centroid_kwargs = {}
     for key, val in kwargs.items():
-        if key in spec.args:
+        if key in spec.parameters:
             centroid_kwargs[key] = val
 
     xcentroids = []
@@ -401,13 +386,17 @@ def centroid_sources(data, xpos, ypos, box_size=11, footprint=None, mask=None,
 
         centroid_kwargs.update({'mask': mask_cutout})
 
-        if 'error' in centroid_kwargs:
-            error_cutout = centroid_kwargs['error'][slices_large]
-            centroid_kwargs['error'] = error_cutout
+        error = centroid_kwargs.get('error', None)
+        if error is not None:
+            centroid_kwargs['error'] = error[slices_large]
 
-        if 'xpeak' in centroid_kwargs and 'ypeak' in centroid_kwargs:
-            centroid_kwargs['xpeak'] -= slices_large[1].start
-            centroid_kwargs['ypeak'] -= slices_large[0].start
+        # remove xpeak and ypeak from the dict and add back only if both
+        # are specified and not None
+        xpeak = centroid_kwargs.pop('xpeak', None)
+        ypeak = centroid_kwargs.pop('ypeak', None)
+        if xpeak is not None and ypeak is not None:
+            centroid_kwargs['xpeak'] = xpeak - slices_large[1].start
+            centroid_kwargs['ypeak'] = ypeak - slices_large[0].start
 
         try:
             xcen, ycen = centroid_func(data_cutout, **centroid_kwargs)
@@ -418,113 +407,3 @@ def centroid_sources(data, xpos, ypos, box_size=11, footprint=None, mask=None,
         ycentroids.append(ycen + slices_large[0].start)
 
     return np.array(xcentroids), np.array(ycentroids)
-
-
-@deprecated('1.2')
-def centroid_epsf(data, mask=None, oversampling=4, shift_val=0.5):
-    """
-    Calculate centering shift of data using pixel symmetry, as described
-    by Anderson and King (2000; PASP 112, 1360) in their ePSF-fitting
-    algorithm.
-
-    Calculate the shift of a 2-dimensional symmetric image based on the
-    asymmetry between f(x, N) and f(x, -N), along with the differential
-    df/dy(x, shift_val) and df/dy(x, -shift_val). Non-finite values
-    (e.g., NaN or inf) in the ``data`` array are automatically masked.
-
-    Parameters
-    ----------
-    data : array_like
-        The input n-dimensional array.
-
-    mask : array_like (bool), optional
-        A boolean mask, with the same shape as ``data``, where a `True`
-        value indicates the corresponding element of ``data`` is masked.
-
-    oversampling : int or tuple of two int, optional
-        Oversampling factors of pixel indices. If ``oversampling`` is a
-        scalar this is treated as both x and y directions having the
-        same oversampling factor.  Otherwise it is treated as
-        ``(x_oversamp, y_oversamp)``.
-
-    shift_val : float, optional
-        The undersampled value at which to compute the shifts. Default
-        is half a pixel. It must be a strictly positive number.
-
-    Returns
-    -------
-    centroid : tuple of floats
-        The (x, y) coordinates of the centroid in pixel order.
-    """
-    data = data.astype(float)
-
-    if mask is not None and mask is not np.ma.nomask:
-        mask = np.asarray(mask, dtype=bool)
-        if data.shape != mask.shape:
-            raise ValueError('data and mask must have the same shape.')
-        data[mask] = 0.
-
-    oversampling = np.atleast_1d(oversampling)
-    if len(oversampling) == 1:
-        oversampling = np.repeat(oversampling, 2)
-    if np.any(oversampling <= 0):
-        raise ValueError('Oversampling factors must all be positive numbers.')
-
-    if shift_val <= 0:
-        raise ValueError('shift_val must be a positive number.')
-
-    # Assume the center of the ePSF is the middle of an odd-sized grid.
-    xidx_0 = int((data.shape[1] - 1) / 2)
-    x_0 = np.arange(data.shape[1], dtype=float)[xidx_0] / oversampling[0]
-    yidx_0 = int((data.shape[0] - 1) / 2)
-    y_0 = np.arange(data.shape[0], dtype=float)[yidx_0] / oversampling[1]
-
-    x_shiftidx = np.around((shift_val * oversampling[0])).astype(int)
-    y_shiftidx = np.around((shift_val * oversampling[1])).astype(int)
-
-    badmask = ~np.isfinite([data[y, x]
-                            for x in [xidx_0, xidx_0 + x_shiftidx,
-                                      xidx_0 + x_shiftidx - 1,
-                                      xidx_0 + x_shiftidx + 1]
-                            for y in [yidx_0, yidx_0 + y_shiftidx,
-                                      yidx_0 + y_shiftidx - 1,
-                                      yidx_0 + y_shiftidx + 1]])
-
-    if np.any(badmask):
-        raise ValueError('One or more centroiding pixels is set to a '
-                         'non-finite value, e.g., NaN or inf.')
-
-    # In Anderson & King (2000) notation this is psi_E(0.5, 0.0) and
-    # values used to compute derivatives.
-    psi_pos_x = data[yidx_0, xidx_0 + x_shiftidx]
-    psi_pos_x_m1 = data[yidx_0, xidx_0 + x_shiftidx - 1]
-    psi_pos_x_p1 = data[yidx_0, xidx_0 + x_shiftidx + 1]
-
-    # Our derivatives are simple differences across two data points, but
-    # this must be in units of the undersampled grid, so 2 pixels becomes
-    # 2/oversampling pixels
-    dpsi_pos_x = np.abs(psi_pos_x_p1 - psi_pos_x_m1) / (2. / oversampling[0])
-
-    # psi_E(-0.5, 0.0) and derivative components.
-    psi_neg_x = data[yidx_0, xidx_0 - x_shiftidx]
-    psi_neg_x_m1 = data[yidx_0, xidx_0 - x_shiftidx - 1]
-    psi_neg_x_p1 = data[yidx_0, xidx_0 - x_shiftidx + 1]
-    dpsi_neg_x = np.abs(psi_neg_x_p1 - psi_neg_x_m1) / (2. / oversampling[0])
-
-    x_shift = (psi_pos_x - psi_neg_x) / (dpsi_pos_x + dpsi_neg_x)
-
-    # psi_E(0.0, 0.5) and derivatives.
-    psi_pos_y = data[yidx_0 + y_shiftidx, xidx_0]
-    psi_pos_y_m1 = data[yidx_0 + y_shiftidx - 1, xidx_0]
-    psi_pos_y_p1 = data[yidx_0 + y_shiftidx + 1, xidx_0]
-    dpsi_pos_y = np.abs(psi_pos_y_p1 - psi_pos_y_m1) / (2. / oversampling[1])
-
-    # psi_E(0.0, -0.5) and derivative components.
-    psi_neg_y = data[yidx_0 - y_shiftidx, xidx_0]
-    psi_neg_y_m1 = data[yidx_0 - y_shiftidx - 1, xidx_0]
-    psi_neg_y_p1 = data[yidx_0 - y_shiftidx + 1, xidx_0]
-    dpsi_neg_y = np.abs(psi_neg_y_p1 - psi_neg_y_m1) / (2. / oversampling[1])
-
-    y_shift = (psi_pos_y - psi_neg_y) / (dpsi_pos_y + dpsi_neg_y)
-
-    return x_0 + x_shift, y_0 + y_shift
