@@ -7,11 +7,10 @@ import warnings
 
 from astropy.modeling.fitting import LevMarLSQFitter
 from astropy.modeling.models import Const1D, Const2D, Gaussian1D, Gaussian2D
-from astropy.utils.decorators import deprecated
 from astropy.utils.exceptions import AstropyUserWarning
 import numpy as np
 
-__all__ = ['centroid_1dg', 'gaussian1d_moments', 'centroid_2dg']
+__all__ = ['centroid_1dg', 'centroid_2dg']
 
 
 def centroid_1dg(data, error=None, mask=None):
@@ -132,31 +131,6 @@ def _gaussian1d_moments(data, mask=None):
     return amplitude, x_mean, x_stddev
 
 
-@deprecated('1.2')
-def gaussian1d_moments(data, mask=None):
-    """
-    Estimate 1D Gaussian parameters from the moments of 1D data.
-
-    This function can be useful for providing initial parameter values
-    when fitting a 1D Gaussian to the ``data``.
-
-    Parameters
-    ----------
-    data : array_like (1D)
-        The 1D array.
-
-    mask : array_like (1D bool), optional
-        A boolean mask, with the same shape as ``data``, where a `True`
-        value indicates the corresponding element of ``data`` is masked.
-
-    Returns
-    -------
-    amplitude, mean, stddev : float
-        The estimated parameters of a 1D Gaussian.
-    """
-    return _gaussian1d_moments(data, mask=mask)  # pragma: no cover
-
-
 def centroid_2dg(data, error=None, mask=None):
     """
     Calculate the centroid of a 2D array by fitting a 2D Gaussian (plus
