@@ -4,7 +4,7 @@ Tests for the core module.
 """
 
 import itertools
-import warnings
+from contextlib import nullcontext
 
 from astropy.modeling.models import Gaussian2D
 from astropy.utils.exceptions import (AstropyUserWarning,
@@ -13,10 +13,8 @@ import numpy as np
 from numpy.testing import assert_allclose
 import pytest
 
-from ..core import (centroid_com, centroid_quadratic, centroid_sources,
-                    centroid_epsf)
+from ..core import centroid_com, centroid_quadratic, centroid_sources
 from ..gaussian import centroid_1dg, centroid_2dg
-from ...psf import IntegratedGaussianPRF
 from ...utils._optional_deps import HAS_SCIPY  # noqa
 
 
@@ -61,15 +59,16 @@ def test_centroid_com(x_std, y_std, theta):
     assert_allclose((xc, yc), (XCEN, YCEN), rtol=0, atol=0.015)
 
     # test with oversampling
-    for oversampling in [4, (4, 6)]:
-        if not hasattr(oversampling, '__len__'):
-            _oversampling = (oversampling, oversampling)
-        else:
-            _oversampling = oversampling
-        xc, yc = centroid_com(data, mask=mask, oversampling=oversampling)
+    with pytest.warns(AstropyDeprecationWarning):
+        for oversampling in [4, (6, 4)]:
+            if not hasattr(oversampling, '__len__'):
+                _oversampling = (oversampling, oversampling)
+            else:
+                _oversampling = oversampling
+            xc, yc = centroid_com(data, mask=mask, oversampling=oversampling)
 
-        desired = [XCEN / _oversampling[0], YCEN / _oversampling[1]]
-        assert_allclose((xc, yc), desired, rtol=0, atol=1.e-3)
+            desired = [XCEN / _oversampling[1], YCEN / _oversampling[0]]
+            assert_allclose((xc, yc), desired, rtol=0, atol=1.e-3)
 
 
 @pytest.mark.skipif('not HAS_SCIPY')
@@ -85,24 +84,26 @@ def test_centroid_com_nan_withmask(use_mask):
         mask = np.zeros(data.shape, dtype=bool)
         mask[20, :] = True
         nwarn = 0
+        ctx = nullcontext()
     else:
         mask = None
         nwarn = 1
+        ctx = pytest.warns(AstropyUserWarning,
+                           match='Input data contains non-finite values')
 
-    with warnings.catch_warnings(record=True) as warnlist:
+    with ctx as warnlist:
         xc, yc = centroid_com(data, mask=mask)
         assert_allclose(xc, xc_ref, rtol=0, atol=1.e-3)
         assert yc > yc_ref
-    assert len(warnlist) == nwarn
-    if nwarn == 1:
-        assert issubclass(warnlist[0].category, AstropyUserWarning)
+        if nwarn == 1:
+            assert len(warnlist) == nwarn
 
-    with warnings.catch_warnings(record=True) as warnlist:
+    ctx = pytest.warns(AstropyUserWarning,
+                       match='Input data contains non-finite values')
+    with ctx as warnlist:
         xc, yc = centroid_quadratic(data, mask=mask)
         assert_allclose(xc, xc_ref, rtol=0, atol=0.15)
-    assert len(warnlist) == 1  # always warns because of NaN
-    if nwarn == 1:
-        assert issubclass(warnlist[0].category, AstropyUserWarning)
+        assert len(warnlist) == 1
 
 
 @pytest.mark.skipif('not HAS_SCIPY')
@@ -111,7 +112,7 @@ def test_centroid_com_invalid_inputs():
     mask = np.zeros((2, 2), dtype=bool)
     with pytest.raises(ValueError):
         centroid_com(data, mask=mask)
-    with pytest.raises(ValueError):
+    with pytest.warns(AstropyDeprecationWarning), pytest.raises(ValueError):
         centroid_com(data, oversampling=-1)
 
 
@@ -147,9 +148,9 @@ def test_centroid_quadratic_npts():
     mask = np.zeros(data.shape, dtype=bool)
     mask[0, :] = True
     mask[2, :] = True
-    with warnings.catch_warnings(record=True) as warnlist:
+    with pytest.warns(AstropyUserWarning,
+                      match='at least 6 unmasked data points'):
         centroid_quadratic(data, mask=mask)
-    assert issubclass(warnlist[0].category, AstropyUserWarning)
 
 
 @pytest.mark.skipif('not HAS_SCIPY')
@@ -184,10 +185,10 @@ def test_centroid_quadratic_edge():
 
     data = np.zeros((5, 5))
     data[0, 0] = 100
-    with warnings.catch_warnings(record=True) as warnlist:
+    with pytest.warns(AstropyUserWarning,
+                      match='maximum value is at the edge'):
         xycen = centroid_quadratic(data)
     assert_allclose(xycen, (0, 0))
-    assert issubclass(warnlist[0].category, AstropyUserWarning)
 
 
 @pytest.mark.skipif('not HAS_SCIPY')
@@ -240,7 +241,7 @@ class TestCentroidSources:
             centroid_sources(data, 25, 26, footprint=np.ones((3, 3, 3)))
 
         def test_func(data):
-            return 1
+            return data
         with pytest.raises(ValueError):
             centroid_sources(data, [25], 26, centroid_func=test_func)
 
@@ -276,8 +277,8 @@ class TestCentroidSources:
         assert_allclose(xcen, xres)
         assert_allclose(ycen, yres)
 
-    @staticmethod
-    def test_centroid_quadratic_kwargs():
+    @pytest.mark.filterwarnings(r'ignore:.*no quadratic fit was performed')
+    def test_centroid_quadratic_kwargs(self):
         data = np.zeros((11, 11))
         data[5, 5] = 100
         data[7, 7] = 110
@@ -308,61 +309,58 @@ class TestCentroidSources:
                                   fit_boxsize=5)
         assert_allclose(xycen5, ([7], [7]))
 
+    def test_centroid_quadratic_mask(self):
+        """
+        Regression test to check that when a mask is input the original
+        data is not alterned.
+        """
+        xc_ref = 24.7
+        yc_ref = 25.2
+        model = Gaussian2D(2.4, xc_ref, yc_ref, x_stddev=5.0, y_stddev=5.0)
+        y, x = np.mgrid[0:51, 0:51]
+        data = model(x, y)
+        mask = data < 1
+        xycen = centroid_quadratic(data, mask=mask)
+        assert ~np.any(np.isnan(data))
+        assert_allclose(xycen, (xc_ref, yc_ref), atol=0.01)
+
     def test_mask(self):
-        mask = np.ones(self.data.shape, dtype=bool)
         xcen1, ycen1 = centroid_sources(self.data, 25, 23, box_size=(55, 55))
-        xcen2, ycen2 = centroid_sources(self.data, 25, 23, box_size=(55, 55),
-                                        mask=mask)
+
+        mask = np.zeros(self.data.shape, dtype=bool)
+        mask[0, 0] = True
+        mask[24, 24] = True
+        mask[11, 24] = True
+        xcen2, ycen2 = centroid_sources(self.data, 25, 23,
+                                        box_size=(55, 55), mask=mask)
         assert not np.allclose(xcen1, xcen2)
         assert not np.allclose(ycen1, ycen2)
 
+        # mask all data values
+        mask = np.ones(self.data.shape, dtype=bool)
+        xcen3, ycen3 = centroid_sources(self.data, 25, 23,
+                                        box_size=(55, 55), mask=mask)
+        assert np.isnan(xcen3[0])
+        assert np.isnan(ycen3[0])
 
-@pytest.mark.skipif('not HAS_SCIPY')
-@pytest.mark.parametrize('oversampling', (4, (4, 6)))
-def test_centroid_epsf(oversampling):
-    sigma = 0.5
-    psf = IntegratedGaussianPRF(sigma=sigma)
-    offsets = np.array((0.1, 0.03))
+    def test_error_none(self):
+        xycen1 = centroid_sources(self.data, xpos=25, ypos=25, error=None,
+                                  centroid_func=centroid_1dg)
+        xycen2 = centroid_sources(self.data, xpos=25, ypos=25, error=None,
+                                  centroid_func=centroid_2dg)
+        assert_allclose(xycen1, ([25], [25]), atol=1.e-3)
+        assert_allclose(xycen2, ([25], [25]), atol=1.e-3)
 
-    if not hasattr(oversampling, '__len__'):
-        _oversampling = (oversampling, oversampling)
-    else:
-        _oversampling = oversampling
-
-    x = np.arange(1 + 25 * _oversampling[0]) / _oversampling[0]
-    y = np.arange(1 + 25 * _oversampling[1]) / _oversampling[1]
-    x0 = x[-1] / 2
-    y0 = y[-1] / 2
-    x -= x0
-    y -= y0
-
-    data = psf.evaluate(x=x.reshape(1, -1), y=y.reshape(-1, 1), flux=1.,
-                        x_0=offsets[0], y_0=offsets[1], sigma=sigma)
-
-    mask = np.zeros(data.shape, dtype=bool)
-    data[25, 25] = 1000.
-    mask[25, 25] = True
-    with pytest.warns(AstropyDeprecationWarning):
-        xc, yc = centroid_epsf(data, mask=mask, oversampling=oversampling)
-    desired = np.array((x0, y0)) + offsets
-    assert_allclose((xc, yc), desired, rtol=1e-3, atol=1e-2)
-
-
-def test_centroid_epsf_exceptions():
-    data = np.ones((5, 5), dtype=float)
-    mask = np.zeros((4, 5), dtype=int)
-    mask[2, 2] = 1
-
-    with pytest.warns(AstropyDeprecationWarning):
-        with pytest.raises(ValueError):
-            centroid_epsf(data, mask)
-        with pytest.raises(ValueError):
-            centroid_epsf(data, shift_val=-1)
-        with pytest.raises(ValueError):
-            centroid_epsf(data, oversampling=-1)
-
-    data = np.ones((21, 21), dtype=float)
-    data[10, 10] = np.inf
-    with pytest.warns(AstropyDeprecationWarning):
-        with pytest.raises(ValueError):
-            centroid_epsf(data)
+    def test_xypeaks_none(self):
+        xycen1 = centroid_sources(self.data, xpos=25, ypos=25, error=None,
+                                  xpeak=None, ypeak=25,
+                                  centroid_func=centroid_quadratic)
+        xycen2 = centroid_sources(self.data, xpos=25, ypos=25, error=None,
+                                  xpeak=25, ypeak=None,
+                                  centroid_func=centroid_quadratic)
+        xycen3 = centroid_sources(self.data, xpos=25, ypos=25, error=None,
+                                  xpeak=None, ypeak=None,
+                                  centroid_func=centroid_quadratic)
+        assert_allclose(xycen1, ([25], [25]), atol=1.e-3)
+        assert_allclose(xycen2, ([25], [25]), atol=1.e-3)
+        assert_allclose(xycen3, ([25], [25]), atol=1.e-3)
