@@ -3,10 +3,9 @@
 # get picked up when running the tests inside an interpreter using
 # packagename.test
 
-import os
-
 try:
-    from pytest_astropy_header.display import PYTEST_HEADER_MODULES, TESTED_VERSIONS
+    from pytest_astropy_header.display import (PYTEST_HEADER_MODULES,
+                                               TESTED_VERSIONS)
     ASTROPY_HEADER = True
 except ImportError:
     ASTROPY_HEADER = False
@@ -29,19 +28,5 @@ def pytest_configure(config):
         PYTEST_HEADER_MODULES.pop('Pandas', None)  # noqa
         PYTEST_HEADER_MODULES.pop('h5py', None)  # noqa
 
-        from . import __version__
-        packagename = os.path.basename(os.path.dirname(__file__))
-        TESTED_VERSIONS[packagename] = __version__
-
-# Uncomment the last two lines in this block to treat all DeprecationWarnings as
-# exceptions. For Astropy v2.0 or later, there are 2 additional keywords,
-# as follow (although default should work for most cases).
-# To ignore some packages that produce deprecation warnings on import
-# (in addition to 'compiler', 'scipy', 'pygments', 'ipykernel', and
-# 'setuptools'), add:
-#     modules_to_ignore_on_import=['module_1', 'module_2']
-# To ignore some specific deprecation warning messages for Python version
-# MAJOR.MINOR or later, add:
-#     warnings_to_ignore_by_pyver={(MAJOR, MINOR): ['Message to ignore']}
-from astropy.tests.helper import enable_deprecations_as_exceptions  # noqa
-enable_deprecations_as_exceptions()
+        from photutils import __version__
+        TESTED_VERSIONS['photutils'] = __version__
