@@ -115,36 +115,74 @@ class Isophote:
         self.valid = valid
         self.stop_code = stop_code
 
-        self.intens = sample.mean
-        self.rms = np.std(sample.values[2])
-        self.int_err = self.rms / np.sqrt(sample.actual_points)
-        self.pix_stddev = self.rms * np.sqrt(sample.sector_area)
-        self.grad = sample.gradient
-        self.grad_error = sample.gradient_error
+        if sample.geometry.sma > 0:
+            self.intens = sample.mean
+            self.rms = np.std(sample.values[2])
+            self.int_err = self.rms / np.sqrt(sample.actual_points)
+            self.pix_stddev = self.rms * np.sqrt(sample.sector_area)
+            self.grad = sample.gradient
+            self.grad_error = sample.gradient_error
 
-        self.grad_r_error = sample.gradient_relative_error
-        self.sarea = sample.sector_area
-        self.ndata = sample.actual_points
-        self.nflag = sample.total_points - sample.actual_points
+            self.grad_r_error = sample.gradient_relative_error
+            self.sarea = sample.sector_area
+            self.ndata = sample.actual_points
+            self.nflag = sample.total_points - sample.actual_points
 
-        # flux contained inside ellipse and circle
-        (self.tflux_e, self.tflux_c, self.npix_e,
-         self.npix_c) = self._compute_fluxes()
+            # flux contained inside ellipse and circle
+            (self.tflux_e, self.tflux_c, self.npix_e,
+             self.npix_c) = self._compute_fluxes()
 
-        self._compute_errors()
+            self._compute_errors()
 
-        # deviations from a perfect ellipse
-        (self.a3, self.b3, self.a3_err,
-         self.b3_err) = self._compute_deviations(sample, 3)
-        (self.a4, self.b4, self.a4_err,
-         self.b4_err) = self._compute_deviations(sample, 4)
+            # deviations from a perfect ellipse
+            (self.a3, self.b3, self.a3_err,
+             self.b3_err) = self._compute_deviations(sample, 3)
+            (self.a4, self.b4, self.a4_err,
+             self.b4_err) = self._compute_deviations(sample, 4)
 
     # This method is useful for sorting lists of instances. Note
     # that __lt__ is the python3 way of supporting sorting.
     def __lt__(self, other):
-        if hasattr(other, 'sma'):
+        try:
             return self.sma < other.sma
-        raise ValueError('Comparison object does not have a "sma" attribute.')
+        except AttributeError as err:
+            raise AttributeError('Comparison object does not have a "sma" '
+                                 'attribute.') from err
+
+    def __gt__(self, other):
+        try:
+            return self.sma > other.sma
+        except AttributeError as err:
+            raise AttributeError('Comparison object does not have a "sma" '
+                                 'attribute.') from err
+
+    def __le__(self, other):
+        try:
+            return self.sma <= other.sma
+        except AttributeError as err:
+            raise AttributeError('Comparison object does not have a "sma" '
+                                 'attribute.') from err
+
+    def __ge__(self, other):
+        try:
+            return self.sma >= other.sma
+        except AttributeError as err:
+            raise AttributeError('Comparison object does not have a "sma" '
+                                 'attribute.') from err
+
+    def __eq__(self, other):
+        try:
+            return self.sma == other.sma
+        except AttributeError as err:
+            raise AttributeError('Comparison object does not have a "sma" '
+                                 'attribute.') from err
+
+    def __ne__(self, other):
+        try:
+            return self.sma != other.sma
+        except AttributeError as err:
+            raise AttributeError('Comparison object does not have a "sma" '
+                                 'attribute.') from err
 
     def __str__(self):
         return str(self.to_table())
@@ -236,8 +274,8 @@ class Isophote:
             b = up_coeffs[2] / self.sma / sample.gradient
 
             def errfunc(x, phi, order, intensities):
-                return (x[0] + x[1] * np.sin(order * phi) +
-                        x[2] * np.cos(order * phi) - intensities)
+                return (x[0] + x[1] * np.sin(order * phi)
+                        + x[2] * np.cos(order * phi) - intensities)
 
             up_var_residual = np.std(errfunc(up_coeffs, self.sample.values[0],
                                              n, self.sample.values[2]),
@@ -285,11 +323,11 @@ class Isophote:
             eb = abs(errors[1] * (1. - eps) / self.grad)
             self.x0_err = np.sqrt((ea * np.cos(pa))**2 + (eb * np.sin(pa))**2)
             self.y0_err = np.sqrt((ea * np.sin(pa))**2 + (eb * np.cos(pa))**2)
-            self.ellip_err = (abs(2. * errors[4] * (1. - eps) / self.sma /
-                                  self.grad))
+            self.ellip_err = (abs(2. * errors[4] * (1. - eps) / self.sma
+                                  / self.grad))
             if abs(eps) > np.finfo(float).resolution:
-                self.pa_err = (abs(2. * errors[3] * (1. - eps) / self.sma /
-                                   self.grad / (1. - (1. - eps)**2)))
+                self.pa_err = (abs(2. * errors[3] * (1. - eps) / self.sma
+                                   / self.grad / (1. - (1. - eps)**2)))
             else:
                 self.pa_err = 0.
         except Exception:  # we want to catch everything
@@ -353,15 +391,12 @@ class CentralPixel(Isophote):
 
     Parameters
     ----------
-    sample : `~photutils.utils.EllipseSample` instance
+    sample : `~photutils.isophote.EllipseSample` instance
         The sample information.
     """
 
     def __init__(self, sample):
-        self.sample = sample
-        self.niter = 0
-        self.valid = True
-        self.stop_code = 0
+        super().__init__(sample, 0, True, 0)
 
         self.intens = sample.mean
 
@@ -389,6 +424,13 @@ class CentralPixel(Isophote):
         self.x0_err = 0.
         self.y0_err = 0.
 
+    def __eq__(self, other):
+        try:
+            return self.sma == other.sma
+        except AttributeError as err:
+            raise AttributeError('Comparison object does not have a "sma" '
+                                 'attribute.') from err
+
     @property
     def eps(self):
         return 0.
@@ -744,9 +786,9 @@ def _get_properties(isophote_list):
     Returns
     -------
     result : `dict`
-        An OrderedDict with the list of the isophote_list properties.
+        An dictionary with the list of the isophote_list properties.
     """
-    properties = dict()
+    properties = {}
     for an_item in isophote_list.__class__.__dict__:
         p_type = isophote_list.__class__.__dict__[an_item]
         # Exclude the sample property
@@ -785,11 +827,11 @@ def _isophote_list_to_table(isophote_list, columns='main'):
     # the isophote_list parameters
 
     def __rename_properties(properties,
-                            orig_names=['int_err', 'eps', 'ellip_err',
-                                        'grad_r_error', 'nflag'],
-                            new_names=['intens_err', 'ellipticity',
+                            orig_names=('int_err', 'eps', 'ellip_err',
+                                        'grad_r_error', 'nflag'),
+                            new_names=('intens_err', 'ellipticity',
                                        'ellipticity_err', 'grad_rerror',
-                                       'nflag']):
+                                       'nflag')):
         """
         Simple renaming for some of the isophote_list parameters.
 
