@@ -6,20 +6,22 @@ ISR WFC3 2016-12.
 """
 
 import copy
-import time
 import warnings
 
 from astropy.modeling.fitting import LevMarLSQFitter
 from astropy.nddata.utils import (overlap_slices, PartialOverlapError,
                                   NoOverlapError)
 from astropy.stats import SigmaClip
+from astropy.utils.decorators import deprecated_renamed_argument
 from astropy.utils.exceptions import AstropyUserWarning
 import numpy as np
 
 from .epsf_stars import EPSFStar, EPSFStars, LinkedEPSFStar
 from .models import EPSFModel
-from ..centroids import centroid_com, centroid_epsf
-from ..utils._optional_deps import HAS_BOTTLENECK  # noqa
+from .utils import _interpolate_missing_data
+from ..centroids import centroid_com
+from ..utils._optional_deps import HAS_BOTTLENECK, HAS_TQDM  # noqa
+from ..utils._parameters import as_pair
 from ..utils._round import _py2intround
 
 
@@ -37,13 +39,13 @@ class EPSFFitter:
 
     fit_boxsize : int, tuple of int, or `None`, optional
         The size (in pixels) of the box centered on the star to be used
-        for ePSF fitting.  This allows using only a small number of
+        for ePSF fitting. This allows using only a small number of
         central pixels of the star (i.e., where the star is brightest)
-        for fitting.  If ``fit_boxsize`` is a scalar then a square box
-        of size ``fit_boxsize`` will be used.  If ``fit_boxsize`` has
-        two elements, they should be in ``(ny, nx)`` order.  The size
-        must be greater than or equal to 3 pixels for both axes.  If
-        `None`, the fitter will use the entire star image.
+        for fitting. If ``fit_boxsize`` is a scalar then a square box of
+        size ``fit_boxsize`` will be used. If ``fit_boxsize`` has two
+        elements, they must be in ``(ny, nx)`` order. ``fit_boxsize``
+        must have odd values and be greater than or equal to 3 for both
+        axes. If `None`, the fitter will use the entire star image.
 
     fitter_kwargs : dict-like, optional
         Any additional keyword arguments (except ``x``, ``y``, ``z``, or
@@ -51,22 +53,13 @@ class EPSFFitter:
         of the input ``fitter``.
     """
 
-    def __init__(self, fitter=LevMarLSQFitter(), fit_boxsize=5,
+    def __init__(self, *, fitter=LevMarLSQFitter(), fit_boxsize=5,
                  **fitter_kwargs):
 
         self.fitter = fitter
         self.fitter_has_fit_info = hasattr(self.fitter, 'fit_info')
-
-        if fit_boxsize is not None:
-            fit_boxsize = np.atleast_1d(fit_boxsize).astype(int)
-            if len(fit_boxsize) == 1:
-                fit_boxsize = np.repeat(fit_boxsize, 2)
-
-            min_size = 3
-            if any([size < min_size for size in fit_boxsize]):
-                raise ValueError(f'size must be >= {min_size} for x and y')
-
-        self.fit_boxsize = fit_boxsize
+        self.fit_boxsize = as_pair('fit_boxsize', fit_boxsize,
+                                   lower_bound=(3, 0), check_odd=True)
 
         # remove any fitter keyword arguments that we need to set
         remove_kwargs = ['x', 'y', 'z', 'weights']
@@ -152,8 +145,8 @@ class EPSFFitter:
                                               (ycenter, xcenter),
                                               mode='strict')
             except (PartialOverlapError, NoOverlapError):
-                warnings.warn('The star at ({star.center[0]}, '
-                              '{star.center[1]}) cannot be fit because '
+                warnings.warn(f'The star at ({star.center[0]}, '
+                              f'{star.center[1]}) cannot be fit because '
                               'its fitting region extends beyond the star '
                               'cutout image.', AstropyUserWarning)
 
@@ -234,13 +227,11 @@ class EPSFBuilder:
 
     Parameters
     ----------
-    oversampling : int or tuple of two int, optional
-        The oversampling factor(s) of the ePSF relative to the input
-        ``stars`` along the x and y axes. The ``oversampling`` can
-        either be a single float or a tuple of two floats of the form
-        ``(x_oversamp, y_oversamp)``.  If ``oversampling`` is a scalar
-        then the oversampling will be the same for both the x and y
-        axes.
+    oversampling : int or array_like (int)
+        The integer oversampling factor(s) of the ePSF relative to the
+        input ``stars`` along each axis. If ``oversampling`` is a scalar
+        then it will be used for both axes. If ``oversampling`` has two
+        elements, they must be in ``(y, x)`` order.
 
     shape : float, tuple of two floats, or `None`, optional
         The shape of the output ePSF.  If the ``shape`` is not `None`,
@@ -270,29 +261,31 @@ class EPSFBuilder:
         each ePSF build iteration.
 
     fitter : `EPSFFitter` object, optional
-        A `EPSFFitter` object use to fit the ePSF to stars.  To set
-        fitter options, a new object with specific options should be
-        passed in - the default uses simply the default options.  To see
-        more of these options, see the `EPSFFitter` documentation.
+        A `EPSFFitter` object use to fit the ePSF to stars. To set
+        custom fitter options, input a new `EPSFFitter` object. See the
+        `EPSFFitter` documentation for options.
 
     maxiters : int, optional
         The maximum number of iterations to perform.
 
     progress_bar : bool, option
-        Whether to print the progress bar during the build iterations.
+        Whether to print the progress bar during the build
+        iterations. The progress bar requires that the `tqdm
+        <https://tqdm.github.io/>`_ optional dependency be installed.
+        Note that the progress bar does not currently work in the
+        Jupyter console due to limitations in ``tqdm``.
 
     norm_radius : float, optional
         The pixel radius over which the ePSF is normalized.
 
-    shift_val : float, optional
-        The undersampled value at which to compute the shifts.  It must
-        be a strictly positive number.
-
     recentering_boxsize : float or tuple of two floats, optional
-            The size (in pixels) of the box used to calculate the centroid
-            of the ePSF during each build iteration.  If a single integer
-            number is provided, then a square box will be used.  If two
-            values are provided, then they should be in ``(ny, nx)`` order.
+            The size (in pixels) of the box used to calculate the
+            centroid of the ePSF during each build iteration. If a
+            single integer number is provided, then a square box will
+            be used. If two values are provided, then they must be in
+            ``(ny, nx)`` order. ``recentering_boxsize`` must have odd
+            must have odd values and be greater than or equal to 3 for
+            both axes.
 
     center_accuracy : float, optional
             The desired accuracy for the centers of stars.  The building
@@ -300,11 +293,11 @@ class EPSFBuilder:
             less than ``center_accuracy`` pixels between iterations.  All
             stars must meet this condition for the loop to exit.
 
-    flux_residual_sigclip : `~astropy.stats.SigmaClip` object, optional
-        A `~astropy.stats.SigmaClip` object used to determine which pixels
-        are ignored based on the star sampling flux residuals, when
-        computing the average residual of ePSF grid points in each iteration
-        step.
+    sigma_clip : `astropy.stats.SigmaClip` instance, optional
+        A `~astropy.stats.SigmaClip` object that defines the sigma
+        clipping parameters used to determine which pixels are ignored
+        when stacking the ePSF residuals in each iteration step. If
+        `None` then no sigma clipping will be performed.
 
     Notes
     -----
@@ -314,33 +307,29 @@ class EPSFBuilder:
     .. _bottleneck:  https://github.com/pydata/bottleneck
     """
 
-    def __init__(self, oversampling=4., shape=None,
+    @deprecated_renamed_argument('flux_residual_sigclip', 'sigma_clip', '1.5')
+    def __init__(self, *, oversampling=4, shape=None,
                  smoothing_kernel='quartic', recentering_func=centroid_com,
                  recentering_maxiters=20, fitter=EPSFFitter(), maxiters=10,
-                 progress_bar=True, norm_radius=5.5, shift_val=0.5,
+                 progress_bar=True, norm_radius=5.5,
                  recentering_boxsize=(5, 5), center_accuracy=1.0e-3,
-                 flux_residual_sigclip=SigmaClip(sigma=3, cenfunc='median',
-                                                 maxiters=10)):
+                 sigma_clip=SigmaClip(sigma=3, cenfunc='median', maxiters=10)):
 
         if oversampling is None:
             raise ValueError("'oversampling' must be specified.")
-        oversampling = np.atleast_1d(oversampling).astype(int)
-        if len(oversampling) == 1:
-            oversampling = np.repeat(oversampling, 2)
-        if np.any(oversampling <= 0.0):
-            raise ValueError('oversampling must be a positive number.')
+        self.oversampling = as_pair('oversampling', oversampling,
+                                    lower_bound=(0, 1))
         self._norm_radius = norm_radius
-        self._shift_val = shift_val
-        self.oversampling = oversampling
-        self.shape = self._init_img_params(shape)
-        if self.shape is not None:
-            self.shape = self.shape.astype(int)
+        if shape is not None:
+            self.shape = as_pair('shape', shape, lower_bound=(0, 1))
+        else:
+            self.shape = shape
 
         self.recentering_func = recentering_func
         self.recentering_maxiters = recentering_maxiters
-        self.recentering_boxsize = self._init_img_params(recentering_boxsize)
-        self.recentering_boxsize = self.recentering_boxsize.astype(int)
-
+        self.recentering_boxsize = as_pair('recentering_boxsize',
+                                           recentering_boxsize,
+                                           lower_bound=(3, 0), check_odd=True)
         self.smoothing_kernel = smoothing_kernel
 
         if not isinstance(fitter, EPSFFitter):
@@ -358,10 +347,10 @@ class EPSFBuilder:
 
         self.progress_bar = progress_bar
 
-        if not isinstance(flux_residual_sigclip, SigmaClip):
-            raise ValueError("'flux_residual_sigclip' must be an"
-                             " astropy.stats.SigmaClip function.")
-        self.flux_residual_sigclip = flux_residual_sigclip
+        if not isinstance(sigma_clip, SigmaClip):
+            raise ValueError('sigma_clip must be an '
+                             'astropy.stats.SigmaClip instance.')
+        self._sigma_clip = sigma_clip
 
         # store each ePSF build iteration
         self._epsf = []
@@ -369,19 +358,6 @@ class EPSFBuilder:
     def __call__(self, stars):
         return self.build_epsf(stars)
 
-    @staticmethod
-    def _init_img_params(param):
-        """
-        Initialize 2D image-type parameters that can accept either a
-        single or two values.
-        """
-        if param is not None:
-            param = np.atleast_1d(param)
-            if len(param) == 1:
-                param = np.repeat(param, 2)
-
-        return param
-
     def _create_initial_epsf(self, stars):
         """
         Create an initial `EPSFModel` object.
@@ -390,9 +366,9 @@ class EPSFBuilder:
 
         If ``shape`` is not specified, the shape of the ePSF data array
         is determined from the shape of the input ``stars`` and the
-        oversampling factor.  If the size is even along any axis, it
-        will be made odd by adding one.  The output ePSF will always
-        have odd sizes along both axes to ensure a central pixel.
+        oversampling factor. If the size is even along any axis, it will
+        be made odd by adding one. The output ePSF will always have odd
+        sizes along both axes to ensure a central pixel.
 
         Parameters
         ----------
@@ -405,23 +381,20 @@ class EPSFBuilder:
             The initial ePSF model.
         """
         norm_radius = self._norm_radius
-        shift_val = self._shift_val
         oversampling = self.oversampling
         shape = self.shape
 
         # define the ePSF shape
         if shape is not None:
-            shape = np.atleast_1d(shape).astype(int)
-            if len(shape) == 1:
-                shape = np.repeat(shape, 2)
+            shape = as_pair('shape', shape, lower_bound=(0, 1), check_odd=True)
         else:
             # Stars class should have odd-sized dimensions, and thus we
             # get the oversampled shape as oversampling * len + 1; if
             # len=25, then newlen=101, for example.
-            x_shape = (np.ceil(stars._max_shape[0]) * oversampling[0] +
-                       1).astype(int)
-            y_shape = (np.ceil(stars._max_shape[1]) * oversampling[1] +
-                       1).astype(int)
+            x_shape = (np.ceil(stars._max_shape[0]) * oversampling[1]
+                       + 1).astype(int)
+            y_shape = (np.ceil(stars._max_shape[1]) * oversampling[0]
+                       + 1).astype(int)
 
             shape = np.array((y_shape, x_shape))
 
@@ -439,8 +412,7 @@ class EPSFBuilder:
         ycenter = stars._max_shape[1] / 2.
 
         epsf = EPSFModel(data=data, origin=(xcenter, ycenter),
-                         oversampling=oversampling, norm_radius=norm_radius,
-                         shift_val=shift_val)
+                         oversampling=oversampling, norm_radius=norm_radius)
 
         return epsf
 
@@ -476,25 +448,21 @@ class EPSFBuilder:
         x = star._xidx_centered
         y = star._yidx_centered
 
-        stardata = (star._data_values_normalized -
-                    epsf.evaluate(x=x, y=y, flux=1.0, x_0=0.0, y_0=0.0))
+        stardata = (star._data_values_normalized
+                    - epsf.evaluate(x=x, y=y, flux=1.0, x_0=0.0, y_0=0.0))
 
-        x = epsf.oversampling[0] * star._xidx_centered
-        y = epsf.oversampling[1] * star._yidx_centered
+        x = epsf.oversampling[1] * star._xidx_centered
+        y = epsf.oversampling[0] * star._yidx_centered
 
-        epsf_xcenter, epsf_ycenter = (int((epsf.data.shape[1] -
-                                           1) / 2),
-                                      int((epsf.data.shape[0] -
-                                           1) / 2))
+        epsf_xcenter, epsf_ycenter = (int((epsf.data.shape[1] - 1) / 2),
+                                      int((epsf.data.shape[0] - 1) / 2))
         xidx = _py2intround(x + epsf_xcenter)
         yidx = _py2intround(y + epsf_ycenter)
 
         resampled_img = np.full(epsf.shape, np.nan)
 
-        mask = np.logical_and(np.logical_and(xidx >= 0,
-                                             xidx < epsf.shape[1]),
-                              np.logical_and(yidx >= 0,
-                                             yidx < epsf.shape[0]))
+        mask = np.logical_and(np.logical_and(xidx >= 0, xidx < epsf.shape[1]),
+                              np.logical_and(yidx >= 0, yidx < epsf.shape[0]))
         xidx_ = xidx[mask]
         yidx_ = yidx[mask]
 
@@ -609,10 +577,11 @@ class EPSFBuilder:
 
         box_size : float or tuple of two floats, optional
             The size (in pixels) of the box used to calculate the
-            centroid of the ePSF during each build iteration.  If a
-            single integer number is provided, then a square box will be
-            used.  If two values are provided, then they should be in
-            ``(ny, nx)`` order.
+            centroid of the ePSF during each build iteration. If a
+            single integer number is provided, then a square box will
+            be used. If two values are provided, then they must be in
+            ``(ny, nx)`` order. ``box_size`` must have odd values and be
+            greater than or equal to 3 for both axes.
 
         maxiters : int, optional
             The maximum number of recentering iterations to perform.
@@ -631,57 +600,38 @@ class EPSFBuilder:
 
         epsf = EPSFModel(data=epsf._data, origin=epsf.origin,
                          oversampling=epsf.oversampling,
-                         norm_radius=epsf._norm_radius,
-                         shift_val=epsf._shift_val, normalize=False)
+                         norm_radius=epsf._norm_radius, normalize=False)
 
         xcenter, ycenter = epsf.origin
 
         y, x = np.indices(epsf._data.shape, dtype=float)
-        x /= epsf.oversampling[0]
-        y /= epsf.oversampling[1]
+        x /= epsf.oversampling[1]
+        y /= epsf.oversampling[0]
 
         dx_total, dy_total = 0, 0
         iter_num = 0
         center_accuracy_sq = center_accuracy ** 2
         center_dist_sq = center_accuracy_sq + 1.e6
         center_dist_sq_prev = center_dist_sq + 1
-        while (iter_num < maxiters and
-               center_dist_sq >= center_accuracy_sq):
+        while (iter_num < maxiters and center_dist_sq >= center_accuracy_sq):
             iter_num += 1
 
             # Anderson & King (2000) recentering function depends
             # on specific pixels, and thus does not need a cutout
-            if self.recentering_func == centroid_epsf:
-                epsf_cutout = epsf_data
-            else:
-                slices_large, _ = overlap_slices(epsf_data.shape, box_size,
-                                                 (ycenter *
-                                                  self.oversampling[1],
-                                                  xcenter *
-                                                  self.oversampling[0]))
-                epsf_cutout = epsf_data[slices_large]
+            slices_large, _ = overlap_slices(epsf_data.shape, box_size,
+                                             (ycenter * self.oversampling[0],
+                                              xcenter * self.oversampling[1]))
+            epsf_cutout = epsf_data[slices_large]
             mask = ~np.isfinite(epsf_cutout)
 
-            try:
-                # find a new center position
-                xcenter_new, ycenter_new = centroid_func(
-                    epsf_cutout, mask=mask, oversampling=epsf.oversampling,
-                    shift_val=epsf._shift_val)
-            except TypeError:
-                # centroid_func doesn't accept oversampling and/or shift_val
-                # keywords - try oversampling alone
-                try:
-                    xcenter_new, ycenter_new = centroid_func(
-                        epsf_cutout, mask=mask, oversampling=epsf.oversampling)
-                except TypeError:
-                    # centroid_func doesn't accept oversampling and
-                    # shift_val
-                    xcenter_new, ycenter_new = centroid_func(epsf_cutout,
-                                                             mask=mask)
+            # find a new center position
+            xcenter_new, ycenter_new = centroid_func(epsf_cutout,
+                                                     mask=mask)
+            xcenter_new /= self.oversampling[1]
+            ycenter_new /= self.oversampling[0]
 
-            if self.recentering_func != centroid_epsf:
-                xcenter_new += slices_large[1].start/self.oversampling[0]
-                ycenter_new += slices_large[0].start/self.oversampling[1]
+            xcenter_new += slices_large[1].start / self.oversampling[1]
+            ycenter_new += slices_large[0].start / self.oversampling[0]
 
             # Calculate the shift; dx = i - x_star so if dx was positively
             # incremented then x_star was negatively incremented for a given i.
@@ -741,9 +691,8 @@ class EPSFBuilder:
         with warnings.catch_warnings():
             warnings.simplefilter('ignore', category=RuntimeWarning)
             warnings.simplefilter('ignore', category=AstropyUserWarning)
-            residuals = self.flux_residual_sigclip(residuals, axis=0,
-                                                   masked=False,
-                                                   return_bounds=False)
+            residuals = self._sigma_clip(residuals, axis=0, masked=False,
+                                         return_bounds=False)
             if HAS_BOTTLENECK:
                 import bottleneck
                 residuals = bottleneck.nanmedian(residuals, axis=0)
@@ -767,8 +716,7 @@ class EPSFBuilder:
 
         epsf = EPSFModel(data=new_epsf, origin=epsf.origin,
                          oversampling=epsf.oversampling,
-                         norm_radius=epsf._norm_radius,
-                         shift_val=epsf._shift_val, normalize=False)
+                         norm_radius=epsf._norm_radius, normalize=False)
 
         epsf._data = self._recenter_epsf(
             epsf, centroid_func=self.recentering_func,
@@ -777,15 +725,14 @@ class EPSFBuilder:
 
         # Return the new ePSF object, but with undersampled grid pixel
         # coordinates.
-        xcenter = (epsf._data.shape[1] - 1) / 2. / epsf.oversampling[0]
-        ycenter = (epsf._data.shape[0] - 1) / 2. / epsf.oversampling[1]
+        xcenter = (epsf._data.shape[1] - 1) / 2. / epsf.oversampling[1]
+        ycenter = (epsf._data.shape[0] - 1) / 2. / epsf.oversampling[0]
 
         return EPSFModel(data=epsf._data, origin=(xcenter, ycenter),
                          oversampling=epsf.oversampling,
-                         norm_radius=epsf._norm_radius,
-                         shift_val=epsf._shift_val)
+                         norm_radius=epsf._norm_radius)
 
-    def build_epsf(self, stars, init_epsf=None):
+    def build_epsf(self, stars, *, init_epsf=None):
         """
         Build iteratively an ePSF from star cutouts.
 
@@ -811,24 +758,21 @@ class EPSFBuilder:
         n_stars = stars.n_stars
         fit_failed = np.zeros(n_stars, dtype=bool)
         epsf = init_epsf
-        dt = 0.
         center_dist_sq = self.center_accuracy_sq + 1.
         centers = stars.cutout_center_flat
 
-        while (iter_num < self.maxiters and not np.all(fit_failed) and
-               np.max(center_dist_sq) >= self.center_accuracy_sq):
+        if self.progress_bar and HAS_TQDM:
+            from tqdm.auto import tqdm
+            pbar_desc = f'EPSFBuilder ({self.maxiters} maxiters)'
+            pbar = tqdm(total=self.maxiters, desc=pbar_desc)
+        else:
+            pbar = None
+
+        while (iter_num < self.maxiters and not np.all(fit_failed)
+               and np.max(center_dist_sq) >= self.center_accuracy_sq):
 
-            t_start = time.time()
             iter_num += 1
 
-            if self.progress_bar:
-                if iter_num == 1:
-                    dt_str = ' [? s/iter]'
-                else:
-                    dt_str = f' [{dt:.1f} s/iter]'
-                print(f'PROGRESS: iteration {iter_num:d} (of max '
-                      f'{self.maxiters}){dt_str}', end='\r')
-
             # build/improve the ePSF
             epsf = self._build_epsf_step(stars, epsf=epsf)
 
@@ -851,7 +795,7 @@ class EPSFBuilder:
             # after 3 iterations
             if iter_num > 3 and np.any(fit_failed):
                 idx = fit_failed.nonzero()[0]
-                for i in idx:
+                for i in idx:  # pylint: disable=not-an-iterable
                     stars.all_stars[i]._excluded_from_fit = True
 
             # if no star centers have moved by more than pixel accuracy,
@@ -863,62 +807,14 @@ class EPSFBuilder:
 
             self._epsf.append(epsf)
 
-            dt = time.time() - t_start
+            if pbar is not None:
+                pbar.update()
+
+        if pbar is not None:
+            if iter_num < self.maxiters:
+                pbar.write(f'EPSFBuilder converged after {iter_num} '
+                           f'iterations (of {self.maxiters} maximum '
+                           'iterations)')
+            pbar.close()
 
         return epsf, stars
-
-
-def _interpolate_missing_data(data, mask, method='cubic'):
-    """
-    Interpolate missing data as identified by the ``mask`` keyword.
-
-    Parameters
-    ----------
-    data : 2D `~numpy.ndarray`
-        An array containing the 2D image.
-
-    mask : 2D bool `~numpy.ndarray`
-        A 2D boolean mask array with the same shape as the input
-        ``data``, where a `True` value indicates the corresponding
-        element of ``data`` is masked.  The masked data points are
-        those that will be interpolated.
-
-    method : {'cubic', 'nearest'}, optional
-        The method of used to interpolate the missing data:
-
-        * ``'cubic'``:  Masked data are interpolated using 2D cubic
-            splines.  This is the default.
-
-        * ``'nearest'``:  Masked data are interpolated using
-            nearest-neighbor interpolation.
-
-    Returns
-    -------
-    data_interp : 2D `~numpy.ndarray`
-        The interpolated 2D image.
-    """
-    from scipy import interpolate
-
-    data_interp = np.array(data, copy=True)
-
-    if len(data_interp.shape) != 2:
-        raise ValueError("'data' must be a 2D array.")
-
-    if mask.shape != data.shape:
-        raise ValueError("'mask' and 'data' must have the same shape.")
-
-    y, x = np.indices(data_interp.shape)
-    xy = np.dstack((x[~mask].ravel(), y[~mask].ravel()))[0]
-    z = data_interp[~mask].ravel()
-
-    if method == 'nearest':
-        interpol = interpolate.NearestNDInterpolator(xy, z)
-    elif method == 'cubic':
-        interpol = interpolate.CloughTocher2DInterpolator(xy, z)
-    else:
-        raise ValueError('Unsupported interpolation method.')
-
-    xy_missing = np.dstack((x[mask].ravel(), y[mask].ravel()))[0]
-    data_interp[mask] = interpol(xy_missing)
-
-    return data_interp
