@@ -12,11 +12,11 @@ from astropy.nddata.utils import (overlap_slices, NoOverlapError,
 from astropy.table import Table
 from astropy.utils import lazyproperty
 from astropy.utils.exceptions import AstropyUserWarning
-from astropy.wcs import WCS
-from astropy.wcs.utils import skycoord_to_pixel
 import numpy as np
 
+from .utils import _interpolate_missing_data
 from ..aperture import BoundingBox
+from ..utils._parameters import as_pair
 
 __all__ = ['EPSFStar', 'EPSFStars', 'LinkedEPSFStar', 'extract_stars']
 
@@ -61,8 +61,8 @@ class EPSFStar:
         An optional identification number or label for the star.
     """
 
-    def __init__(self, data, weights=None, cutout_center=None, origin=(0, 0),
-                 wcs_large=None, id_label=None):
+    def __init__(self, data, *, weights=None, cutout_center=None,
+                 origin=(0, 0), wcs_large=None, id_label=None):
 
         self._data = np.asanyarray(data)
         self.shape = self._data.shape
@@ -158,8 +158,6 @@ class EPSFStar:
         Missing data is filled in by interpolation to better estimate
         the total flux.
         """
-        from .epsf import _interpolate_missing_data
-
         if np.any(self.mask):
             data_interp = _interpolate_missing_data(self.data, method='cubic',
                                                     mask=self.mask)
@@ -301,8 +299,7 @@ class EPSFStars:
         del self._data[index]
 
     def __iter__(self):
-        for i in self._data:
-            yield i
+        yield from self._data
 
     # explicit set/getstate to avoid infinite recursion
     # from pickler using __getattr__
@@ -385,8 +382,7 @@ class EPSFStars:
         for star in self.all_stars:
             if star._excluded_from_fit:
                 continue
-            else:
-                stars.append(star)
+            stars.append(star)
 
         return stars
 
@@ -470,28 +466,20 @@ class LinkedEPSFStar(EPSFStars):
             return
 
         idx = np.logical_not(self._excluded_from_fit).nonzero()[0]
-        if idx.size == 0:
+        if idx.shape == (0,):  # pylint: disable=no-member
             warnings.warn('Cannot constrain centers of linked stars because '
                           'all the stars have been excluded during the ePSF '
                           'build process.', AstropyUserWarning)
             return
 
-        good_stars = [self._data[i] for i in idx]
+        good_stars = [self._data[i] for i in idx]  # pylint: disable=not-an-iterable
 
         coords = []
         for star in good_stars:
             wcs = star.wcs_large
             xposition = star.center[0]
             yposition = star.center[1]
-            try:
-                coords.append(wcs.pixel_to_world_values(xposition, yposition))
-            except AttributeError:
-                if isinstance(wcs, WCS):
-                    # for Astropy < 3.1 WCS support
-                    coords.append(wcs.all_pix2world(xposition, yposition, 0))
-                else:
-                    raise ValueError('Input wcs does not support the shared '
-                                     'WCS interface.')
+            coords.append(wcs.pixel_to_world_values(xposition, yposition))
 
         # compute mean cartesian coordinates
         lon, lat = np.transpose(coords)
@@ -511,17 +499,11 @@ class LinkedEPSFStar(EPSFStars):
         # convert mean sky coordinates back to center pixel coordinates
         # for each star
         for star in good_stars:
-            try:
-                center = star.wcs_large.world_to_pixel_values(mean_lon,
-                                                              mean_lat)
-            except AttributeError:
-                # for Astropy < 3.1 WCS support
-                center = star.wcs_large.all_world2pix(mean_lon, mean_lat, 0)
-
+            center = star.wcs_large.world_to_pixel_values(mean_lon, mean_lat)
             star.cutout_center = np.array(center) - star.origin
 
 
-def extract_stars(data, catalogs, size=(11, 11)):
+def extract_stars(data, catalogs, *, size=(11, 11)):
     """
     Extract cutout images centered on stars defined in the input
     catalog(s).
@@ -573,10 +555,9 @@ def extract_stars(data, catalogs, size=(11, 11)):
     size : int or array_like (int), optional
         The extraction box size along each axis.  If ``size`` is a
         scalar then a square box of size ``size`` will be used.  If
-        ``size`` has two elements, they should be in ``(ny, nx)`` order.
-        The size must be greater than or equal to 3 pixel for both axes.
-        Size must be odd in both axes; if either is even, it is padded
-        by one to force oddness.
+        ``size`` has two elements, they must be in ``(ny, nx)`` order.
+        ``size`` must have odd values and be greater than or equal to 3
+        for both axes.
 
     Returns
     -------
@@ -605,7 +586,7 @@ def extract_stars(data, catalogs, size=(11, 11)):
                              'NDData objects, the catalog must have a '
                              '"skycoord" column.')
 
-        if any([img.wcs is None for img in data]):
+        if any(img.wcs is None for img in data):
             raise ValueError('When inputting a single catalog with multiple '
                              'NDData objects, each NDData object must have '
                              'a wcs attribute.')
@@ -616,29 +597,18 @@ def extract_stars(data, catalogs, size=(11, 11)):
                     raise ValueError('When inputting multiple catalogs, '
                                      'each one must have a "x" and "y" '
                                      'column or a "skycoord" column.')
-                else:
-                    if any([img.wcs is None for img in data]):
-                        raise ValueError('When inputting catalog(s) with '
-                                         'only skycoord positions, each '
-                                         'NDData object must have a wcs '
-                                         'attribute.')
+
+                if any(img.wcs is None for img in data):
+                    raise ValueError('When inputting catalog(s) with only '
+                                     'skycoord positions, each NDData object '
+                                     'must have a wcs attribute.')
 
         if len(data) != len(catalogs):
             raise ValueError('When inputting multiple catalogs, the number '
                              'of catalogs must match the number of input '
                              'images.')
 
-    size = np.atleast_1d(size)
-    if len(size) == 1:
-        size = np.repeat(size, 2)
-
-    # Force size to odd numbers such that there is always a central pixel with
-    # even spacing either side of the pixel.
-    size = tuple(_size+1 if _size % 2 == 0 else _size for _size in size)
-
-    min_size = 3
-    if size[0] < min_size or size[1] < min_size:
-        raise ValueError(f'size must be >= {min_size} for x and y')
+    size = as_pair('size', size, lower_bound=(3, 0), check_odd=True)
 
     if len(catalogs) == 1:  # may included linked stars
         use_xy = True
@@ -664,7 +634,8 @@ def extract_stars(data, catalogs, size=(11, 11)):
             n_extracted += len(good_stars)
             if not good_stars:
                 continue  # no overlap in any image
-            elif len(good_stars) == 1:
+
+            if len(good_stars) == 1:
                 good_stars = good_stars[0]  # only one star, cannot be linked
             else:
                 good_stars = LinkedEPSFStar(good_stars)
@@ -681,14 +652,14 @@ def extract_stars(data, catalogs, size=(11, 11)):
 
     n_excluded = n_input - n_extracted
     if n_excluded > 0:
-        warnings.warn('{} star(s) were not extracted because their cutout '
-                      'region extended beyond the input image.'
-                      .format(n_excluded), AstropyUserWarning)
+        warnings.warn(f'{n_excluded} star(s) were not extracted because '
+                      'their cutout region extended beyond the input image.',
+                      AstropyUserWarning)
 
     return EPSFStars(stars_out)
 
 
-def _extract_stars(data, catalog, size=(11, 11), use_xy=True):
+def _extract_stars(data, catalog, *, size=(11, 11), use_xy=True):
     """
     Extract cutout images from a single image centered on stars defined
     in the single input catalog.
@@ -712,12 +683,10 @@ def _extract_stars(data, catalog, size=(11, 11), use_xy=True):
         coordinates will be used.
 
     size : int or array_like (int), optional
-        The extraction box size along each axis.  If ``size`` is a
-        scalar then a square box of size ``size`` will be used.  If
-        ``size`` has two elements, they should be in ``(ny, nx)`` order.
-        The size must be greater than or equal to 3 pixel for both axes.
-        Size must be odd in both axes; if either is even, it is padded
-        by one to force oddness.
+        The extraction box size along each axis. If ``size`` is a scalar
+        then a square box of size ``size`` will be used. If ``size`` has
+        two elements, they must be in ``(ny, nx)`` order. ``size`` must
+        have odd values and be greater than or equal to 3 for both axes.
 
     use_xy : bool, optional
         Whether to use the ``x`` and ``y`` pixel positions when both
@@ -730,22 +699,11 @@ def _extract_stars(data, catalog, size=(11, 11), use_xy=True):
     stars : list of `EPSFStar` objects
         A list of `EPSFStar` instances containing the extracted stars.
     """
-    # Force size to odd numbers such that there is always a central pixel with
-    # even spacing either side of the pixel.
-    if np.isscalar(size):
-        size = size+1 if size % 2 == 0 else size
-    else:
-        size = tuple(_size+1 if _size % 2 == 0 else _size for _size in size)
+    size = as_pair('size', size, lower_bound=(3, 0), check_odd=True)
 
     colnames = catalog.colnames
     if ('x' not in colnames or 'y' not in colnames) or not use_xy:
-        try:
-            xcenters, ycenters = data.wcs.world_to_pixel(catalog['skycoord'])
-        except AttributeError:
-            # for Astropy < 3.1 WCS support
-            xcenters, ycenters = skycoord_to_pixel(catalog['skycoord'],
-                                                   data.wcs, origin=0,
-                                                   mode='all')
+        xcenters, ycenters = data.wcs.world_to_pixel(catalog['skycoord'])
     else:
         xcenters = catalog['x'].data.astype(float)
         ycenters = catalog['y'].data.astype(float)
@@ -783,7 +741,7 @@ def _extract_stars(data, catalog, size=(11, 11), use_xy=True):
 
         origin = (large_slc[1].start, large_slc[0].start)
         cutout_center = (xcenter - origin[0], ycenter - origin[1])
-        star = EPSFStar(data_cutout, weights_cutout,
+        star = EPSFStar(data_cutout, weights=weights_cutout,
                         cutout_center=cutout_center, origin=origin,
                         wcs_large=data.wcs, id_label=obj_id)
 
