@@ -13,6 +13,7 @@ from astropy.utils.exceptions import AstropyWarning
 import numpy as np
 
 from ..aperture import CircularAperture
+from ..utils._parameters import as_pair
 
 __all__ = ['NonNormalizable', 'FittableImageModel', 'EPSFModel',
            'GriddedPSFModel', 'IntegratedGaussianPRF', 'PRFAdapter']
@@ -108,11 +109,11 @@ class FittableImageModel(Fittable2DModel):
         the `compute_interpolator` method.  See `compute_interpolator`
         for more details.
 
-    oversampling : int or tuple of two int, optional
-        The oversampling factor(s) of the model in the ``x`` and ``y``
-        directions.  If ``oversampling`` is a scalar it will be treated
-        as being the same in both x and y; otherwise a tuple of two
-        floats will be treated as ``(x_oversamp, y_oversamp)``.
+    oversampling : int or array_like (int)
+        The integer oversampling factor(s) of the ePSF relative to the
+        input ``stars`` along each axis. If ``oversampling`` is a scalar
+        then it will be used for both axes. If ``oversampling`` has two
+        elements, they must be in ``(y, x)`` order.
     """
 
     flux = Parameter(description='Intensity scaling factor for image data.',
@@ -124,7 +125,7 @@ class FittableImageModel(Fittable2DModel):
                     'the output coordinate grid on which the model is '
                     'evaluated.', default=0.0)
 
-    def __init__(self, data, flux=flux.default, x_0=x_0.default,
+    def __init__(self, data, *, flux=flux.default, x_0=x_0.default,
                  y_0=y_0.default, normalize=False,
                  normalization_correction=1.0, origin=None, oversampling=1,
                  fill_value=0.0, **kwargs):
@@ -133,12 +134,14 @@ class FittableImageModel(Fittable2DModel):
         self._img_norm = None
         self._normalization_status = 0 if normalize else 2
         self._store_interpolator_kwargs(**kwargs)
-        self._set_oversampling(oversampling)
+        self._oversampling = as_pair('oversampling', oversampling,
+                                     lower_bound=(0, 1))
 
         if normalization_correction <= 0:
             raise ValueError("'normalization_correction' must be strictly "
                              "positive.")
         self._normalization_correction = normalization_correction
+        self._normalization_constant = 1.0 / self._normalization_correction
 
         self._data = np.array(data, copy=True, dtype=float)
 
@@ -185,7 +188,7 @@ class FittableImageModel(Fittable2DModel):
         """
         return np.sum(self._data, dtype=float)
 
-    def _compute_normalization(self, normalize):
+    def _compute_normalization(self, normalize=True):
         r"""
         Helper function that computes (corrected) normalization factor
         of the original image data. This quantity is computed as the
@@ -241,29 +244,6 @@ class FittableImageModel(Fittable2DModel):
         """
         return self._oversampling
 
-    def _set_oversampling(self, value):
-        value = np.atleast_1d(value)
-
-        if np.any(~np.isfinite(value)):
-            raise ValueError('Oversampling factor must be a finite value')
-
-        if np.any(value <= 0):
-            raise ValueError('Oversampling factor must be greater than 0')
-
-        if len(value) == 1:
-            value = np.repeat(value, 2)
-        if len(value) != 2:
-            raise ValueError('Oversampling factor must have 1 or 2 '
-                             'elements')
-        if value.ndim != 1:
-            raise ValueError('Oversampling factor must be 1D')
-
-        value_int = value.astype(int)
-        if np.any(value_int != value):  # e.g., 2.0 is OK, 2.1 is not
-            raise ValueError('Oversampling elements must be integers')
-
-        self._oversampling = value
-
     @property
     def data(self):
         """Get original image data."""
@@ -464,7 +444,7 @@ class FittableImageModel(Fittable2DModel):
 
         self._store_interpolator_kwargs(**kwargs)
 
-    def evaluate(self, x, y, flux, x_0, y_0, use_oversampling=True):
+    def evaluate(self, x, y, flux, x_0, y_0, *, use_oversampling=True):
         """
         Evaluate the model on some input variables and provided model
         parameters.
@@ -477,8 +457,8 @@ class FittableImageModel(Fittable2DModel):
             input indices will be multiplied by this factor.
         """
         if use_oversampling:
-            xi = self._oversampling[0] * (np.asarray(x) - x_0)
-            yi = self._oversampling[1] * (np.asarray(y) - y_0)
+            xi = self._oversampling[1] * (np.asarray(x) - x_0)
+            yi = self._oversampling[0] * (np.asarray(y) - y_0)
         else:
             xi = np.asarray(x) - x_0
             yi = np.asarray(y) - y_0
@@ -494,8 +474,8 @@ class FittableImageModel(Fittable2DModel):
         if self._fill_value is not None:
             # find indices of pixels that are outside the input pixel grid and
             # set these pixels to the 'fill_value':
-            invalid = (((xi < 0) | (xi > self._nx - 1)) |
-                       ((yi < 0) | (yi > self._ny - 1)))
+            invalid = (((xi < 0) | (xi > self._nx - 1))
+                       | ((yi < 0) | (yi > self._ny - 1)))
             evaluated_model[invalid] = self._fill_value
 
         return evaluated_model
@@ -517,28 +497,22 @@ class EPSFModel(FittableImageModel):
 
     Parameters
     ----------
-    oversampling : int or tuple of two int, optional
-        The oversampling factor(s) of the model in the ``x`` and ``y``
-        directions.  If ``oversampling`` is a scalar it will be treated
-        as being the same in both x and y; otherwise a tuple of two
-        floats will be treated as ``(x_oversamp, y_oversamp)``.
+    oversampling : int or array_like (int)
+        The integer oversampling factor(s) of the ePSF relative to the
+        input ``stars`` along each axis. If ``oversampling`` is a scalar
+        then it will be used for both axes. If ``oversampling`` has two
+        elements, they must be in ``(y, x)`` order.
 
     norm_radius : float, optional
         The radius inside which the ePSF is normalized by the sum over
         undersampled integer pixel values inside a circular aperture.
-
-    shift_val : float, optional
-        The fractional undersampled pixel amount (equivalent to an
-        integer oversampled pixel value) at which to evaluate the
-        asymmetric ePSF centroid corrections.
     """
 
-    def __init__(self, data, flux=1.0, x_0=0.0, y_0=0.0, normalize=True,
+    def __init__(self, data, *, flux=1.0, x_0=0.0, y_0=0.0, normalize=True,
                  normalization_correction=1.0, origin=None, oversampling=1,
-                 fill_value=0.0, norm_radius=5.5, shift_val=0.5, **kwargs):
+                 fill_value=0.0, norm_radius=5.5, **kwargs):
 
         self._norm_radius = norm_radius
-        self._shift_val = shift_val
 
         super().__init__(data=data, flux=flux, x_0=x_0, y_0=y_0,
                          normalize=normalize,
@@ -572,29 +546,33 @@ class EPSFModel(FittableImageModel):
         flux, _ = aper.do_photometry(self._data, method='exact')
         return flux[0] / np.product(self.oversampling)
 
-    def _compute_normalization(self):
+    def _compute_normalization(self, normalize=True):
         """
         Helper function that computes (corrected) normalization factor
         of the original image data. For the ePSF this is defined as the
         sum over the inner N (default=5.5) pixels of the non-oversampled
         image. Will re-normalize the data to the value calculated.
         """
-        if self._img_norm is None:
-            if np.sum(self._data) == 0:
-                self._img_norm = 1
+        if normalize:
+            if self._img_norm is None:
+                if np.sum(self._data) == 0:
+                    self._img_norm = 1
+                else:
+                    self._img_norm = self._compute_raw_image_norm()
+
+            if self._img_norm != 0.0 and np.isfinite(self._img_norm):
+                self._data /= (self._img_norm * self._normalization_correction)
+                self._normalization_status = 0
             else:
-                self._img_norm = self._compute_raw_image_norm()
-
-        if self._img_norm != 0.0 and np.isfinite(self._img_norm):
-            self._data /= (self._img_norm * self._normalization_correction)
-            self._normalization_status = 0
+                self._normalization_status = 1
+                self._img_norm = 1
+                warnings.warn('Overflow encountered while computing '
+                              'normalization constant. Normalization '
+                              'constant will be set to 1.', NonNormalizable)
         else:
-            self._normalization_status = 1
-            self._img_norm = 1
-            warnings.warn("Overflow encountered while computing "
-                          "normalization constant. Normalization "
-                          "constant will be set to 1.", NonNormalizable)
+            self._normalization_status = 2
 
+    @property
     def normalized_data(self):
         """
         Overloaded dummy function that also returns self._data, as the
@@ -607,8 +585,8 @@ class EPSFModel(FittableImageModel):
     @FittableImageModel.origin.setter
     def origin(self, origin):
         if origin is None:
-            self._x_origin = (self._nx - 1) / 2.0 / self.oversampling[0]
-            self._y_origin = (self._ny - 1) / 2.0 / self.oversampling[1]
+            self._x_origin = (self._nx - 1) / 2.0 / self.oversampling[1]
+            self._y_origin = (self._ny - 1) / 2.0 / self.oversampling[0]
         elif (hasattr(origin, '__iter__') and len(origin) == 2):
             self._x_origin, self._y_origin = origin
         else:
@@ -670,15 +648,12 @@ class EPSFModel(FittableImageModel):
             degx = 3
             degy = 3
 
-        if 's' in kwargs:
-            smoothness = kwargs['s']
-        else:
-            smoothness = 0
+        smoothness = kwargs.get('s', 0)
 
         # Interpolator must be set to interpolate on the undersampled
         # pixel grid, going from 0 to len(undersampled_grid)
-        x = np.arange(self._nx, dtype=float) / self.oversampling[0]
-        y = np.arange(self._ny, dtype=float) / self.oversampling[1]
+        x = np.arange(self._nx, dtype=float) / self.oversampling[1]
+        y = np.arange(self._ny, dtype=float) / self.oversampling[0]
         self.interpolator = RectBivariateSpline(
             x, y, self._data.T, kx=degx, ky=degy, s=smoothness)
 
@@ -698,9 +673,9 @@ class EPSFModel(FittableImageModel):
             # find indices of pixels that are outside the input pixel
             # grid and set these pixels to the 'fill_value':
             invalid = (((xi < 0) | (xi > (self._nx - 1)
-                                    / self.oversampling[0])) |
-                       ((yi < 0) | (yi > (self._ny - 1)
-                                    / self.oversampling[1])))
+                                    / self.oversampling[1]))
+                       | ((yi < 0) | (yi > (self._ny - 1)
+                                      / self.oversampling[0])))
             evaluated_model[invalid] = self._fill_value
 
         return evaluated_model
@@ -740,7 +715,7 @@ class GriddedPSFModel(Fittable2DModel):
     y_0 = Parameter(description='y position in the output coordinate grid '
                     'where the model is evaluated.', default=0.0)
 
-    def __init__(self, data, flux=flux.default, x_0=x_0.default,
+    def __init__(self, data, *, flux=flux.default, x_0=x_0.default,
                  y_0=y_0.default, fill_value=0.0):
 
         if not isinstance(data, NDData):
@@ -767,19 +742,22 @@ class GriddedPSFModel(Fittable2DModel):
         self.meta = data.meta
         self.grid_xypos = data.meta['grid_xypos']
         self.oversampling = data.meta['oversampling']
+        self._fill_value = fill_value
 
         self._grid_xpos, self._grid_ypos = np.transpose(self.grid_xypos)
         self._xgrid = np.unique(self._grid_xpos)  # also sorts values
         self._ygrid = np.unique(self._grid_ypos)  # also sorts values
 
-        if (len(list(itertools.product(self._xgrid, self._ygrid))) !=
-                len(self.grid_xypos)):
+        if (len(list(itertools.product(self._xgrid, self._ygrid)))
+                != len(self.grid_xypos)):
             raise ValueError('"grid_xypos" must form a regular grid.')
 
         self._xgrid_min = self._xgrid[0]
         self._xgrid_max = self._xgrid[-1]
         self._ygrid_min = self._ygrid[0]
         self._ygrid_max = self._ygrid[-1]
+        self._ref_indices = None
+        self._psf_interp = None
 
         super().__init__(flux, x_0, y_0)
 
@@ -833,8 +811,10 @@ class GriddedPSFModel(Fittable2DModel):
         if not np.isscalar(x) or not np.isscalar(y):  # pragma: no cover
             raise TypeError('x and y must be scalars')
 
-        if (x < self._xgrid_min or x > self._xgrid_max or
-                y < self._ygrid_min or y > self._ygrid_max):  # pragma: no cover
+        if (x < self._xgrid_min
+                or x > self._xgrid_max
+                or y < self._ygrid_min
+                or y > self._ygrid_max):  # pragma: no cover
             raise ValueError('(x, y) position is outside of the region '
                              'defined by grid of PSF positions')
 
@@ -919,8 +899,8 @@ class GriddedPSFModel(Fittable2DModel):
         if not np.isscalar(y_0):
             y_0 = y_0[0]
 
-        if (x_0 < self._xgrid_min or x_0 > self._xgrid_max or
-                y_0 < self._ygrid_min or y_0 > self._ygrid_max):
+        if (x_0 < self._xgrid_min or x_0 > self._xgrid_max
+                or y_0 < self._ygrid_min or y_0 > self._ygrid_max):
 
             # position is outside of the grid, so simply use the
             # closest reference PSF
@@ -1029,11 +1009,11 @@ class IntegratedGaussianPRF(Fittable2DModel):
 
     def evaluate(self, x, y, flux, x_0, y_0, sigma):
         """Model function Gaussian PSF model."""
-        return (flux / 4 *
-                ((self._erf((x - x_0 + 0.5) / (np.sqrt(2) * sigma)) -
-                  self._erf((x - x_0 - 0.5) / (np.sqrt(2) * sigma))) *
-                 (self._erf((y - y_0 + 0.5) / (np.sqrt(2) * sigma)) -
-                  self._erf((y - y_0 - 0.5) / (np.sqrt(2) * sigma)))))
+        return (flux / 4
+                * ((self._erf((x - x_0 + 0.5) / (np.sqrt(2) * sigma))
+                    - self._erf((x - x_0 - 0.5) / (np.sqrt(2) * sigma)))
+                   * (self._erf((y - y_0 + 0.5) / (np.sqrt(2) * sigma))
+                      - self._erf((y - y_0 - 0.5) / (np.sqrt(2) * sigma)))))
 
 
 class PRFAdapter(Fittable2DModel):
@@ -1078,7 +1058,7 @@ class PRFAdapter(Fittable2DModel):
     x_0 = Parameter(default=0)
     y_0 = Parameter(default=0)
 
-    def __init__(self, psfmodel, renormalize_psf=True, flux=flux.default,
+    def __init__(self, psfmodel, *, renormalize_psf=True, flux=flux.default,
                  x_0=x_0.default, y_0=y_0.default, xname=None, yname=None,
                  fluxname=None, **kwargs):
 
@@ -1118,8 +1098,8 @@ class PRFAdapter(Fittable2DModel):
             setattr(self.psfmodel, self.yname, y_0)
 
         if self.fluxname is None:
-            return (flux * self._psf_scale_factor *
-                    self._integrated_psfmodel(dx, dy))
+            return (flux * self._psf_scale_factor
+                    * self._integrated_psfmodel(dx, dy))
         else:
             setattr(self.psfmodel, self.yname, flux * self._psf_scale_factor)
             return self._integrated_psfmodel(dx, dy)
@@ -1133,7 +1113,7 @@ class PRFAdapter(Fittable2DModel):
         outravel = out.ravel()
         for i, (xi, yi) in enumerate(zip(dx.ravel(), dy.ravel())):
             outravel[i] = dblquad(self.psfmodel,
-                                  xi-0.5, xi+0.5,
-                                  lambda x: yi-0.5, lambda x: yi+0.5,
+                                  xi - 0.5, xi + 0.5,
+                                  lambda x: yi - 0.5, lambda x: yi + 0.5,
                                   **self._dblquadkwargs)[0]
         return out
