@@ -126,7 +126,7 @@ class BasicPSFPhotometry:
         https://ui.adsabs.harvard.edu/abs/1987PASP...99..191S/abstract
     """
 
-    def __init__(self, group_maker, bkg_estimator, psf_model, fitshape,
+    def __init__(self, group_maker, bkg_estimator, psf_model, fitshape, *,
                  finder=None, fitter=LevMarLSQFitter(), aperture_radius=None,
                  extra_output_cols=None):
         self.group_maker = group_maker
@@ -187,8 +187,8 @@ class BasicPSFPhotometry:
 
         Returns
         -------
-        residual_image : 2D array-like, `~astropy.io.fits.ImageHDU`, \
-            `~astropy.io.fits.HDUList`
+        residual_image : 2D `~numpy.ndarray`
+            The 2D residual image.
         """
         return self._residual_image
 
@@ -200,8 +200,8 @@ class BasicPSFPhotometry:
         if hasattr(self.psf_model, 'fwhm'):
             self.aperture_radius = self.psf_model.fwhm.value
         elif hasattr(self.psf_model, 'sigma'):
-            self.aperture_radius = (self.psf_model.sigma.value *
-                                    gaussian_sigma_to_fwhm)
+            self.aperture_radius = (self.psf_model.sigma.value
+                                    * gaussian_sigma_to_fwhm)
         # If PSF model doesn't have FWHM or sigma value -- as it
         # is not a Gaussian; most likely because it's an ePSF --
         # then we fall back on fitting a circle of the average
@@ -220,14 +220,38 @@ class BasicPSFPhotometry:
                           'consider supplying a specific aperture_radius.',
                           AstropyUserWarning)
 
-    def __call__(self, image, init_guesses=None):
+    @staticmethod
+    def _make_mask(image, mask):
+        if mask is not None:
+            if image.shape != mask.shape:
+                raise ValueError('image and mask must have the same shape')
+
+        # if NaNs are in the data, no actually fitting takes place
+        # https://github.com/astropy/astropy/pull/12811
+        finite_mask = ~np.isfinite(image)
+
+        if mask is not None:
+            mask |= finite_mask
+            if np.any(finite_mask & ~mask):
+                warnings.warn('Input data contains unmasked non-finite '
+                              'values (NaN or inf), which were '
+                              'automatically ignored.', AstropyUserWarning)
+        else:
+            mask = finite_mask
+            if np.any(finite_mask):
+                warnings.warn('Input data contains unmasked non-finite '
+                              'values (NaN or inf), which were '
+                              'automatically ignored.', AstropyUserWarning)
+        return mask
+
+    def __call__(self, image, *, mask=None, init_guesses=None):
         """
         Perform PSF photometry. See `do_photometry` for more details
         including the `__call__` signature.
         """
-        return self.do_photometry(image, init_guesses)
+        return self.do_photometry(image, mask=mask, init_guesses=init_guesses)
 
-    def do_photometry(self, image, init_guesses=None):
+    def do_photometry(self, image, *, mask=None, init_guesses=None):
         """
         Perform PSF photometry in ``image``.
 
@@ -244,10 +268,10 @@ class BasicPSFPhotometry:
 
         Parameters
         ----------
-        image : 2D array-like, `~astropy.io.fits.ImageHDU`, \
-                `~astropy.io.fits.HDUList`
-            Image to perform photometry.
-        init_guesses: `~astropy.table.Table`
+        image : 2D `~numpy.ndarray`
+            Image to perform photometry. Invalid data values (i.e., NaN
+            or inf) are automatically ignored.
+        init_guesses : `~astropy.table.Table`
             Table which contains the initial guesses (estimates) for the
             set of parameters. Columns 'x_0' and 'y_0' which represent
             the positions (in pixel coordinates) for each object must be
@@ -260,6 +284,10 @@ class BasicPSFPhotometry:
             ``extra_output_cols`` the initial values are used; if the columns
             specified in ``extra_output_cols`` are not given in
             ``init_guesses`` then NaNs will be returned.
+        mask : 2D bool `~numpy.ndarray`, optional
+            A boolean mask with the same shape as ``image``, where
+            a `True` value indicates the corresponding element of
+            ``image`` is masked.
 
         Returns
         -------
@@ -273,6 +301,8 @@ class BasicPSFPhotometry:
             covariance matrix. If ``param_cov`` is not present,
             uncertanties are not reported.
         """
+        mask = self._make_mask(image, mask)
+
         if self.bkg_estimator is not None:
             image = image - self.bkg_estimator(image)
 
@@ -303,7 +333,7 @@ class BasicPSFPhotometry:
                                              r=self.aperture_radius)
 
                 init_guesses['flux_0'] = aperture_photometry(
-                    image, apertures)['aperture_sum']
+                    image, apertures, mask=mask)['aperture_sum']
 
             # if extra_output_cols have been given, check whether init_guesses
             # was supplied with extra_output_cols pre-attached and populate
@@ -317,15 +347,17 @@ class BasicPSFPhotometry:
             if self.finder is None:
                 raise ValueError('Finder cannot be None if init_guesses are '
                                  'not given.')
-            sources = self.finder(image)
-            if len(sources) > 0:
+            sources = self.finder(image, mask=mask)
+            if sources is None:
+                return None
+            else:
                 positions = np.transpose((sources['xcentroid'],
                                           sources['ycentroid']))
                 apertures = CircularAperture(positions,
                                              r=self.aperture_radius)
 
                 sources['aperture_flux'] = aperture_photometry(
-                    image, apertures)['aperture_sum']
+                    image, apertures, mask=mask)['aperture_sum']
 
                 # init_guesses should be the initial 3 required
                 # parameters (x, y, flux) and then concatenated with any
@@ -343,15 +375,16 @@ class BasicPSFPhotometry:
         self._define_fit_param_names()
         for p0, param in self._pars_to_set.items():
             if p0 not in init_guesses.colnames:
-                init_guesses[p0] = (len(init_guesses) *
-                                    [getattr(self.psf_model, param).value])
+                init_guesses[p0] = (len(init_guesses)
+                                    * [getattr(self.psf_model, param).value])
 
         if skip_group_maker:
             star_groups = init_guesses
         else:
             star_groups = self.group_maker(init_guesses)
 
-        output_tab, self._residual_image = self.nstar(image, star_groups)
+        output_tab, self._residual_image = self.nstar(image, star_groups,
+                                                      mask=mask)
         star_groups = star_groups.group_by('group_id')
 
         if hasattr(output_tab, 'update'):  # requires Astropy >= 5.0
@@ -369,7 +402,7 @@ class BasicPSFPhotometry:
 
         return star_groups
 
-    def nstar(self, image, star_groups):
+    def nstar(self, image, star_groups, *, mask=None):
         """
         Fit, as appropriate, a compound or single model to the given
         ``star_groups``. Groups are fitted sequentially from the
@@ -378,8 +411,9 @@ class BasicPSFPhotometry:
 
         Parameters
         ----------
-        image : numpy.ndarray
-            Background-subtracted image.
+        image : 2D `~numpy.ndarray`
+            Background-subtracted image. Invalid data values (i.e., NaN
+            or inf) are automatically ignored.
 
         star_groups : `~astropy.table.Table`
             This table must contain the following columns: ``id``,
@@ -390,16 +424,21 @@ class BasicPSFPhotometry:
             other parameter in the psf model is free (i.e., the
             ``fixed`` attribute of that parameter is ``False``).
 
+        mask : 2D bool `~numpy.ndarray`, optional
+            A boolean mask with the same shape as ``image``, where
+            a `True` value indicates the corresponding element of
+            ``image`` is masked.
+
         Returns
         -------
         result_tab : `~astropy.table.QTable`
             Astropy table that contains photometry results.
 
-        image : numpy.ndarray
+        image : 2D `~numpy.ndarray`
             Residual image.
         """
         result_tab = QTable()
-        for param_tab_name in self._pars_to_output.keys():
+        for param_tab_name in self._pars_to_output:
             result_tab.add_column(Column(name=param_tab_name))
 
         unc_tab = QTable()
@@ -410,29 +449,29 @@ class BasicPSFPhotometry:
         y, x = np.indices(image.shape)
 
         star_groups = star_groups.group_by('group_id')
-        for n in range(len(star_groups.groups)):
-            group_psf = get_grouped_psf_model(self.psf_model,
-                                              star_groups.groups[n],
+        for group in star_groups.groups:
+            group_psf = get_grouped_psf_model(self.psf_model, group,
                                               self._pars_to_set)
             usepixel = np.zeros_like(image, dtype=bool)
 
-            for row in star_groups.groups[n]:
+            for row in group:
                 usepixel[overlap_slices(large_array_shape=image.shape,
                                         small_array_shape=self.fitshape,
                                         position=(row['y_0'], row['x_0']),
                                         mode='trim')[0]] = True
 
+            if mask is not None:
+                usepixel &= ~mask
+
             fit_model = self.fitter(group_psf, x[usepixel], y[usepixel],
                                     image[usepixel])
-            param_table = self._model_params2table(fit_model,
-                                                   star_groups.groups[n])
+            param_table = self._model_params2table(fit_model, group)
             result_tab = vstack([result_tab, param_table])
 
             param_cov = self.fitter.fit_info.get('param_cov', None)
             if param_cov is not None:
                 unc_tab = vstack([unc_tab,
-                                  self._get_uncertainties(
-                                      len(star_groups.groups[n]))])
+                                  self._get_uncertainties(len(group))])
 
             # do not subtract if the fitting did not go well
             try:
@@ -534,7 +573,7 @@ class BasicPSFPhotometry:
         """
         param_tab = QTable()
 
-        for param_tab_name in self._pars_to_output.keys():
+        for param_tab_name in self._pars_to_output:
             param_tab.add_column(Column(name=param_tab_name,
                                         data=np.empty(len(star_group))))
 
@@ -547,7 +586,8 @@ class BasicPSFPhotometry:
                     # searches leaves and we might want a intermediate
                     # node of the tree
                     sub_models = [model for model
-                                  in fit_model.traverse_postorder() if model.name == i]
+                                  in fit_model.traverse_postorder()
+                                  if model.name == i]
                     if len(sub_models) != 1:
                         raise ValueError('sub_models must have a length of 1')
                     sub_model = sub_models[0]
@@ -654,11 +694,13 @@ class IterativelySubtractedPSFPhotometry(BasicPSFPhotometry):
     """
 
     def __init__(self, group_maker, bkg_estimator, psf_model, fitshape,
-                 finder, fitter=LevMarLSQFitter(), niters=3,
+                 finder, *, fitter=LevMarLSQFitter(), niters=3,
                  aperture_radius=None, extra_output_cols=None):
 
         super().__init__(group_maker, bkg_estimator, psf_model, fitshape,
-                         finder, fitter, aperture_radius, extra_output_cols)
+                         finder=finder, fitter=fitter,
+                         aperture_radius=aperture_radius,
+                         extra_output_cols=extra_output_cols)
         self.niters = niters
 
     @property
@@ -673,11 +715,10 @@ class IterativelySubtractedPSFPhotometry(BasicPSFPhotometry):
             try:
                 if value <= 0:
                     raise ValueError('niters must be positive.')
-                else:
-                    self._niters = int(value)
-            except ValueError:
+                self._niters = int(value)
+            except ValueError as exc:
                 raise ValueError('niters must be None or an integer or '
-                                 'convertable into an integer.')
+                                 'convertable into an integer.') from exc
 
     @property
     def finder(self):
@@ -690,10 +731,9 @@ class IterativelySubtractedPSFPhotometry(BasicPSFPhotometry):
                              "IterativelySubtractedPSFPhotometry - you may "
                              "want to use BasicPSFPhotometry. Please see the "
                              "Detection section on photutils documentation.")
-        else:
-            self._finder = value
+        self._finder = value
 
-    def do_photometry(self, image, init_guesses=None):
+    def do_photometry(self, image, *, mask=None, init_guesses=None):
         """
         Perform PSF photometry in ``image``.
 
@@ -710,10 +750,10 @@ class IterativelySubtractedPSFPhotometry(BasicPSFPhotometry):
 
         Parameters
         ----------
-        image : 2D array-like, `~astropy.io.fits.ImageHDU`, \
-                `~astropy.io.fits.HDUList`
-            Image to perform photometry.
-        init_guesses: `~astropy.table.Table`
+        image : 2D `~numpy.ndarray`
+            Image to perform photometry. Invalid data values (i.e., NaN
+            or inf) are automatically ignored.
+        init_guesses : `~astropy.table.Table`
             Table which contains the initial guesses (estimates) for the
             set of parameters. Columns 'x_0' and 'y_0' which represent
             the positions (in pixel coordinates) for each object must be
@@ -726,6 +766,10 @@ class IterativelySubtractedPSFPhotometry(BasicPSFPhotometry):
             ``extra_output_cols`` the initial values are used; if the columns
             specified in ``extra_output_cols`` are not given in
             ``init_guesses`` then NaNs will be returned.
+        mask : 2D bool `~numpy.ndarray`, optional
+            A boolean mask with the same shape as ``image``, where
+            a `True` value indicates the corresponding element of
+            ``image`` is masked.
 
         Returns
         -------
@@ -738,13 +782,16 @@ class IterativelySubtractedPSFPhotometry(BasicPSFPhotometry):
             ``fit_info`` with the key ``param_cov``, which contains the
             covariance matrix.
         """
+        mask = super()._make_mask(image, mask)
+
         if init_guesses is not None:
-            table = super().do_photometry(image, init_guesses)
+            table = super().do_photometry(image, mask=mask,
+                                          init_guesses=init_guesses)
             table['iter_detected'] = np.ones(table['x_fit'].shape, dtype=int)
 
             # n_start = 2 because it starts in the second iteration
             # since the first iteration is above
-            output_table = self._do_photometry(n_start=2)
+            output_table = self._do_photometry(n_start=2, mask=mask)
             output_table = vstack([table, output_table])
         else:
             if self.bkg_estimator is not None:
@@ -755,13 +802,13 @@ class IterativelySubtractedPSFPhotometry(BasicPSFPhotometry):
             if self.aperture_radius is None:
                 self.set_aperture_radius()
 
-            output_table = self._do_photometry()
+            output_table = self._do_photometry(mask=mask)
 
         output_table.meta = {'version': _get_version_info()}
 
         return QTable(output_table)
 
-    def _do_photometry(self, n_start=1):
+    def _do_photometry(self, n_start=1, mask=None):
         """
         Helper function which performs the iterations of the photometry
         process.
@@ -787,17 +834,17 @@ class IterativelySubtractedPSFPhotometry(BasicPSFPhotometry):
             output_table.add_column(Column(name=init_parname))
             output_table.add_column(Column(name=fit_parname))
 
-        sources = self.finder(self._residual_image)
+        sources = self.finder(self._residual_image, mask=mask)
 
         n = n_start
-        while((sources is not None and len(sources) > 0) and
-              (self.niters is None or n <= self.niters)):
+        while ((sources is not None and len(sources) > 0)
+               and (self.niters is None or n <= self.niters)):
             positions = np.transpose((sources['xcentroid'],
                                       sources['ycentroid']))
             apertures = CircularAperture(positions,
                                          r=self.aperture_radius)
             sources['aperture_flux'] = aperture_photometry(
-                self._residual_image, apertures)['aperture_sum']
+                self._residual_image, apertures, mask=mask)['aperture_sum']
 
             init_guess_tab = QTable(names=['id', 'x_0', 'y_0', 'flux_0'],
                                     data=[sources['id'], sources['xcentroid'],
@@ -809,13 +856,12 @@ class IterativelySubtractedPSFPhotometry(BasicPSFPhotometry):
                 if param_tab_name not in (['x_0', 'y_0', 'flux_0']):
                     init_guess_tab.add_column(
                         Column(name=param_tab_name,
-                               data=(getattr(self.psf_model,
-                                             param_name) *
-                                     np.ones(len(sources)))))
+                               data=(getattr(self.psf_model, param_name)
+                                     * np.ones(len(sources)))))
 
             star_groups = self.group_maker(init_guess_tab)
             table, self._residual_image = super().nstar(
-                self._residual_image, star_groups)
+                self._residual_image, star_groups, mask=mask)
 
             star_groups = star_groups.group_by('group_id')
             table = hstack([star_groups, table])
@@ -828,7 +874,7 @@ class IterativelySubtractedPSFPhotometry(BasicPSFPhotometry):
             # do not warn if no sources are found beyond the first iteration
             with warnings.catch_warnings():
                 warnings.simplefilter('ignore', NoDetectionsWarning)
-                sources = self.finder(self._residual_image)
+                sources = self.finder(self._residual_image, mask=mask)
 
             n += 1
 
@@ -947,7 +993,7 @@ class DAOPhotPSFPhotometry(IterativelySubtractedPSFPhotometry):
     """
 
     def __init__(self, crit_separation, threshold, fwhm, psf_model, fitshape,
-                 sigma=3., ratio=1.0, theta=0.0, sigma_radius=1.5,
+                 *, sigma=3., ratio=1.0, theta=0.0, sigma_radius=1.5,
                  sharplo=0.2, sharphi=1.0, roundlo=-1.0, roundhi=1.0,
                  fitter=LevMarLSQFitter(),
                  niters=3, aperture_radius=None, extra_output_cols=None):
