@@ -9,15 +9,17 @@ from astropy.modeling import Fittable2DModel, Parameter
 from astropy.modeling.fitting import LevMarLSQFitter
 from astropy.nddata.utils import extract_array, subpixel_indices
 from astropy.table import Table
+from astropy.utils.decorators import deprecated
 import numpy as np
 
-from ..segmentation._utils import mask_to_mirrored_value
+from ..segmentation.utils import _mask_to_mirrored_value
 
 __all__ = ['DiscretePRF', 'Reproject']
 
 __doctest_requires__ = {('Reproject'): ['gwcs']}
 
 
+@deprecated('1.5.0')
 class DiscretePRF(Fittable2DModel):
     """
     A discrete Pixel Response Function (PRF) model.
@@ -223,8 +225,8 @@ class DiscretePRF(Fittable2DModel):
             positions = np.array(positions)
 
         if isinstance(positions, Table) or \
-                (isinstance(positions, np.ndarray) and
-                 positions.dtype.names is not None):
+                (isinstance(positions, np.ndarray)
+                 and positions.dtype.names is not None):
             # One can do clever things like
             # positions['x_0', 'y_0'].as_array().view((positions['x_0'].dtype,
             #                                          2))
@@ -269,28 +271,29 @@ class DiscretePRF(Fittable2DModel):
                                                   (y, x))
                     # Check shape to exclude incomplete PRFs at the boundaries
                     # of the image
-                    if (extracted_prf.shape == (size, size) and
-                            np.ma.sum(extracted_prf) != 0):
+                    if (extracted_prf.shape == (size, size)
+                            and np.ma.sum(extracted_prf) != 0):
                         # Replace NaN values by mirrored value, with respect
                         # to the prf's center
                         if fix_nan:
                             prf_nan = extracted_prf.mask
                             if prf_nan.any():
-                                if (prf_nan.sum() > 3 or
-                                        prf_nan[size // 2, size // 2]):
+                                if (prf_nan.sum() > 3
+                                        or prf_nan[size // 2, size // 2]):
                                     continue
-                                else:
-                                    extracted_prf = mask_to_mirrored_value(
-                                        extracted_prf, prf_nan,
-                                        (size // 2, size // 2))
+
+                                extracted_prf = _mask_to_mirrored_value(
+                                    extracted_prf, prf_nan,
+                                    (size // 2, size // 2))
+
                         # Normalize and add extracted PRF to data cube
                         if fluxes is None:
-                            extracted_prf_norm = (np.ma.copy(extracted_prf) /
-                                                  np.ma.sum(extracted_prf))
+                            extracted_prf_norm = (np.ma.copy(extracted_prf)
+                                                  / np.ma.sum(extracted_prf))
                         else:
                             fluxes_sub_prfs = fluxes[sub_prf_indices]
-                            extracted_prf_norm = (np.ma.copy(extracted_prf) /
-                                                  fluxes_sub_prfs[k])
+                            extracted_prf_norm = (np.ma.copy(extracted_prf)
+                                                  / fluxes_sub_prfs[k])
                         extracted_sub_prfs.append(extracted_prf_norm)
                     else:
                         continue
@@ -299,6 +302,7 @@ class DiscretePRF(Fittable2DModel):
         return cls(prf_model, subsampling=subsampling)
 
 
+@deprecated('1.5.0')
 class Reproject:
     """
     Class to reproject pixel coordinates between unrectified and
@@ -343,9 +347,9 @@ class Reproject:
         try:
             skycoord = wcs1.pixel_to_world(x, y)
             return wcs2.world_to_pixel(skycoord)
-        except AttributeError:
+        except AttributeError as exc:
             raise ValueError('Input wcs objects do not support the shared '
-                             'WCS interface.')
+                             'WCS interface.') from exc
 
     def to_rectified(self, x, y):
         """
