@@ -9,6 +9,7 @@ from astropy.modeling.fitting import LevMarLSQFitter
 from astropy.nddata import NDData
 from astropy.table import Table
 from astropy.stats import SigmaClip
+from astropy.utils.exceptions import AstropyUserWarning
 import numpy as np
 from numpy.testing import assert_allclose, assert_almost_equal
 import pytest
@@ -26,7 +27,6 @@ class TestEPSFBuild:
         """
         Create a simulated image for testing.
         """
-
         from scipy.spatial import cKDTree
 
         shape = (750, 750)
@@ -68,7 +68,8 @@ class TestEPSFBuild:
 
     def test_extract_stars(self):
         size = 25
-        stars = extract_stars(self.nddata, self.init_stars, size=size)
+        with pytest.warns(AstropyUserWarning, match='were not extracted'):
+            stars = extract_stars(self.nddata, self.init_stars, size=size)
 
         assert len(stars) == 81
         assert isinstance(stars, EPSFStars)
@@ -79,10 +80,10 @@ class TestEPSFBuild:
         """
         This is an end-to-end test of EPSFBuilder on a simulated image.
         """
-
         size = 25
-        oversampling = 4.
-        stars = extract_stars(self.nddata, self.init_stars, size=size)
+        oversampling = 4
+        with pytest.warns(AstropyUserWarning, match='were not extracted'):
+            stars = extract_stars(self.nddata, self.init_stars, size=size)
         epsf_builder = EPSFBuilder(oversampling=oversampling, maxiters=15,
                                    progress_bar=False, norm_radius=25,
                                    recentering_maxiters=15)
@@ -96,31 +97,33 @@ class TestEPSFBuild:
 
         psf_model = IntegratedGaussianPRF(sigma=self.stddev)
         z = epsf.data
-        x = psf_model.evaluate(y.reshape(-1, 1), y.reshape(1, -1), 1, y0, y0, self.stddev)
+        x = psf_model.evaluate(y.reshape(-1, 1), y.reshape(1, -1), 1, y0, y0,
+                               self.stddev)
         assert_allclose(z, x, rtol=1e-2, atol=1e-5)
 
         resid_star = fitted_stars[0].compute_residual_image(epsf)
-        assert_almost_equal(np.sum(resid_star)/fitted_stars[0].flux, 0, decimal=3)
+        assert_almost_equal(np.sum(resid_star) / fitted_stars[0].flux, 0,
+                            decimal=3)
 
     def test_epsf_fitting_bounds(self):
         size = 25
-        oversampling = 4.
-        stars = extract_stars(self.nddata, self.init_stars, size=size)
+        oversampling = 4
+        with pytest.warns(AstropyUserWarning, match='were not extracted'):
+            stars = extract_stars(self.nddata, self.init_stars, size=size)
         epsf_builder = EPSFBuilder(oversampling=oversampling, maxiters=8,
                                    progress_bar=True, norm_radius=25,
                                    recentering_maxiters=5,
-                                   fitter=EPSFFitter(fit_boxsize=30),
+                                   fitter=EPSFFitter(fit_boxsize=31),
                                    smoothing_kernel='quadratic')
         # With a boxsize larger than the cutout we expect the fitting to
         # fail for all stars, due to star._fit_error_status
-        with pytest.raises(ValueError):
+        with pytest.raises(ValueError), pytest.warns(AstropyUserWarning):
             epsf_builder(stars)
 
     def test_epsf_build_invalid_fitter(self):
         """
         Test that the input fitter is an EPSFFitter instance.
         """
-
         with pytest.raises(TypeError):
             EPSFBuilder(fitter=EPSFFitter, maxiters=3)
 
@@ -147,13 +150,12 @@ def test_epsfbuilder_inputs():
     EPSFBuilder(oversampling=[4, 6])
 
     # invalid inputs
-    for sigclip in [None, [], 'a']:
+    for sigma_clip in [None, [], 'a']:
         with pytest.raises(ValueError):
-            EPSFBuilder(flux_residual_sigclip=sigclip)
+            EPSFBuilder(sigma_clip=sigma_clip)
 
     # valid inputs
-    EPSFBuilder(flux_residual_sigclip=SigmaClip(sigma=2.5, cenfunc='mean',
-                                                maxiters=2))
+    EPSFBuilder(sigma_clip=SigmaClip(sigma=2.5, cenfunc='mean', maxiters=2))
 
 
 def test_epsfmodel_inputs():
@@ -163,11 +165,11 @@ def test_epsfmodel_inputs():
 
     data = np.ones((5, 5), dtype=float)
     data[2, 2] = np.inf
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError, match='must be finite'):
         EPSFModel(data)
 
-    data[2, 2] = np.finfo(float).max * 2
-    with pytest.raises(ValueError):
+    data[2, 2] = np.nan
+    with pytest.raises(ValueError, match='must be finite'):
         EPSFModel(data, flux=None)
 
     data[2, 2] = 1
@@ -184,7 +186,7 @@ def test_epsfmodel_inputs():
 @pytest.mark.skipif('not HAS_SCIPY')
 @pytest.mark.parametrize('oversamp', [3, 4])
 def test_epsf_build_oversampling(oversamp):
-    offsets = np.arange(oversamp) * 1./oversamp - 0.5 + 1./(2. * oversamp)
+    offsets = np.arange(oversamp) * 1. / oversamp - 0.5 + 1. / (2. * oversamp)
     xydithers = np.array(list(itertools.product(offsets, offsets)))
     xdithers = np.transpose(xydithers)[0]
     ydithers = np.transpose(xydithers)[1]
@@ -208,7 +210,7 @@ def test_epsf_build_oversampling(oversamp):
     stars = extract_stars(nddata, stars_tbl, size=25)
     epsf_builder = EPSFBuilder(oversampling=oversamp, maxiters=15,
                                progress_bar=False, recentering_maxiters=20)
-    epsf, fitted_stars = epsf_builder(stars)
+    epsf, _ = epsf_builder(stars)
 
     # input PSF shape
     size = epsf.data.shape[0]
@@ -218,4 +220,4 @@ def test_epsf_build_oversampling(oversamp):
     yy, xx = np.mgrid[0:size, 0:size]
     psf = m(xx, yy)
 
-    assert_allclose(epsf.data, psf*epsf.data.sum(), atol=2.5e-4)
+    assert_allclose(epsf.data, psf * epsf.data.sum(), atol=2.5e-4)
