@@ -10,14 +10,9 @@ import numpy as np
 from numpy.testing import assert_allclose
 import pytest
 
-from ..epsf_stars import extract_stars, EPSFStar, EPSFStars
+from ..epsf_stars import extract_stars, EPSFStars
 from ..models import EPSFModel, IntegratedGaussianPRF
-
-try:
-    import scipy  # noqa
-    HAS_SCIPY = True
-except ImportError:
-    HAS_SCIPY = False
+from ...utils._optional_deps import HAS_SCIPY  # noqa
 
 
 @pytest.mark.skipif('not HAS_SCIPY')
@@ -41,7 +36,7 @@ class TestExtractStars:
         stars = extract_stars(self.nddata, self.stars_tbl, size=size)
         assert len(stars) == 4
         assert isinstance(stars, EPSFStars)
-        assert isinstance(stars[0], EPSFStar)
+        assert isinstance(stars[0], EPSFStars)
         assert stars[0].data.shape == (size, size)
         assert stars.n_stars == stars.n_all_stars
         assert stars.n_stars == stars.n_good_stars
@@ -68,7 +63,7 @@ def test_epsf_star_residual_image():
     """
 
     size = 100
-    yy, xx, = np.mgrid[0:size+1, 0:size+1] / 4
+    yy, xx, = np.mgrid[0:size + 1, 0:size + 1] / 4
     gmodel = IntegratedGaussianPRF().evaluate(xx, yy, 1, 12.5, 12.5, 2.5)
     epsf = EPSFModel(gmodel, oversampling=4, norm_radius=100)
     _size = 25
@@ -80,8 +75,20 @@ def test_epsf_star_residual_image():
     tbl['y'] = [12]
     stars = extract_stars(NDData(data), tbl, size=23)
     residual = stars[0].compute_residual_image(epsf)
-    # As current EPSFStar instances cannot accept IntegratedGaussianPRF as input,
-    # we have to accept some loss of precision from the conversion to ePSF, and
-    # spline fitting (twice), so assert_allclose cannot be more more precise than
-    # 0.001 currently.
+    # As current EPSFStar instances cannot accept IntegratedGaussianPRF
+    # as input, we have to accept some loss of precision from the
+    # conversion to ePSF, and spline fitting (twice), so assert_allclose
+    # cannot be more more precise than 0.001 currently.
     assert_allclose(np.sum(residual), 0., atol=1.e-3, rtol=1e-3)
+
+
+def test_stars_pickleable():
+    """
+    Verify that EPSFStars can be successfully
+    pickled/unpickled for use multiprocessing
+    """
+    from multiprocessing.reduction import ForkingPickler
+    # Doesn't need to actually contain anything useful
+    stars = EPSFStars([1])
+    # This should not blow up
+    ForkingPickler.loads(ForkingPickler.dumps(stars))
