@@ -9,8 +9,8 @@ from astropy.modeling.fitting import LevMarLSQFitter, SimplexLSQFitter
 from astropy.modeling.models import Gaussian2D, Moffat2D
 from astropy.stats import SigmaClip, gaussian_sigma_to_fwhm
 from astropy.table import Table
-from astropy.tests.helper import catch_warnings
-from astropy.utils.exceptions import AstropyUserWarning
+from astropy.utils.exceptions import (AstropyUserWarning,
+                                      AstropyDeprecationWarning)
 import numpy as np
 from numpy.testing import assert_allclose, assert_array_equal, assert_equal
 import pytest
@@ -115,11 +115,11 @@ def test_psf_photometry_niters(sigma_psf, sources):
     img_shape = (32, 32)
     # generate image with read-out noise (Gaussian) and
     # background noise (Poisson)
-    image = (make_gaussian_prf_sources_image(img_shape, sources) +
-             make_noise_image(img_shape, distribution='poisson', mean=6.,
-                              seed=0) +
-             make_noise_image(img_shape, distribution='gaussian', mean=0.,
-                              stddev=2., seed=0))
+    image = (make_gaussian_prf_sources_image(img_shape, sources)
+             + make_noise_image(img_shape, distribution='poisson', mean=6.,
+                                seed=0)
+             + make_noise_image(img_shape, distribution='gaussian', mean=0.,
+                                stddev=2., seed=0))
     cp_image = image.copy()
     sigma_clip = SigmaClip(sigma=3.)
     bkgrms = StdBackgroundRMS(sigma_clip)
@@ -132,12 +132,12 @@ def test_psf_photometry_niters(sigma_psf, sources):
         result_tab = iter_phot_obj(image)
         residual_image = iter_phot_obj.get_residual_image()
 
-        assert (result_tab['x_0_unc'] < 1.96 * sigma_psf /
-                np.sqrt(sources['flux'])).all()
-        assert (result_tab['y_0_unc'] < 1.96 * sigma_psf /
-                np.sqrt(sources['flux'])).all()
-        assert (result_tab['flux_unc'] < 1.96 *
-                np.sqrt(sources['flux'])).all()
+        assert (result_tab['x_0_unc'] < 1.96 * sigma_psf
+                / np.sqrt(sources['flux'])).all()
+        assert (result_tab['y_0_unc'] < 1.96 * sigma_psf
+                / np.sqrt(sources['flux'])).all()
+        assert (result_tab['flux_unc'] < 1.96
+                * np.sqrt(sources['flux'])).all()
 
         assert_allclose(result_tab['x_fit'], sources['x_0'], rtol=1e-1)
         assert_allclose(result_tab['y_fit'], sources['y_0'], rtol=1e-1)
@@ -152,6 +152,9 @@ def test_psf_photometry_niters(sigma_psf, sources):
         assert_array_equal(cp_image, image)
 
 
+@pytest.mark.filterwarnings('ignore:Both init_guesses and finder are '
+                            'different than None')
+@pytest.mark.filterwarnings('ignore:No sources were found')
 @pytest.mark.skipif('not HAS_SCIPY')
 @pytest.mark.parametrize("sigma_psf, sources",
                          [(sigma_psfs[0], sources1),
@@ -171,11 +174,11 @@ def test_psf_photometry_oneiter(sigma_psf, sources):
     img_shape = (32, 32)
     # generate image with read-out noise (Gaussian) and
     # background noise (Poisson)
-    image = (make_gaussian_prf_sources_image(img_shape, sources) +
-             make_noise_image(img_shape, distribution='poisson', mean=6.,
-                              seed=0) +
-             make_noise_image(img_shape, distribution='gaussian', mean=0.,
-                              stddev=2., seed=0))
+    image = (make_gaussian_prf_sources_image(img_shape, sources)
+             + make_noise_image(img_shape, distribution='poisson', mean=6.,
+                                seed=0)
+             + make_noise_image(img_shape, distribution='gaussian', mean=0.,
+                                stddev=2., seed=0))
     cp_image = image.copy()
 
     sigma_clip = SigmaClip(sigma=3.)
@@ -186,12 +189,12 @@ def test_psf_photometry_oneiter(sigma_psf, sources):
     for phot_proc in phot_objs:
         result_tab = phot_proc(image)
         residual_image = phot_proc.get_residual_image()
-        assert (result_tab['x_0_unc'] < 1.96 * sigma_psf /
-                np.sqrt(sources['flux'])).all()
-        assert (result_tab['y_0_unc'] < 1.96 * sigma_psf /
-                np.sqrt(sources['flux'])).all()
-        assert (result_tab['flux_unc'] < 1.96 *
-                np.sqrt(sources['flux'])).all()
+        assert (result_tab['x_0_unc'] < 1.96 * sigma_psf
+                / np.sqrt(sources['flux'])).all()
+        assert (result_tab['y_0_unc'] < 1.96 * sigma_psf
+                / np.sqrt(sources['flux'])).all()
+        assert (result_tab['flux_unc'] < 1.96
+                * np.sqrt(sources['flux'])).all()
         assert_allclose(result_tab['x_fit'], sources['x_0'], rtol=1e-1)
         assert_allclose(result_tab['y_fit'], sources['y_0'], rtol=1e-1)
         assert_allclose(result_tab['flux_fit'], sources['flux'], rtol=1e-1)
@@ -207,12 +210,12 @@ def test_psf_photometry_oneiter(sigma_psf, sources):
                                                 sources['y_0']])
         cp_pos = pos.copy()
 
-        result_tab = phot_proc(image, pos)
+        result_tab = phot_proc(image, init_guesses=pos)
         residual_image = phot_proc.get_residual_image()
         assert 'x_0_unc' not in result_tab.colnames
         assert 'y_0_unc' not in result_tab.colnames
-        assert (result_tab['flux_unc'] < 1.96 *
-                np.sqrt(sources['flux'])).all()
+        assert (result_tab['flux_unc'] < 1.96
+                * np.sqrt(sources['flux'])).all()
         assert_array_equal(result_tab['x_fit'], sources['x_0'])
         assert_array_equal(result_tab['y_fit'], sources['y_0'])
         assert_allclose(result_tab['flux_fit'], sources['flux'], rtol=1e-1)
@@ -307,33 +310,35 @@ def test_finder_positions_warning():
     positions['x_0'] = [12.8, 18.2, 25.3]
     positions['y_0'] = [15.7, 16.5, 25.1]
 
-    image = (make_gaussian_prf_sources_image((32, 32), sources1) +
-             make_noise_image((32, 32), distribution='poisson', mean=6.,
-                              seed=0))
+    image = (make_gaussian_prf_sources_image((32, 32), sources1)
+             + make_noise_image((32, 32), distribution='poisson', mean=6.,
+                                seed=0))
 
-    with catch_warnings(AstropyUserWarning):
+    with pytest.warns(AstropyUserWarning, match='Both init_guesses and '
+                      'finder are different than None'):
         result_tab = basic_phot_obj(image=image, init_guesses=positions)
-        assert_array_equal(result_tab['x_0'], positions['x_0'])
-        assert_array_equal(result_tab['y_0'], positions['y_0'])
-        assert_allclose(result_tab['x_fit'], positions['x_0'], rtol=1e-1)
-        assert_allclose(result_tab['y_fit'], positions['y_0'], rtol=1e-1)
+    assert_array_equal(result_tab['x_0'], positions['x_0'])
+    assert_array_equal(result_tab['y_0'], positions['y_0'])
+    assert_allclose(result_tab['x_fit'], positions['x_0'], rtol=1e-1)
+    assert_allclose(result_tab['y_fit'], positions['y_0'], rtol=1e-1)
 
+    basic_phot_obj.finder = None
     with pytest.raises(ValueError):
-        basic_phot_obj.finder = None
         result_tab = basic_phot_obj(image=image)
 
 
+@pytest.mark.filterwarnings('ignore:The fit may be unsuccessful')
 @pytest.mark.skipif('not HAS_SCIPY')
 def test_aperture_radius():
     img_shape = (32, 32)
 
     # generate image with read-out noise (Gaussian) and
     # background noise (Poisson)
-    image = (make_gaussian_prf_sources_image(img_shape, sources1) +
-             make_noise_image(img_shape, distribution='poisson', mean=6.,
-                              seed=0) +
-             make_noise_image(img_shape, distribution='gaussian', mean=0.,
-                              stddev=2., seed=0))
+    image = (make_gaussian_prf_sources_image(img_shape, sources1)
+             + make_noise_image(img_shape, distribution='poisson', mean=6.,
+                                seed=0)
+             + make_noise_image(img_shape, distribution='gaussian', mean=0.,
+                                stddev=2., seed=0))
 
     basic_phot_obj = make_psf_photometry_objs()[0]
 
@@ -428,12 +433,14 @@ for x, y, flux in WIDE_INTAB:
 @pytest.mark.skipif('not HAS_SCIPY')
 def test_psf_photometry_discrete():
     """ Test psf_photometry with discrete PRF model. """
-
-    prf = DiscretePRF(test_psf, subsampling=1)
+    with pytest.warns(AstropyDeprecationWarning):
+        prf = DiscretePRF(test_psf, subsampling=1)
     basic_phot = BasicPSFPhotometry(group_maker=DAOGroup(2),
                                     bkg_estimator=None, psf_model=prf,
                                     fitshape=7)
-    f = basic_phot(image=image, init_guesses=INTAB)
+    with pytest.warns(AstropyUserWarning, match='aperture_radius is None and '
+                      'could not be determined by psf_model'):
+        f = basic_phot(image=image, init_guesses=INTAB)
 
     for n in ['x', 'y', 'flux']:
         assert_allclose(f[n + '_0'], f[n + '_fit'], rtol=1e-6)
@@ -445,8 +452,8 @@ def test_tune_coordinates():
     Test psf_photometry with discrete PRF model and coordinates that need
     to be adjusted in the fit.
     """
-
-    prf = DiscretePRF(test_psf, subsampling=1)
+    with pytest.warns(AstropyDeprecationWarning):
+        prf = DiscretePRF(test_psf, subsampling=1)
     prf.x_0.fixed = False
     prf.y_0.fixed = False
     # Shift all sources by 0.3 pixels
@@ -457,7 +464,9 @@ def test_tune_coordinates():
                                     bkg_estimator=None, psf_model=prf,
                                     fitshape=7)
 
-    f = basic_phot(image=image, init_guesses=intab)
+    with pytest.warns(AstropyUserWarning, match='aperture_radius is None and '
+                      'could not be determined by psf_model'):
+        f = basic_phot(image=image, init_guesses=intab)
     for n in ['x', 'y', 'flux']:
         assert_allclose(f[n + '_0'], f[n + '_fit'], rtol=1e-3)
 
@@ -467,8 +476,8 @@ def test_psf_boundary():
     """
     Test psf_photometry with discrete PRF model at the boundary of the data.
     """
-
-    prf = DiscretePRF(test_psf, subsampling=1)
+    with pytest.warns(AstropyDeprecationWarning):
+        prf = DiscretePRF(test_psf, subsampling=1)
 
     basic_phot = BasicPSFPhotometry(group_maker=DAOGroup(2),
                                     bkg_estimator=None, psf_model=prf,
@@ -485,7 +494,7 @@ def test_default_aperture_radius():
     Test psf_photometry with non-Gaussian model, such that it raises a
     warning about aperture_radius.
     """
-    def tophatfinder(image):
+    def tophatfinder(image, mask=None):
         """ Simple top hat finder function for use with a top hat PRF"""
         fluxes = np.unique(image[image > 1])
         table = Table(names=['id', 'xcentroid', 'ycentroid', 'flux'],
@@ -494,13 +503,13 @@ def test_default_aperture_radius():
             ys, xs = np.where(image == f)
             x = np.mean(xs)
             y = np.mean(ys)
-            table.add_row([int(n+1), x, y, f*9])
+            table.add_row([int(n + 1), x, y, f * 9])
         table.sort(['flux'])
 
         return table
 
     prf = np.zeros((7, 7), float)
-    prf[2:5, 2:5] = 1/9
+    prf[2:5, 2:5] = 1 / 9
     prf = FittableImageModel(prf)
 
     img = np.zeros((50, 50), float)
@@ -508,7 +517,7 @@ def test_default_aperture_radius():
     y0 = [20, 5, 40]
     f0 = [50, 100, 200]
     for x, y, f in zip(x0, y0, f0):
-        img[y-1:y+2, x-1:x+2] = f/9
+        img[y - 1:y + 2, x - 1:x + 2] = f / 9
 
     intab = Table(data=[[37, 19.6, 34.9], [19.6, 4.5, 40.1]],
                   names=['x_0', 'y_0'])
@@ -563,7 +572,6 @@ def test_psf_boundary_gaussian():
     """
     Test psf_photometry with discrete PRF model at the boundary of the data.
     """
-
     psf = IntegratedGaussianPRF(GAUSSIAN_WIDTH)
 
     basic_phot = BasicPSFPhotometry(group_maker=DAOGroup(2),
@@ -580,7 +588,6 @@ def test_psf_photometry_gaussian():
     """
     Test psf_photometry with Gaussian PSF model.
     """
-
     psf = IntegratedGaussianPRF(sigma=GAUSSIAN_WIDTH)
 
     basic_phot = BasicPSFPhotometry(group_maker=DAOGroup(2),
@@ -597,7 +604,6 @@ def test_psf_photometry_gaussian2(renormalize_psf):
     """
     Test psf_photometry with Gaussian PSF model from Astropy.
     """
-
     psf = Gaussian2D(1. / (2 * np.pi * GAUSSIAN_WIDTH ** 2), PSF_SIZE // 2,
                      PSF_SIZE // 2, GAUSSIAN_WIDTH, GAUSSIAN_WIDTH)
     psf = prepare_psf_model(psf, xname='x_mean', yname='y_mean',
@@ -606,7 +612,9 @@ def test_psf_photometry_gaussian2(renormalize_psf):
     basic_phot = BasicPSFPhotometry(group_maker=DAOGroup(2),
                                     bkg_estimator=None, psf_model=psf,
                                     fitshape=7)
-    f = basic_phot(image=image, init_guesses=INTAB)
+    with pytest.warns(AstropyUserWarning, match='aperture_radius is None and '
+                      'could not be determined by psf_model'):
+        f = basic_phot(image=image, init_guesses=INTAB)
 
     for n in ['x', 'y']:
         assert_allclose(f[n + '_0'], f[n + '_fit'], rtol=1e-1)
@@ -618,7 +626,6 @@ def test_psf_photometry_moffat():
     """
     Test psf_photometry with Moffat PSF model from Astropy.
     """
-
     psf = Moffat2D(1. / (2 * np.pi * GAUSSIAN_WIDTH ** 2), PSF_SIZE // 2,
                    PSF_SIZE // 2, 1, 1)
     psf = prepare_psf_model(psf, xname='x_0', yname='y_0',
@@ -627,7 +634,9 @@ def test_psf_photometry_moffat():
     basic_phot = BasicPSFPhotometry(group_maker=DAOGroup(2),
                                     bkg_estimator=None, psf_model=psf,
                                     fitshape=7)
-    f = basic_phot(image=image, init_guesses=INTAB)
+    with pytest.warns(AstropyUserWarning, match='aperture_radius is None and '
+                      'could not be determined by psf_model'):
+        f = basic_phot(image=image, init_guesses=INTAB)
     f.pprint(max_width=-1)
 
     for n in ['x', 'y']:
@@ -642,7 +651,6 @@ def test_psf_fitting_data_on_edge():
     No mask is input explicitly here, but source 2 is so close to the
     edge that the subarray that's extracted gets a mask internally.
     """
-
     psf_guess = IntegratedGaussianPRF(flux=1, sigma=WIDE_GAUSSIAN_WIDTH)
     psf_guess.flux.fixed = psf_guess.x_0.fixed = psf_guess.y_0.fixed = False
     basic_phot = BasicPSFPhotometry(group_maker=DAOGroup(2),
@@ -656,20 +664,21 @@ def test_psf_fitting_data_on_edge():
                         rtol=0.05, atol=0.1)
 
 
+@pytest.mark.filterwarnings('ignore:Both init_guesses and finder '
+                            'are different than None')
 @pytest.mark.skipif('not HAS_SCIPY')
 @pytest.mark.parametrize("sigma_psf, sources", [(sigma_psfs[2], sources3)])
 def test_psf_extra_output_cols(sigma_psf, sources):
     """
     Test the handling of a non-None extra_output_cols
     """
-
     psf_model = IntegratedGaussianPRF(sigma=sigma_psf)
     tshape = (32, 32)
-    image = (make_gaussian_prf_sources_image(tshape, sources) +
-             make_noise_image(tshape, distribution='poisson', mean=6.,
-                              seed=0) +
-             make_noise_image(tshape, distribution='gaussian', mean=0.,
-                              stddev=2., seed=0))
+    image = (make_gaussian_prf_sources_image(tshape, sources)
+             + make_noise_image(tshape, distribution='poisson', mean=6.,
+                                seed=0)
+             + make_noise_image(tshape, distribution='gaussian', mean=0.,
+                                stddev=2., seed=0))
 
     init_guess1 = None
     init_guess2 = Table(names=['x_0', 'y_0', 'sharpness', 'roundness1',
@@ -708,9 +717,9 @@ def test_psf_extra_output_cols(sigma_psf, sources):
 
 @pytest.fixture(params=[2, 3])
 def overlap_image(request):
-
     if request.param == 2:
-        close_tab = Table([[50., 53.], [50., 50.], [25., 25.]], names=['x_0', 'y_0', 'flux_0'])
+        close_tab = Table([[50., 53.], [50., 50.], [25., 25.]],
+                          names=['x_0', 'y_0', 'flux_0'])
     elif request.param == 3:
         close_tab = Table([[50., 55., 50.], [50., 50., 55.], [25., 25., 25.]],
                           names=['x_0', 'y_0', 'flux_0'])
@@ -722,20 +731,24 @@ def overlap_image(request):
     for x, y, flux in close_tab:
         close_model = Gaussian2D(flux / (2 * np.pi * GAUSSIAN_WIDTH ** 2),
                                  x, y, GAUSSIAN_WIDTH, GAUSSIAN_WIDTH)
-        close_image += discretize_model(close_model, (0, IMAGE_SIZE), (0, IMAGE_SIZE),
-                                        mode='oversample')
+        close_image += discretize_model(close_model, (0, IMAGE_SIZE),
+                                        (0, IMAGE_SIZE), mode='oversample')
     return close_image
 
 
 @pytest.mark.skipif('not HAS_SCIPY')
 def test_psf_fitting_group(overlap_image):
-    """ Test psf_photometry when two input stars are close and need to be fit together """
+    """
+    Test psf_photometry when two input stars are close and need to be
+    fit together.
+    """
     from photutils.background import MADStdBackgroundRMS
 
     # There are a few models here that fail, be it something
     # created by EPSFBuilder or simpler the Moffat2D one
     # unprepared_psf = Moffat2D(amplitude=1, gamma=2, alpha=2.8, x_0=0, y_0=0)
-    # psf = prepare_psf_model(unprepared_psf, xname='x_0', yname='y_0', fluxname=None)
+    # psf = prepare_psf_model(unprepared_psf, xname='x_0', yname='y_0',
+    #                         fluxname=None)
     psf = prepare_psf_model(Gaussian2D(), renormalize_psf=False)
 
     psf.fwhm = Parameter('fwhm', 'this is not the way to add this I think')
@@ -760,7 +773,7 @@ def test_finder_return_none():
     Test psf_photometry with finder that does not return None if no
     sources are detected, to test Iterative PSF fitting.
     """
-    def tophatfinder(image):
+    def tophatfinder(image, mask=None):
         """ Simple top hat finder function for use with a top hat PRF"""
         fluxes = np.unique(image[image > 1])
         table = Table(names=['id', 'xcentroid', 'ycentroid', 'flux'],
@@ -795,7 +808,9 @@ def test_finder_return_none():
                                                    fitshape=7, niters=2,
                                                    aperture_radius=3)
 
-    results = iter_phot(image=img, init_guesses=intab)
+    with pytest.warns(AstropyUserWarning, match='Both init_guesses and finder '
+                      'are different than None'):
+        results = iter_phot(image=img, init_guesses=intab)
     assert_allclose(results['flux_fit'], f0, rtol=0.05)
 
 
@@ -812,7 +827,8 @@ def test_psf_photometry_uncertainties():
                                     bkg_estimator=None, psf_model=psf,
                                     fitter=SimplexLSQFitter(),
                                     fitshape=7)
-    phot_tbl = basic_phot(image=image, init_guesses=INTAB)
+    with pytest.warns(AstropyUserWarning, match='The fit may be unsuccessful'):
+        phot_tbl = basic_phot(image=image, init_guesses=INTAB)
     columns = ('flux_unc', 'x_0_unc', 'y_0_unc')
     for column in columns:
         assert column not in phot_tbl.colnames
@@ -820,21 +836,60 @@ def test_psf_photometry_uncertainties():
 
 @pytest.mark.skipif('not HAS_SCIPY')
 def test_re_use_result_as_initial_guess():
-
     img_shape = (32, 32)
     # generate image with read-out noise (Gaussian) and
     # background noise (Poisson)
-    image = (make_gaussian_prf_sources_image(img_shape, sources1) +
-             make_noise_image(img_shape, distribution='poisson', mean=6.,
-                              seed=0) +
-             make_noise_image(img_shape, distribution='gaussian', mean=0.,
-                              stddev=2., seed=0))
+    image = (make_gaussian_prf_sources_image(img_shape, sources1)
+             + make_noise_image(img_shape, distribution='poisson', mean=6.,
+                                seed=0)
+             + make_noise_image(img_shape, distribution='gaussian', mean=0.,
+                                stddev=2., seed=0))
 
     _, _, dao_phot_obj = make_psf_photometry_objs()
 
-    result_table = dao_phot_obj(image)
+    with pytest.warns(AstropyUserWarning, match='The fit may be unsuccessful'):
+        result_table = dao_phot_obj(image)
     result_table['x'] = result_table['x_fit']
     result_table['y'] = result_table['y_fit']
     result_table['flux'] = result_table['flux_fit']
-    second_result = dao_phot_obj(image, result_table)
+    with pytest.warns(AstropyUserWarning, match='Both init_guesses and finder '
+                      'are different than None'):
+        second_result = dao_phot_obj(image, init_guesses=result_table)
     assert second_result
+
+
+@pytest.mark.skipif('not HAS_SCIPY')
+def test_photometry_mask_nan():
+    size = 64
+    sources1 = Table()
+    sources1['flux'] = [800]
+    sources1['x_0'] = [size / 2]
+    sources1['y_0'] = [size / 2]
+    sources1['sigma'] = [6]
+    sources1['theta'] = [0]
+
+    img_shape = (size, size)
+    data = make_gaussian_prf_sources_image(img_shape, sources1)
+    data[30, 20:40] = np.nan
+
+    daogroup = DAOGroup(3.)
+    psf_model = IntegratedGaussianPRF(sigma=2.)
+    psfphot = BasicPSFPhotometry(group_maker=daogroup, finder=None,
+                                 bkg_estimator=None, psf_model=psf_model,
+                                 fitshape=(11, 11))
+
+    init = Table()
+    init['x_0'] = [30]
+    init['y_0'] = [30]
+    init['flux_0'] = [200.]
+
+    mask = ~np.isfinite(data)
+    tbl = psfphot(data, init_guesses=init, mask=mask)
+    assert tbl['x_fit'] != init['x_0']
+    assert tbl['y_fit'] != init['y_0']
+    assert tbl['flux_fit'] != init['flux_0']
+
+    with pytest.warns(AstropyUserWarning, match='Input data contains unmasked '
+                      'non-finite values'):
+        tbl2 = psfphot(data, init_guesses=init)
+        assert tbl == tbl2
