@@ -6,6 +6,7 @@ Tests for the utils module.
 from astropy.convolution.utils import discretize_model
 from astropy.modeling.models import Gaussian2D
 from astropy.table import Table
+from astropy.utils.exceptions import AstropyDeprecationWarning
 import numpy as np
 from numpy.testing import assert_allclose
 import pytest
@@ -55,14 +56,14 @@ def moffimg():
     mof = Moffat2D(alpha=4.8)
 
     # this is the analytic value needed to get a total flux of 1
-    mof.amplitude = (mof.alpha-1)/(np.pi*mof.gamma**2)
+    mof.amplitude = (mof.alpha - 1) / (np.pi * mof.gamma**2)
 
     # first make sure it really is normalized
     assert (1 - integrate.dblquad(mof, -10, 10,
                                   lambda x: -10, lambda x: 10)[0]) < 1e-6
 
     # now create an "image" of the PSF
-    xg, yg = np.meshgrid(*([np.linspace(-2, 2, 100)]*2))
+    xg, yg = np.meshgrid(*([np.linspace(-2, 2, 100)] * 2))
 
     return mof, (xg, yg, mof(xg, yg))
 
@@ -79,7 +80,7 @@ def test_moffat_fitting(moffimg):
 
     # a closeish-but-wrong "guessed Moffat"
     guess_moffat = Moffat2D(x_0=.1, y_0=-.05, gamma=1.05,
-                            amplitude=mof.amplitude*1.06, alpha=4.75)
+                            amplitude=mof.amplitude * 1.06, alpha=4.75)
 
     f = LevMarLSQFitter()
 
@@ -114,7 +115,7 @@ def test_prepare_psf_model(moffimg, prepkwargs, tols):
 
     # a close-but-wrong "guessed Moffat"
     guess_moffat = Moffat2D(x_0=.1, y_0=-.05, gamma=1.01,
-                            amplitude=mof.amplitude*1.01, alpha=4.79)
+                            amplitude=mof.amplitude * 1.01, alpha=4.79)
     if prepkwargs['renormalize_psf']:
         # definitely very wrong, so this ensures the re-normalization
         # stuff works
@@ -143,6 +144,8 @@ def test_prepare_psf_model(moffimg, prepkwargs, tols):
         assert fit_psfmod.psfmodel.amplitude == guess_moffat.amplitude
 
 
+@pytest.mark.filterwarnings('ignore:aperture_radius is None and could not '
+                            'be determined by psf_model')
 @pytest.mark.skipif('not HAS_SCIPY')
 def test_prepare_psf_model_offset():
     """
@@ -248,8 +251,8 @@ def test_get_grouped_psf_model_submodel_names(prf_model):
 @pytest.mark.skipif('not HAS_SCIPY')
 def test_subtract_psf():
     """Test subtract_psf."""
-
-    prf = DiscretePRF(test_psf, subsampling=1)
+    with pytest.warns(AstropyDeprecationWarning):
+        prf = DiscretePRF(test_psf, subsampling=1)
     posflux = INTAB.copy()
     for n in posflux.colnames:
         posflux.rename_column(n, n.split('_')[0] + '_fit')
