@@ -5,8 +5,11 @@ segment within a segmentation image.
 """
 
 from copy import deepcopy
+import inspect
+import warnings
 
 from astropy.utils import lazyproperty
+from astropy.utils.exceptions import AstropyUserWarning
 import numpy as np
 
 from ..aperture import BoundingBox
@@ -24,15 +27,16 @@ class SegmentationImage:
 
     Parameters
     ----------
-    data : array_like (int)
-        A segmentation array where source regions are labeled by
-        different positive integer values.  A value of zero is reserved
-        for the background.  The segmentation image must contain at
-        least one non-zero pixel and must not contain any non-finite
-        values (e.g., NaN, inf).
+    data : 2D int `~numpy.ndarray`
+        A 2D segmentation array where source regions are labeled by
+        different positive integer values. A value of zero is reserved
+        for the background. The segmentation image must have integer
+        type.
     """
 
     def __init__(self, data):
+        if not isinstance(data, np.ndarray):
+            raise TypeError('input data must be a numpy ndarray')
         self.data = data
 
     def __str__(self):
@@ -58,15 +62,6 @@ class SegmentationImage:
         """
         return self._data
 
-    @lazyproperty
-    def _cmap(self):
-        """
-        A matplotlib colormap consisting of (random) muted colors.
-
-        This is very useful for plotting the segmentation array.
-        """
-        return self.make_cmap(background_color='#000000', seed=0)
-
     @staticmethod
     def _get_labels(data):
         """
@@ -114,26 +109,37 @@ class SegmentationImage:
         """The segmentation array."""
         return self._data
 
+    @property
+    def _lazyproperties(self):
+        """
+        A list of all class lazyproperties (even in superclasses).
+        """
+        def islazyproperty(obj):
+            return isinstance(obj, lazyproperty)
+
+        return [i[0] for i in inspect.getmembers(self.__class__,
+                                                 predicate=islazyproperty)]
+
+    def _reset_lazyproperties(self):
+        for key in self._lazyproperties:
+            self.__dict__.pop(key, None)
+
     @data.setter
     def data(self, value):
-        if np.any(~np.isfinite(value)):
-            raise ValueError('data must not contain any non-finite values '
-                             '(e.g., NaN, inf)')
+        if not np.issubdtype(value.dtype, np.integer):
+            raise TypeError('data must be have integer type')
 
-        value = np.asarray(value, dtype=int)
-        if not np.any(value):
-            raise ValueError('The segmentation image must contain at least '
-                             'one non-zero pixel.')
-
-        if np.min(value) < 0:
+        labels = self._get_labels(value)  # array([]) if value all zeros
+        if labels.shape != (0,) and np.min(labels) < 0:
             raise ValueError('The segmentation image cannot contain '
                              'negative integers.')
 
         if '_data' in self.__dict__:
-            # needed only when data is reassigned, not on init
-            self.__dict__ = {}
+            # reset cached properties when data is reassigned, but not on init
+            self._reset_lazyproperties()
 
         self._data = value  # pylint: disable=attribute-defined-outside-init
+        self.__dict__['labels'] = labels
 
     @lazyproperty
     def data_ma(self):
@@ -156,7 +162,16 @@ class SegmentationImage:
     @lazyproperty
     def labels(self):
         """The sorted non-zero labels in the segmentation array."""
-        return self._get_labels(self.data)
+        if '_raw_slices' in self.__dict__:
+            labels_all = np.arange(len(self._raw_slices)) + 1
+            labels = []
+            # if a label is missing, raw_slices will be None instead of a slice
+            for label, slc in zip(labels_all, self._raw_slices):
+                if slc is not None:
+                    labels.append(label)
+            return np.array(labels)
+        else:
+            return self._get_labels(self.data)
 
     @lazyproperty
     def nlabels(self):
@@ -165,7 +180,9 @@ class SegmentationImage:
 
     @lazyproperty
     def max_label(self):
-        """The maximum non-zero label in the segmentation array."""
+        """The maximum label in the segmentation array."""
+        if self.nlabels == 0:
+            return 0
         return np.max(self.labels)
 
     def get_index(self, label):
@@ -214,6 +231,11 @@ class SegmentationImage:
         self.check_labels(labels)
         return np.searchsorted(self.labels, labels)
 
+    @lazyproperty
+    def _raw_slices(self):
+        from scipy.ndimage import find_objects
+        return find_objects(self.data)
+
     @lazyproperty
     def slices(self):
         """
@@ -224,9 +246,7 @@ class SegmentationImage:
         has a length equal to the number of labels and matches the order
         of the ``labels`` attribute.
         """
-        from scipy.ndimage import find_objects
-
-        return [slc for slc in find_objects(self._data) if slc is not None]
+        return [slc for slc in self._raw_slices if slc is not None]
 
     @lazyproperty
     def bbox(self):
@@ -245,7 +265,7 @@ class SegmentationImage:
     @lazyproperty
     def background_area(self):
         """The area (in pixel**2) of the background (label=0) region."""
-        return len(self.data[self.data == 0])
+        return self._data.size - np.count_nonzero(self._data)
 
     @lazyproperty
     def areas(self):
@@ -257,9 +277,10 @@ class SegmentationImage:
         returned array has a length equal to the number of labels and
         matches the order of the ``labels`` attribute.
         """
-        return np.array([area
-                         for area in np.bincount(self.data.ravel())[1:]
-                         if area != 0])
+        areas = []
+        for label, slices in zip(self.labels, self.slices):
+            areas.append(np.count_nonzero(self._data[slices] == label))
+        return np.array(areas)
 
     def get_area(self, label):
         """
@@ -272,10 +293,10 @@ class SegmentationImage:
 
         Returns
         -------
-        area : `~numpy.ndarray`
+        area : float
             The area of the labeled region.
         """
-        return self.get_areas(label)
+        return self.get_areas(label)[0]
 
     def get_areas(self, labels):
         """
@@ -292,17 +313,19 @@ class SegmentationImage:
         areas : `~numpy.ndarray`
             The areas of the labeled regions.
         """
-        idx = self.get_indices(labels)
+        idx = self.get_indices(np.atleast_1d(labels))
         return self.areas[idx]
 
     @lazyproperty
     def is_consecutive(self):
         """
-        Determine whether or not the non-zero labels in the segmentation
-        array are consecutive and start from 1.
+        Boolean value indicating whether or not the non-zero labels in
+        the segmentation array are consecutive and start from 1.
         """
-        return ((self.labels[-1] - self.labels[0] + 1) == self.nlabels and
-                self.labels[0] == 1)
+        if self.nlabels == 0:
+            return False
+        return ((self.labels[-1] - self.labels[0] + 1) == self.nlabels
+                and self.labels[0] == 1)
 
     @lazyproperty
     def missing_labels(self):
@@ -364,50 +387,66 @@ class SegmentationImage:
         if bad_labels:
             if len(bad_labels) == 1:
                 raise ValueError(f'label {bad_labels} is invalid')
-            else:
-                raise ValueError(f'labels {bad_labels} are invalid')
+            raise ValueError(f'labels {bad_labels} are invalid')
 
-    def make_cmap(self, background_color='#000000', seed=None):
+    def make_cmap(self, background_color='#000000ff', seed=None):
         """
         Define a matplotlib colormap consisting of (random) muted
         colors.
 
-        This is very useful for plotting the segmentation array.
+        This is useful for plotting the segmentation array.
 
         Parameters
         ----------
-        background_color : str or `None`, optional
-            A hex string in the "#rrggbb" format defining the first
-            color in the colormap.  This color will be used as the
-            background color (label = 0) when plotting the segmentation
-            array.  The default is black ('#000000').
+        background_color : Matplotlib color, optional
+            The color of the first color in the colormap.
+            The color may be specified using any of
+            the `Matplotlib color formats
+            <https://matplotlib.org/stable/tutorials/colors/colors.html>`_.
+            This color will be used as the background color (label = 0)
+            when plotting the segmentation image. The default color is
+            black with alpha=1.0 ('#000000ff').
 
         seed : int, optional
             A seed to initialize the `numpy.random.BitGenerator`. If
             `None`, then fresh, unpredictable entropy will be pulled
-            from the OS.  Separate function calls with the same ``seed``
+            from the OS. Separate function calls with the same ``seed``
             will generate the same colormap.
 
         Returns
         -------
         cmap : `matplotlib.colors.ListedColormap`
-            The matplotlib colormap.
+            The matplotlib colormap with colors in RGBA format.
         """
+        if self.nlabels == 0:
+            return None
+
         from matplotlib import colors
 
         cmap = make_random_cmap(self.max_label + 1, seed=seed)
 
         if background_color is not None:
-            cmap.colors[0] = colors.hex2color(background_color)
+            cmap.colors[0] = colors.to_rgba(background_color)
 
         return cmap
 
+    @lazyproperty
+    def cmap(self):
+        """
+        A matplotlib colormap consisting of (random) muted colors.
+
+        This is useful for plotting the segmentation array.
+        """
+        return self.make_cmap(background_color='#000000ff', seed=0)
+
     def reassign_label(self, label, new_label, relabel=False):
         """
         Reassign a label number to a new number.
 
         If ``new_label`` is already present in the segmentation array,
         then it will be combined with the input ``label`` number.
+        Note that this can result in a label that is no longer pixel
+        connected.
 
         Parameters
         ----------
@@ -425,12 +464,13 @@ class SegmentationImage:
         Examples
         --------
         >>> from photutils.segmentation import SegmentationImage
-        >>> segm = SegmentationImage([[1, 1, 0, 0, 4, 4],
-        ...                           [0, 0, 0, 0, 0, 4],
-        ...                           [0, 0, 3, 3, 0, 0],
-        ...                           [7, 0, 0, 0, 0, 5],
-        ...                           [7, 7, 0, 5, 5, 5],
-        ...                           [7, 7, 0, 0, 5, 5]])
+        >>> data = np.array([[1, 1, 0, 0, 4, 4],
+        ...                  [0, 0, 0, 0, 0, 4],
+        ...                  [0, 0, 3, 3, 0, 0],
+        ...                  [7, 0, 0, 0, 0, 5],
+        ...                  [7, 7, 0, 5, 5, 5],
+        ...                  [7, 7, 0, 0, 5, 5]])
+        >>> segm = SegmentationImage(data)
         >>> segm.reassign_label(label=1, new_label=2)
         >>> segm.data
         array([[2, 2, 0, 0, 4, 4],
@@ -440,12 +480,13 @@ class SegmentationImage:
                [7, 7, 0, 5, 5, 5],
                [7, 7, 0, 0, 5, 5]])
 
-        >>> segm = SegmentationImage([[1, 1, 0, 0, 4, 4],
-        ...                           [0, 0, 0, 0, 0, 4],
-        ...                           [0, 0, 3, 3, 0, 0],
-        ...                           [7, 0, 0, 0, 0, 5],
-        ...                           [7, 7, 0, 5, 5, 5],
-        ...                           [7, 7, 0, 0, 5, 5]])
+        >>> data = np.array([[1, 1, 0, 0, 4, 4],
+        ...                  [0, 0, 0, 0, 0, 4],
+        ...                  [0, 0, 3, 3, 0, 0],
+        ...                  [7, 0, 0, 0, 0, 5],
+        ...                  [7, 7, 0, 5, 5, 5],
+        ...                  [7, 7, 0, 0, 5, 5]])
+        >>> segm = SegmentationImage(data)
         >>> segm.reassign_label(label=1, new_label=4)
         >>> segm.data
         array([[4, 4, 0, 0, 4, 4],
@@ -455,12 +496,13 @@ class SegmentationImage:
                [7, 7, 0, 5, 5, 5],
                [7, 7, 0, 0, 5, 5]])
 
-        >>> segm = SegmentationImage([[1, 1, 0, 0, 4, 4],
-        ...                           [0, 0, 0, 0, 0, 4],
-        ...                           [0, 0, 3, 3, 0, 0],
-        ...                           [7, 0, 0, 0, 0, 5],
-        ...                           [7, 7, 0, 5, 5, 5],
-        ...                           [7, 7, 0, 0, 5, 5]])
+        >>> data = np.array([[1, 1, 0, 0, 4, 4],
+        ...                  [0, 0, 0, 0, 0, 4],
+        ...                  [0, 0, 3, 3, 0, 0],
+        ...                  [7, 0, 0, 0, 0, 5],
+        ...                  [7, 7, 0, 5, 5, 5],
+        ...                  [7, 7, 0, 0, 5, 5]])
+        >>> segm = SegmentationImage(data)
         >>> segm.reassign_label(label=1, new_label=4, relabel=True)
         >>> segm.data
         array([[2, 2, 0, 0, 2, 2],
@@ -477,9 +519,10 @@ class SegmentationImage:
         Reassign one or more label numbers.
 
         Multiple input ``labels`` will all be reassigned to the same
-        ``new_label`` number.  If ``new_label`` is already present in
+        ``new_label`` number. If ``new_label`` is already present in
         the segmentation array, then it will be combined with the input
-        ``labels``.
+        ``labels``. Note that both of these can result in a label that
+        is no longer pixel connected.
 
         Parameters
         ----------
@@ -497,12 +540,13 @@ class SegmentationImage:
         Examples
         --------
         >>> from photutils.segmentation import SegmentationImage
-        >>> segm = SegmentationImage([[1, 1, 0, 0, 4, 4],
-        ...                           [0, 0, 0, 0, 0, 4],
-        ...                           [0, 0, 3, 3, 0, 0],
-        ...                           [7, 0, 0, 0, 0, 5],
-        ...                           [7, 7, 0, 5, 5, 5],
-        ...                           [7, 7, 0, 0, 5, 5]])
+        >>> data = np.array([[1, 1, 0, 0, 4, 4],
+        ...                  [0, 0, 0, 0, 0, 4],
+        ...                  [0, 0, 3, 3, 0, 0],
+        ...                  [7, 0, 0, 0, 0, 5],
+        ...                  [7, 7, 0, 5, 5, 5],
+        ...                  [7, 7, 0, 0, 5, 5]])
+        >>> segm = SegmentationImage(data)
         >>> segm.reassign_labels(labels=[1, 7], new_label=2)
         >>> segm.data
         array([[2, 2, 0, 0, 4, 4],
@@ -512,12 +556,13 @@ class SegmentationImage:
                [2, 2, 0, 5, 5, 5],
                [2, 2, 0, 0, 5, 5]])
 
-        >>> segm = SegmentationImage([[1, 1, 0, 0, 4, 4],
-        ...                           [0, 0, 0, 0, 0, 4],
-        ...                           [0, 0, 3, 3, 0, 0],
-        ...                           [7, 0, 0, 0, 0, 5],
-        ...                           [7, 7, 0, 5, 5, 5],
-        ...                           [7, 7, 0, 0, 5, 5]])
+        >>> data = np.array([[1, 1, 0, 0, 4, 4],
+        ...                  [0, 0, 0, 0, 0, 4],
+        ...                  [0, 0, 3, 3, 0, 0],
+        ...                  [7, 0, 0, 0, 0, 5],
+        ...                  [7, 7, 0, 5, 5, 5],
+        ...                  [7, 7, 0, 0, 5, 5]])
+        >>> segm = SegmentationImage(data)
         >>> segm.reassign_labels(labels=[1, 7], new_label=4)
         >>> segm.data
         array([[4, 4, 0, 0, 4, 4],
@@ -527,12 +572,13 @@ class SegmentationImage:
                [4, 4, 0, 5, 5, 5],
                [4, 4, 0, 0, 5, 5]])
 
-        >>> segm = SegmentationImage([[1, 1, 0, 0, 4, 4],
-        ...                           [0, 0, 0, 0, 0, 4],
-        ...                           [0, 0, 3, 3, 0, 0],
-        ...                           [7, 0, 0, 0, 0, 5],
-        ...                           [7, 7, 0, 5, 5, 5],
-        ...                           [7, 7, 0, 0, 5, 5]])
+        >>> data = np.array([[1, 1, 0, 0, 4, 4],
+        ...                  [0, 0, 0, 0, 0, 4],
+        ...                  [0, 0, 3, 3, 0, 0],
+        ...                  [7, 0, 0, 0, 0, 5],
+        ...                  [7, 7, 0, 5, 5, 5],
+        ...                  [7, 7, 0, 0, 5, 5]])
+        >>> segm = SegmentationImage(data)
         >>> segm.reassign_labels(labels=[1, 7], new_label=2, relabel=True)
         >>> segm.data
         array([[1, 1, 0, 0, 3, 3],
@@ -560,7 +606,7 @@ class SegmentationImage:
                 idx = idx2[idx]
 
         data_new = idx[self.data]
-        self.__dict__ = {}  # reset all cached properties
+        self._reset_lazyproperties()  # reset all cached properties
         self._data = data_new  # use _data to avoid validation
 
     def relabel_consecutive(self, start_label=1):
@@ -577,12 +623,13 @@ class SegmentationImage:
         Examples
         --------
         >>> from photutils.segmentation import SegmentationImage
-        >>> segm = SegmentationImage([[1, 1, 0, 0, 4, 4],
-        ...                           [0, 0, 0, 0, 0, 4],
-        ...                           [0, 0, 3, 3, 0, 0],
-        ...                           [7, 0, 0, 0, 0, 5],
-        ...                           [7, 7, 0, 5, 5, 5],
-        ...                           [7, 7, 0, 0, 5, 5]])
+        >>> data = np.array([[1, 1, 0, 0, 4, 4],
+        ...                  [0, 0, 0, 0, 0, 4],
+        ...                  [0, 0, 3, 3, 0, 0],
+        ...                  [7, 0, 0, 0, 0, 5],
+        ...                  [7, 7, 0, 5, 5, 5],
+        ...                  [7, 7, 0, 0, 5, 5]])
+        >>> segm = SegmentationImage(data)
         >>> segm.relabel_consecutive()
         >>> segm.data
         array([[1, 1, 0, 0, 3, 3],
@@ -592,19 +639,29 @@ class SegmentationImage:
                [5, 5, 0, 4, 4, 4],
                [5, 5, 0, 0, 4, 4]])
         """
+        if self.nlabels == 0:
+            warnings.warn('Cannot relabel a segmentation image of all zeros',
+                          AstropyUserWarning)
+            return
+
         if start_label <= 0:
             raise ValueError('start_label must be > 0.')
 
-        if ((self.labels[0] == start_label) and
-                (self.labels[-1] - self.labels[0] + 1) == self.nlabels):
+        if ((self.labels[0] == start_label)
+                and (self.labels[-1] - self.labels[0] + 1) == self.nlabels):
             return
 
-        new_labels = np.zeros(self.max_label + 1, dtype=int)
-        new_labels[self.labels] = np.arange(self.nlabels) + start_label
+        old_slices = self.__dict__.get('slices', None)
+        new_labels = np.arange(self.nlabels) + start_label
+        new_label_map = np.zeros(self.max_label + 1, dtype=int)
+        new_label_map[self.labels] = new_labels
 
-        data_new = new_labels[self.data]
-        self.__dict__ = {}  # reset all cached properties
+        data_new = new_label_map[self.data]
+        self._reset_lazyproperties()  # reset all cached properties
         self._data = data_new  # use _data to avoid validation
+        self.__dict__['labels'] = new_labels
+        if old_slices is not None:
+            self.__dict__['slices'] = old_slices  # slice order is unchanged
 
     def keep_label(self, label, relabel=False):
         """
@@ -622,12 +679,15 @@ class SegmentationImage:
         Examples
         --------
         >>> from photutils.segmentation import SegmentationImage
-        >>> segm = SegmentationImage([[1, 1, 0, 0, 4, 4],
-        ...                           [0, 0, 0, 0, 0, 4],
-        ...                           [0, 0, 3, 3, 0, 0],
-        ...                           [7, 0, 0, 0, 0, 5],
-        ...                           [7, 7, 0, 5, 5, 5],
-        ...                           [7, 7, 0, 0, 5, 5]])
+
+        >>> data = np.array([[1, 1, 0, 0, 4, 4],
+        ...                  [0, 0, 0, 0, 0, 4],
+        ...                  [0, 0, 3, 3, 0, 0],
+        ...                  [7, 0, 0, 0, 0, 5],
+        ...                  [7, 7, 0, 5, 5, 5],
+        ...                  [7, 7, 0, 0, 5, 5]])
+
+        >>> segm = SegmentationImage(data)
         >>> segm.keep_label(label=3)
         >>> segm.data
         array([[0, 0, 0, 0, 0, 0],
@@ -637,12 +697,13 @@ class SegmentationImage:
                [0, 0, 0, 0, 0, 0],
                [0, 0, 0, 0, 0, 0]])
 
-        >>> segm = SegmentationImage([[1, 1, 0, 0, 4, 4],
-        ...                           [0, 0, 0, 0, 0, 4],
-        ...                           [0, 0, 3, 3, 0, 0],
-        ...                           [7, 0, 0, 0, 0, 5],
-        ...                           [7, 7, 0, 5, 5, 5],
-        ...                           [7, 7, 0, 0, 5, 5]])
+        >>> data = np.array([[1, 1, 0, 0, 4, 4],
+        ...                  [0, 0, 0, 0, 0, 4],
+        ...                  [0, 0, 3, 3, 0, 0],
+        ...                  [7, 0, 0, 0, 0, 5],
+        ...                  [7, 7, 0, 5, 5, 5],
+        ...                  [7, 7, 0, 0, 5, 5]])
+        >>> segm = SegmentationImage(data)
         >>> segm.keep_label(label=3, relabel=True)
         >>> segm.data
         array([[0, 0, 0, 0, 0, 0],
@@ -671,12 +732,13 @@ class SegmentationImage:
         Examples
         --------
         >>> from photutils.segmentation import SegmentationImage
-        >>> segm = SegmentationImage([[1, 1, 0, 0, 4, 4],
-        ...                           [0, 0, 0, 0, 0, 4],
-        ...                           [0, 0, 3, 3, 0, 0],
-        ...                           [7, 0, 0, 0, 0, 5],
-        ...                           [7, 7, 0, 5, 5, 5],
-        ...                           [7, 7, 0, 0, 5, 5]])
+        >>> data = np.array([[1, 1, 0, 0, 4, 4],
+        ...                  [0, 0, 0, 0, 0, 4],
+        ...                  [0, 0, 3, 3, 0, 0],
+        ...                  [7, 0, 0, 0, 0, 5],
+        ...                  [7, 7, 0, 5, 5, 5],
+        ...                  [7, 7, 0, 0, 5, 5]])
+        >>> segm = SegmentationImage(data)
         >>> segm.keep_labels(labels=[5, 3])
         >>> segm.data
         array([[0, 0, 0, 0, 0, 0],
@@ -686,12 +748,13 @@ class SegmentationImage:
                [0, 0, 0, 5, 5, 5],
                [0, 0, 0, 0, 5, 5]])
 
-        >>> segm = SegmentationImage([[1, 1, 0, 0, 4, 4],
-        ...                           [0, 0, 0, 0, 0, 4],
-        ...                           [0, 0, 3, 3, 0, 0],
-        ...                           [7, 0, 0, 0, 0, 5],
-        ...                           [7, 7, 0, 5, 5, 5],
-        ...                           [7, 7, 0, 0, 5, 5]])
+        >>> data = np.array([[1, 1, 0, 0, 4, 4],
+        ...                  [0, 0, 0, 0, 0, 4],
+        ...                  [0, 0, 3, 3, 0, 0],
+        ...                  [7, 0, 0, 0, 0, 5],
+        ...                  [7, 7, 0, 5, 5, 5],
+        ...                  [7, 7, 0, 0, 5, 5]])
+        >>> segm = SegmentationImage(data)
         >>> segm.keep_labels(labels=[5, 3], relabel=True)
         >>> segm.data
         array([[0, 0, 0, 0, 0, 0],
@@ -727,12 +790,13 @@ class SegmentationImage:
         Examples
         --------
         >>> from photutils.segmentation import SegmentationImage
-        >>> segm = SegmentationImage([[1, 1, 0, 0, 4, 4],
-        ...                           [0, 0, 0, 0, 0, 4],
-        ...                           [0, 0, 3, 3, 0, 0],
-        ...                           [7, 0, 0, 0, 0, 5],
-        ...                           [7, 7, 0, 5, 5, 5],
-        ...                           [7, 7, 0, 0, 5, 5]])
+        >>> data = np.array([[1, 1, 0, 0, 4, 4],
+        ...                  [0, 0, 0, 0, 0, 4],
+        ...                  [0, 0, 3, 3, 0, 0],
+        ...                  [7, 0, 0, 0, 0, 5],
+        ...                  [7, 7, 0, 5, 5, 5],
+        ...                  [7, 7, 0, 0, 5, 5]])
+        >>> segm = SegmentationImage(data)
         >>> segm.remove_label(label=5)
         >>> segm.data
         array([[1, 1, 0, 0, 4, 4],
@@ -742,12 +806,13 @@ class SegmentationImage:
                [7, 7, 0, 0, 0, 0],
                [7, 7, 0, 0, 0, 0]])
 
-        >>> segm = SegmentationImage([[1, 1, 0, 0, 4, 4],
-        ...                           [0, 0, 0, 0, 0, 4],
-        ...                           [0, 0, 3, 3, 0, 0],
-        ...                           [7, 0, 0, 0, 0, 5],
-        ...                           [7, 7, 0, 5, 5, 5],
-        ...                           [7, 7, 0, 0, 5, 5]])
+        >>> data = np.array([[1, 1, 0, 0, 4, 4],
+        ...                  [0, 0, 0, 0, 0, 4],
+        ...                  [0, 0, 3, 3, 0, 0],
+        ...                  [7, 0, 0, 0, 0, 5],
+        ...                  [7, 7, 0, 5, 5, 5],
+        ...                  [7, 7, 0, 0, 5, 5]])
+        >>> segm = SegmentationImage(data)
         >>> segm.remove_label(label=5, relabel=True)
         >>> segm.data
         array([[1, 1, 0, 0, 3, 3],
@@ -778,12 +843,13 @@ class SegmentationImage:
         Examples
         --------
         >>> from photutils.segmentation import SegmentationImage
-        >>> segm = SegmentationImage([[1, 1, 0, 0, 4, 4],
-        ...                           [0, 0, 0, 0, 0, 4],
-        ...                           [0, 0, 3, 3, 0, 0],
-        ...                           [7, 0, 0, 0, 0, 5],
-        ...                           [7, 7, 0, 5, 5, 5],
-        ...                           [7, 7, 0, 0, 5, 5]])
+        >>> data = np.array([[1, 1, 0, 0, 4, 4],
+        ...                  [0, 0, 0, 0, 0, 4],
+        ...                  [0, 0, 3, 3, 0, 0],
+        ...                  [7, 0, 0, 0, 0, 5],
+        ...                  [7, 7, 0, 5, 5, 5],
+        ...                  [7, 7, 0, 0, 5, 5]])
+        >>> segm = SegmentationImage(data)
         >>> segm.remove_labels(labels=[5, 3])
         >>> segm.data
         array([[1, 1, 0, 0, 4, 4],
@@ -793,12 +859,13 @@ class SegmentationImage:
                [7, 7, 0, 0, 0, 0],
                [7, 7, 0, 0, 0, 0]])
 
-        >>> segm = SegmentationImage([[1, 1, 0, 0, 4, 4],
-        ...                           [0, 0, 0, 0, 0, 4],
-        ...                           [0, 0, 3, 3, 0, 0],
-        ...                           [7, 0, 0, 0, 0, 5],
-        ...                           [7, 7, 0, 5, 5, 5],
-        ...                           [7, 7, 0, 0, 5, 5]])
+        >>> data = np.array([[1, 1, 0, 0, 4, 4],
+        ...                  [0, 0, 0, 0, 0, 4],
+        ...                  [0, 0, 3, 3, 0, 0],
+        ...                  [7, 0, 0, 0, 0, 5],
+        ...                  [7, 7, 0, 5, 5, 5],
+        ...                  [7, 7, 0, 0, 5, 5]])
+        >>> segm = SegmentationImage(data)
         >>> segm.remove_labels(labels=[5, 3], relabel=True)
         >>> segm.data
         array([[1, 1, 0, 0, 2, 2],
@@ -837,12 +904,13 @@ class SegmentationImage:
         Examples
         --------
         >>> from photutils.segmentation import SegmentationImage
-        >>> segm = SegmentationImage([[1, 1, 0, 0, 4, 4],
-        ...                           [0, 0, 0, 0, 0, 4],
-        ...                           [0, 0, 3, 3, 0, 0],
-        ...                           [7, 0, 0, 0, 0, 5],
-        ...                           [7, 7, 0, 5, 5, 5],
-        ...                           [7, 7, 0, 0, 5, 5]])
+        >>> data = np.array([[1, 1, 0, 0, 4, 4],
+        ...                  [0, 0, 0, 0, 0, 4],
+        ...                  [0, 0, 3, 3, 0, 0],
+        ...                  [7, 0, 0, 0, 0, 5],
+        ...                  [7, 7, 0, 5, 5, 5],
+        ...                  [7, 7, 0, 0, 5, 5]])
+        >>> segm = SegmentationImage(data)
         >>> segm.remove_border_labels(border_width=1)
         >>> segm.data
         array([[0, 0, 0, 0, 0, 0],
@@ -852,12 +920,13 @@ class SegmentationImage:
                [0, 0, 0, 0, 0, 0],
                [0, 0, 0, 0, 0, 0]])
 
-        >>> segm = SegmentationImage([[1, 1, 0, 0, 4, 4],
-        ...                           [0, 0, 0, 0, 0, 4],
-        ...                           [0, 0, 3, 3, 0, 0],
-        ...                           [7, 0, 0, 0, 0, 5],
-        ...                           [7, 7, 0, 5, 5, 5],
-        ...                           [7, 7, 0, 0, 5, 5]])
+        >>> data = np.array([[1, 1, 0, 0, 4, 4],
+        ...                  [0, 0, 0, 0, 0, 4],
+        ...                  [0, 0, 3, 3, 0, 0],
+        ...                  [7, 0, 0, 0, 0, 5],
+        ...                  [7, 7, 0, 5, 5, 5],
+        ...                  [7, 7, 0, 0, 5, 5]])
+        >>> segm = SegmentationImage(data)
         >>> segm.remove_border_labels(border_width=1,
         ...                           partial_overlap=False)
         >>> segm.data
@@ -908,12 +977,13 @@ class SegmentationImage:
         Examples
         --------
         >>> from photutils.segmentation import SegmentationImage
-        >>> segm = SegmentationImage([[1, 1, 0, 0, 4, 4],
-        ...                           [0, 0, 0, 0, 0, 4],
-        ...                           [0, 0, 3, 3, 0, 0],
-        ...                           [7, 0, 0, 0, 0, 5],
-        ...                           [7, 7, 0, 5, 5, 5],
-        ...                           [7, 7, 0, 0, 5, 5]])
+        >>> data = np.array([[1, 1, 0, 0, 4, 4],
+        ...                  [0, 0, 0, 0, 0, 4],
+        ...                  [0, 0, 3, 3, 0, 0],
+        ...                  [7, 0, 0, 0, 0, 5],
+        ...                  [7, 7, 0, 5, 5, 5],
+        ...                  [7, 7, 0, 0, 5, 5]])
+        >>> segm = SegmentationImage(data)
         >>> mask = np.zeros(segm.data.shape, dtype=bool)
         >>> mask[0, :] = True  # mask the first row
         >>> segm.remove_masked_labels(mask)
@@ -925,12 +995,13 @@ class SegmentationImage:
                [7, 7, 0, 5, 5, 5],
                [7, 7, 0, 0, 5, 5]])
 
-        >>> segm = SegmentationImage([[1, 1, 0, 0, 4, 4],
-        ...                           [0, 0, 0, 0, 0, 4],
-        ...                           [0, 0, 3, 3, 0, 0],
-        ...                           [7, 0, 0, 0, 0, 5],
-        ...                           [7, 7, 0, 5, 5, 5],
-        ...                           [7, 7, 0, 0, 5, 5]])
+        >>> data = np.array([[1, 1, 0, 0, 4, 4],
+        ...                  [0, 0, 0, 0, 0, 4],
+        ...                  [0, 0, 3, 3, 0, 0],
+        ...                  [7, 0, 0, 0, 0, 5],
+        ...                  [7, 7, 0, 5, 5, 5],
+        ...                  [7, 7, 0, 0, 5, 5]])
+        >>> segm = SegmentationImage(data)
         >>> segm.remove_masked_labels(mask, partial_overlap=False)
         >>> segm.data
         array([[0, 0, 0, 0, 4, 4],
@@ -949,6 +1020,50 @@ class SegmentationImage:
             remove_labels = list(set(remove_labels) - set(interior_labels))
         self.remove_labels(remove_labels, relabel=relabel)
 
+    def make_source_mask(self, footprint=None):
+        """
+        Make a source mask from the segmentation image.
+
+        Use the ``footprint`` keyword to perform binary dilation on the
+        segmentation image.
+
+        Parameters
+        ----------
+        footprint : 2D `~numpy.ndarray`, optional
+            The local footprint used for the source dilation. Non-zero
+            elements are considered `True`.  If `None`, then no dilation
+            is performed.
+
+        Returns
+        -------
+        mask : 2D bool `~numpy.ndarray`
+            A 2D boolean image containing the source mask.
+
+        Examples
+        --------
+        >>> import numpy as np
+        >>> from photutils import SegmentationImage
+        >>> from photutils.utils import circular_footprint
+        >>> data = np.zeros((7, 7), dtype=int)
+        >>> data[3, 3] = 1
+        >>> segm = SegmentationImage(data)
+        >>> footprint = circular_footprint(radius=3)
+        >>> mask = segm.make_source_mask(footprint=footprint)
+        >>> mask
+        array([[False, False, False,  True, False, False, False],
+               [False,  True,  True,  True,  True,  True, False],
+               [False,  True,  True,  True,  True,  True, False],
+               [ True,  True,  True,  True,  True,  True,  True],
+               [False,  True,  True,  True,  True,  True, False],
+               [False,  True,  True,  True,  True,  True, False],
+               [False, False, False,  True, False, False, False]])
+        """
+        if footprint is None:
+            return self._data.astype(bool)
+
+        from scipy.ndimage import binary_dilation
+        return binary_dilation(self._data.astype(bool), structure=footprint)
+
     def outline_segments(self, mask_background=False):
         """
         Outline the labeled segments.
@@ -975,12 +1090,13 @@ class SegmentationImage:
         Examples
         --------
         >>> from photutils.segmentation import SegmentationImage
-        >>> segm = SegmentationImage([[0, 0, 0, 0, 0, 0],
-        ...                           [0, 2, 2, 2, 2, 0],
-        ...                           [0, 2, 2, 2, 2, 0],
-        ...                           [0, 2, 2, 2, 2, 0],
-        ...                           [0, 2, 2, 2, 2, 0],
-        ...                           [0, 0, 0, 0, 0, 0]])
+        >>> data = np.array([[0, 0, 0, 0, 0, 0],
+        ...                  [0, 2, 2, 2, 2, 0],
+        ...                  [0, 2, 2, 2, 2, 0],
+        ...                  [0, 2, 2, 2, 2, 0],
+        ...                  [0, 2, 2, 2, 2, 0],
+        ...                  [0, 0, 0, 0, 0, 0]])
+        >>> segm = SegmentationImage(data)
         >>> segm.outline_segments()
         array([[0, 0, 0, 0, 0, 0],
                [0, 2, 2, 2, 2, 0],
@@ -1007,6 +1123,71 @@ class SegmentationImage:
 
         return outlines
 
+    def imshow(self, axes=None, figsize=None, dpi=None, cmap=None, alpha=None):
+        """
+        Display the segmentation image in a matplotlib
+        `~matplotlib.axes.Axes` instance.
+
+        The segmentation image will be displayed with no interpolation
+        and with the origin set to "lower".
+
+        Parameters
+        ----------
+        axes : `matplotlib.axes.Axes` or `None`, optional
+            The matplotlib axes on which to plot. If `None`, then a new
+            `~matplotlib.axes.Axes` instance will be created.
+
+        figsize : 2-tuple of floats or `None`, optional
+            The figure dimension (width, height) in inches when creating
+            a new Axes. This keyword is ignored if ``axes`` is input.
+
+        dpi : float or `None`, optional
+            The figure dots per inch when creating a new Axes. This
+            keyword is ignored if ``axes`` is input.
+
+        cmap : `matplotlib.colors.Colormap`, str, or `None`, optional
+            The `~matplotlib.colors.Colormap` instance or a registered
+            matplotlib colormap name used to map scalar data to colors.
+            If `None`, then the colormap defined by the `cmap` attribute
+            will be used.
+
+        alpha : float, array-like, or `None`, optional
+            The alpha blending value, between 0 (transparent) and 1
+            (opaque). If alpha is an array, the alpha blending values
+            are applied pixel by pixel, and alpha must have the same
+            shape as the segmentation image.
+
+        Returns
+        -------
+        result : `matplotlib.image.AxesImage`
+            An image attached to an `matplotlib.axes.Axes`.
+
+        Examples
+        --------
+        .. plot::
+            :include-source:
+
+            import numpy as np
+            from photutils.segmentation import SegmentationImage
+            data = np.array([[1, 1, 0, 0, 4, 4],
+                            [0, 0, 0, 0, 0, 4],
+                            [0, 0, 3, 3, 0, 0],
+                            [7, 0, 0, 0, 0, 5],
+                            [7, 7, 0, 5, 5, 5],
+                            [7, 7, 0, 0, 5, 5]])
+            segm = SegmentationImage(data)
+            segm.imshow(figsize=(5, 5))
+        """
+        import matplotlib.pyplot as plt
+
+        if axes is None:
+            _, axes = plt.subplots(figsize=figsize, dpi=dpi)
+        if cmap is None:
+            cmap = self.cmap
+
+        return axes.imshow(self.data, cmap=cmap, interpolation='none',
+                           origin='lower', alpha=alpha)
+
 
 class Segment:
     """
@@ -1098,14 +1279,14 @@ class Segment:
         is a view (not a copy) of the input ``data``.  No pixels are
         altered (e.g., set to zero) within the bounding box.
 
-        If ``masked_array` is `True`, then the returned cutout array is
+        If ``masked_array`` is `True`, then the returned cutout array is
         a `~numpy.ma.MaskedArray`, where the mask is `True` for pixels
-        outside of the segment (labeled region).  The data part of the
+        outside of the segment (labeled region). The data part of the
         masked array is a view (not a copy) of the input ``data``.
 
         Parameters
         ----------
-        data : array-like
+        data : 2D `~numpy.ndarray`
             The data array from which to create the masked cutout array.
             ``data`` must have the same shape as the segmentation array.
 
@@ -1117,10 +1298,9 @@ class Segment:
 
         Returns
         -------
-        result : `~numpy.ndarray` or `~numpy.ma.MaskedArray`
+        result : 2D `~numpy.ndarray` or `~numpy.ma.MaskedArray`
             The cutout array.
         """
-        data = np.asanyarray(data)
         if data.shape != self._segment_data.shape:
             raise ValueError('data must have the same shape as the '
                              'segmentation array.')
