@@ -2,6 +2,7 @@
 """
 Tests for the catalog module.
 """
+from astropy.convolution import convolve
 from astropy.coordinates import SkyCoord
 from astropy.modeling.models import Gaussian2D
 from astropy.table import QTable
@@ -13,8 +14,14 @@ import pytest
 from ..catalog import SourceCatalog
 from ..core import SegmentationImage
 from ..detect import detect_sources
+from ..finder import SourceFinder
+from ..utils import make_2dgaussian_kernel
 from ...aperture import CircularAperture, EllipticalAperture
-from ...datasets import make_gwcs, make_wcs, make_noise_image
+from ...background import Background2D, MedianBackground
+from ...datasets import (make_gwcs, make_wcs, make_noise_image,
+                         make_100gaussians_image)
+from ...utils._convolution import _filter_data
+from ...utils.cutouts import CutoutImage
 from ...utils._optional_deps import HAS_GWCS, HAS_MATPLOTLIB, HAS_SCIPY  # noqa
 
 
@@ -200,6 +207,10 @@ class TestSourceCatalog:
         for prop in props:
             assert getattr(obj, prop) is None
 
+        arr_props = ('_background_cutouts', '_error_cutouts')
+        for prop in arr_props:
+            assert getattr(obj, prop)[0] is None
+
         props = ('background_mean', 'background_sum', 'background_centroid',
                  'segment_fluxerr', 'kron_fluxerr')
         for prop in props:
@@ -263,13 +274,17 @@ class TestSourceCatalog:
         assert tbl.colnames == columns
 
     def test_invalid_inputs(self):
+        segm = SegmentationImage(np.zeros(self.data.shape, dtype=int))
+        with pytest.raises(ValueError):
+            SourceCatalog(self.data, segm)
+
         # test 1D arrays
         img1d = np.arange(4)
         segm = SegmentationImage(img1d)
         with pytest.raises(ValueError):
             SourceCatalog(img1d, segm)
 
-        wrong_shape = np.ones((3, 3))
+        wrong_shape = np.ones((3, 3), dtype=int)
         with pytest.raises(ValueError):
             SourceCatalog(wrong_shape, self.segm)
 
@@ -302,7 +317,10 @@ class TestSourceCatalog:
             SourceCatalog(self.data, self.segm,
                           apermask_method=apermask_method)
         with pytest.raises(ValueError):
-            kron_params = (2.5, 0.0, 3.0)
+            kron_params = (0.0, 1.0)
+            SourceCatalog(self.data, self.segm, kron_params=kron_params)
+        with pytest.raises(ValueError):
+            kron_params = (2.5, 0.0)
             SourceCatalog(self.data, self.segm, kron_params=kron_params)
         with pytest.raises(ValueError):
             kron_params = (-2.5, 0.0)
@@ -310,6 +328,9 @@ class TestSourceCatalog:
         with pytest.raises(ValueError):
             kron_params = (2.5, -4.0)
             SourceCatalog(self.data, self.segm, kron_params=kron_params)
+        with pytest.raises(ValueError):
+            kron_params = (2.5, 1.4, -2.0)
+            SourceCatalog(self.data, self.segm, kron_params=kron_params)
 
     def test_invalid_units(self):
         unit = u.uJy
@@ -419,11 +440,20 @@ class TestSourceCatalog:
     def test_kernel(self):
         kernel = np.array([[1., 2, 1], [2, 4, 2], [1, 2, 100]])
         kernel /= kernel.sum()
+
         cat1 = SourceCatalog(self.data, self.segm, kernel=None)
         cat2 = SourceCatalog(self.data, self.segm, kernel=kernel)
         assert not np.array_equal(cat1.xcentroid, cat2.xcentroid)
         assert not np.array_equal(cat1.ycentroid, cat2.ycentroid)
 
+        convolved_data = _filter_data(self.data, kernel, mode='constant',
+                                      fill_value=0.0,
+                                      check_normalization=True)
+        cat3 = SourceCatalog(self.data, self.segm,
+                             convolved_data=convolved_data)
+        assert_allclose(cat2.centroid, cat3.centroid)
+        assert_allclose(cat2.covariance, cat3.covariance)
+
     def test_detection_cat(self):
         data2 = self.data - 5
         cat1 = SourceCatalog(data2, self.segm)
@@ -444,12 +474,16 @@ class TestSourceCatalog:
             SourceCatalog(self.data, self.segm, detection_cat=cat)
 
     def test_kron_minradius(self):
-        kron_params = (2.5, 10.0)
+        kron_params = (2.5, 2.5)
         cat = SourceCatalog(self.data, self.segm, mask=self.mask,
                             apermask_method='none', kron_params=kron_params)
         assert cat.kron_aperture[0] is None
+        assert np.isnan(cat.kron_radius[0])
+        kronrad = cat.kron_radius.value
+        kronrad = kronrad[~np.isnan(kronrad)]
+        assert np.min(kronrad) == kron_params[1]
         assert isinstance(cat.kron_aperture[2], EllipticalAperture)
-        assert isinstance(cat.kron_aperture[4], CircularAperture)
+        assert isinstance(cat.kron_aperture[4], EllipticalAperture)
 
     def test_kron_masking(self):
         apermask_method = 'none'
@@ -468,8 +502,7 @@ class TestSourceCatalog:
 
     def test_kron_negative(self):
         cat = SourceCatalog(self.data - 10, self.segm)
-        assert np.all(np.isnan(cat.kron_radius.value))
-        assert np.all(np.isnan(cat.kron_flux))
+        assert_allclose(cat.kron_radius.value, cat._kron_params[1])
 
     def test_kron_photometry(self):
         flux1, fluxerr1 = self.cat.kron_photometry((2.5, 1.0))
@@ -549,11 +582,16 @@ class TestSourceCatalog:
         for patch in patches:
             assert isinstance(patch, Patch)
 
-        patches = self.cat.plot_kron_apertures((2.5, 1.0))
+        patches = self.cat.plot_kron_apertures()
         assert isinstance(patches, list)
         for patch in patches:
             assert isinstance(patch, Patch)
 
+        patches2 = self.cat.plot_kron_apertures((2.5, 1.0))
+        assert isinstance(patches2, list)
+        for patch in patches2:
+            assert isinstance(patch, Patch)
+
     def test_fluxfrac_radius(self):
         radius1 = self.cat.fluxfrac_radius(0.1, name='fluxfrac_r1')
         radius2 = self.cat.fluxfrac_radius(0.5, name='fluxfrac_r5')
@@ -577,7 +615,7 @@ class TestSourceCatalog:
                             background=self.background, mask=self.mask,
                             wcs=self.wcs, localbkg_width=24)
         radius_hl = cat.fluxfrac_radius(0.5)
-        assert np.all(np.isnan(radius_hl))
+        assert np.isnan(radius_hl[0])
 
     def test_cutout_units(self):
         obj = self.cat_units[0]
@@ -669,7 +707,112 @@ class TestSourceCatalog:
     def test_copy(self):
         cat = SourceCatalog(self.data, self.segm)
         cat2 = cat.copy()
-        cat.kron_flux
+        _ = cat.kron_flux
         assert 'kron_flux' not in cat2.__dict__
         tbl = cat2.to_table()
         assert len(tbl) == 7
+
+    def test_data_dtype(self):
+        """
+        Regression test that input ``data`` with int dtype does not
+        raise UFuncTypeError due to subtraction of float array from int
+        array.
+        """
+        data = np.zeros((25, 25), dtype=np.uint16)
+        data[8:16, 8:16] = 10
+        segmdata = np.zeros((25, 25), dtype=int)
+        segmdata[8:16, 8:16] = 1
+        segm = SegmentationImage(segmdata)
+        cat = SourceCatalog(data, segm, localbkg_width=3)
+        assert cat.min_value == 10
+        assert cat.max_value == 10
+
+    def test_make_circular_apertures(self):
+        radius = 10
+        aper = self.cat.make_circular_apertures(radius)
+        assert len(aper) == len(self.cat)
+        assert isinstance(aper[1], CircularAperture)
+        assert aper[1].r == radius
+
+        obj = self.cat[1]
+        aper = obj.make_circular_apertures(radius)
+        assert isinstance(aper, CircularAperture)
+        assert aper.r == radius
+
+    def test_make_kron_apertures(self):
+        aper = self.cat.make_kron_apertures()
+        assert len(aper) == len(self.cat)
+        assert isinstance(aper[1], EllipticalAperture)
+
+        aper2 = self.cat.make_kron_apertures((2.5, 1))
+        assert len(aper2) == len(self.cat)
+
+        obj = self.cat[1]
+        aper = obj.make_kron_apertures()
+        assert isinstance(aper, EllipticalAperture)
+
+    def test_make_cutouts(self):
+        shape = (10, 11)
+        cut = self.cat.make_cutouts(shape)
+        assert len(cut) == len(self.cat)
+        assert isinstance(cut[1], CutoutImage)
+        assert cut[1].data.shape == shape
+
+        obj = self.cat[1]
+        cut = obj.make_cutouts(shape)
+        assert isinstance(cut, CutoutImage)
+        assert cut.data.shape == shape
+
+
+@pytest.mark.skipif('not HAS_SCIPY')
+def test_kron_params():
+    data = make_100gaussians_image()
+    bkg_estimator = MedianBackground()
+    bkg = Background2D(data, (50, 50), filter_size=(3, 3),
+                       bkg_estimator=bkg_estimator)
+    data -= bkg.background  # subtract the background
+
+    threshold = 1.5 * bkg.background_rms
+
+    kernel = make_2dgaussian_kernel(3.0, size=5)
+    convolved_data = convolve(data, kernel)
+
+    npixels = 10
+    finder = SourceFinder(npixels=npixels, progress_bar=False)
+    segm = finder(convolved_data, threshold)
+
+    minrad = 1.4
+    kron_params = (2.5, minrad, 0.0)
+    cat = SourceCatalog(data, segm, convolved_data=convolved_data,
+                        kron_params=kron_params)
+    assert cat.kron_radius.value.min() == minrad
+    assert_allclose(cat.kron_flux.min(), 246.91339096556538)
+    rh = cat.fluxfrac_radius(0.5)
+    assert_allclose(rh.value.min(), 1.3925520107605818)
+
+    minrad = 1.2
+    kron_params = (2.5, minrad, 0.0)
+    cat = SourceCatalog(data, segm, convolved_data=convolved_data,
+                        kron_params=kron_params)
+    assert cat.kron_radius.value.min() == minrad
+    assert_allclose(cat.kron_flux.min(), 246.91339096556538)
+    rh = cat.fluxfrac_radius(0.5)
+    assert_allclose(rh.value.min(), 1.3979610808075127)
+
+    minrad = 0.2
+    kron_params = (2.5, minrad, 0.0)
+    cat = SourceCatalog(data, segm, convolved_data=convolved_data,
+                        kron_params=kron_params)
+    assert_allclose(cat.kron_radius.value.min(), 0.5712931578847312)
+    assert_allclose(cat.kron_flux.min(), 246.91339096556538)
+    rh = cat.fluxfrac_radius(0.5)
+    assert_allclose(rh.value.min(), 1.34218684691197)
+
+    kron_params = (2.5, 1.4, 7.0)
+    cat = SourceCatalog(data, segm, convolved_data=convolved_data,
+                        kron_params=kron_params)
+    assert cat.kron_radius.value.min() == 0.0
+    assert_allclose(cat.kron_flux.min(), 246.91339096556538)
+    rh = cat.fluxfrac_radius(0.5)
+    assert_allclose(rh.value.min(), 1.3649418211298536)
+    assert isinstance(cat.kron_aperture[0], CircularAperture)
