@@ -3,60 +3,70 @@
 Tests for the core module.
 """
 
+from astropy.utils import lazyproperty
+from astropy.utils.exceptions import AstropyUserWarning
 import numpy as np
-from numpy.testing import assert_allclose
+from numpy.testing import assert_allclose, assert_equal
 import pytest
 
 from ..core import Segment, SegmentationImage
+from ...utils import circular_footprint
 from ...utils._optional_deps import HAS_MATPLOTLIB, HAS_SCIPY  # noqa
 
 
 @pytest.mark.skipif('not HAS_SCIPY')
 class TestSegmentationImage:
     def setup_class(self):
-        self.data = [[1, 1, 0, 0, 4, 4],
-                     [0, 0, 0, 0, 0, 4],
-                     [0, 0, 3, 3, 0, 0],
-                     [7, 0, 0, 0, 0, 5],
-                     [7, 7, 0, 5, 5, 5],
-                     [7, 7, 0, 0, 5, 5]]
+        self.data = np.array([[1, 1, 0, 0, 4, 4],
+                              [0, 0, 0, 0, 0, 4],
+                              [0, 0, 3, 3, 0, 0],
+                              [7, 0, 0, 0, 0, 5],
+                              [7, 7, 0, 5, 5, 5],
+                              [7, 7, 0, 0, 5, 5]])
         self.segm = SegmentationImage(self.data)
 
     def test_array(self):
         assert_allclose(self.segm.data, self.segm.__array__())
 
     def test_copy(self):
-        segm = SegmentationImage(self.data)
+        segm = SegmentationImage(self.data.copy())
         segm2 = segm.copy()
         assert segm.data is not segm2.data
         assert segm.labels is not segm2.labels
         segm.data[0, 0] = 100.
         assert segm.data[0, 0] != segm2.data[0, 0]
 
+    def test_data_all_zeros(self):
+        data = np.zeros((5, 5), dtype=int)
+        segm = SegmentationImage(data)
+        assert segm.max_label == 0
+        assert not segm.is_consecutive
+        assert segm.cmap is None
+        with pytest.warns(AstropyUserWarning,
+                          match='segmentation image of all zeros'):
+            segm.relabel_consecutive()
+
+    def test_data_reassignment(self):
+        segm = SegmentationImage(self.data.copy())
+        segm.data = self.data[0:3, :].copy()
+        assert_equal(segm.labels, [1, 3, 4])
+
     def test_invalid_data(self):
-        # contains all zeros
-        data = np.zeros((3, 3))
-        with pytest.raises(ValueError):
-            SegmentationImage(data)
-
-        # contains a NaN
-        data = np.zeros((5, 5))
-        data[2, 2] = np.nan
-        with pytest.raises(ValueError):
-            SegmentationImage(data)
-
-        # contains an inf
-        data = np.zeros((5, 5))
-        data[2, 2] = np.inf
-        data[0, 0] = -np.inf
-        with pytest.raises(ValueError):
+        # is float dtype
+        data = np.zeros((3, 3), dtype=float)
+        with pytest.raises(TypeError):
             SegmentationImage(data)
 
         # contains a negative value
-        data = np.arange(-1, 8).reshape(3, 3)
+        data = np.arange(-1, 8).reshape(3, 3).astype(int)
         with pytest.raises(ValueError):
             SegmentationImage(data)
 
+        # is not ndarray
+        data = [[1, 1], [0, 1]]
+        with pytest.raises(TypeError):
+            SegmentationImage(data)
+
     @pytest.mark.parametrize('label', [0, -1, 2])
     def test_invalid_label(self, label):
         # test with scalar labels
@@ -146,7 +156,7 @@ class TestSegmentationImage:
     def test_is_consecutive(self):
         assert not self.segm.is_consecutive
 
-        data = [[2, 2, 0], [0, 3, 3], [0, 0, 4]]
+        data = np.array([[2, 2, 0], [0, 3, 3], [0, 0, 4]])
         segm = SegmentationImage(data)
         assert not segm.is_consecutive  # does not start with label=1
 
@@ -164,18 +174,33 @@ class TestSegmentationImage:
         with pytest.raises(ValueError):
             self.segm.check_labels([2, 6])
 
+    def test_bbox_1d(self):
+        segm = SegmentationImage(np.array([0, 0, 1, 1, 0, 2, 2, 0]))
+        with pytest.raises(ValueError):
+            _ = segm.bbox
+
     @pytest.mark.skipif('not HAS_MATPLOTLIB')
     def test_make_cmap(self):
         cmap = self.segm.make_cmap()
         assert len(cmap.colors) == (self.segm.max_label + 1)
-        assert_allclose(cmap.colors[0], [0, 0, 0])
+        assert_allclose(cmap.colors[0], [0, 0, 0, 1])
 
-        assert_allclose(self.segm._cmap.colors,
-                        self.segm.make_cmap(background_color='#000000',
+        assert_allclose(self.segm.cmap.colors,
+                        self.segm.make_cmap(background_color='#000000ff',
                                             seed=0).colors)
 
+    @pytest.mark.skipif('not HAS_MATPLOTLIB')
+    @pytest.mark.parametrize('color, alpha', (('#00000000', 0.),
+                                              ('#00000040', 64 / 255),
+                                              ('#00000080', 128 / 255),
+                                              ('#000000C0', 192 / 255),
+                                              ('#000000FF', 1.)))
+    def test_make_cmap_alpha(self, color, alpha):
+        cmap = self.segm.make_cmap(background_color=color)
+        assert_allclose(cmap.colors[0], (0, 0, 0, alpha))
+
     def test_reassign_labels(self):
-        segm = SegmentationImage(self.data)
+        segm = SegmentationImage(self.data.copy())
         segm.reassign_labels(labels=[1, 7], new_label=2)
         ref_data = np.array([[2, 2, 0, 0, 4, 4],
                              [0, 0, 0, 0, 0, 4],
@@ -188,7 +213,7 @@ class TestSegmentationImage:
 
     @pytest.mark.parametrize('start_label', [1, 5])
     def test_relabel_consecutive(self, start_label):
-        segm = SegmentationImage(self.data)
+        segm = SegmentationImage(self.data.copy())
         ref_data = np.array([[1, 1, 0, 0, 3, 3],
                              [0, 0, 0, 0, 0, 3],
                              [0, 0, 2, 2, 0, 0],
@@ -207,7 +232,7 @@ class TestSegmentationImage:
     @pytest.mark.parametrize('start_label', [0, -1])
     def test_relabel_consecutive_start_invalid(self, start_label):
         with pytest.raises(ValueError):
-            segm = SegmentationImage(self.data)
+            segm = SegmentationImage(self.data.copy())
             segm.relabel_consecutive(start_label=start_label)
 
     def test_keep_labels(self):
@@ -217,7 +242,7 @@ class TestSegmentationImage:
                              [0, 0, 0, 0, 0, 5],
                              [0, 0, 0, 5, 5, 5],
                              [0, 0, 0, 0, 5, 5]])
-        segm = SegmentationImage(self.data)
+        segm = SegmentationImage(self.data.copy())
         segm.keep_labels([5, 3])
         assert_allclose(segm.data, ref_data)
 
@@ -228,7 +253,7 @@ class TestSegmentationImage:
                              [0, 0, 0, 0, 0, 2],
                              [0, 0, 0, 2, 2, 2],
                              [0, 0, 0, 0, 2, 2]])
-        segm = SegmentationImage(self.data)
+        segm = SegmentationImage(self.data.copy())
         segm.keep_labels([5, 3], relabel=True)
         assert_allclose(segm.data, ref_data)
 
@@ -239,7 +264,7 @@ class TestSegmentationImage:
                              [7, 0, 0, 0, 0, 0],
                              [7, 7, 0, 0, 0, 0],
                              [7, 7, 0, 0, 0, 0]])
-        segm = SegmentationImage(self.data)
+        segm = SegmentationImage(self.data.copy())
         segm.remove_labels(labels=[5, 3])
         assert_allclose(segm.data, ref_data)
 
@@ -250,7 +275,7 @@ class TestSegmentationImage:
                              [3, 0, 0, 0, 0, 0],
                              [3, 3, 0, 0, 0, 0],
                              [3, 3, 0, 0, 0, 0]])
-        segm = SegmentationImage(self.data)
+        segm = SegmentationImage(self.data.copy())
         segm.remove_labels(labels=[5, 3], relabel=True)
         assert_allclose(segm.data, ref_data)
 
@@ -261,17 +286,17 @@ class TestSegmentationImage:
                              [0, 0, 0, 0, 0, 0],
                              [0, 0, 0, 0, 0, 0],
                              [0, 0, 0, 0, 0, 0]])
-        segm = SegmentationImage(self.data)
+        segm = SegmentationImage(self.data.copy())
         segm.remove_border_labels(border_width=1)
         assert_allclose(segm.data, ref_data)
 
     def test_remove_border_labels_border_width(self):
         with pytest.raises(ValueError):
-            segm = SegmentationImage(self.data)
+            segm = SegmentationImage(self.data.copy())
             segm.remove_border_labels(border_width=3)
 
     def test_remove_border_labels_no_remaining_segments(self):
-        alt_data = np.copy(self.data)
+        alt_data = self.data.copy()
         alt_data[alt_data == 3] = 0
         segm = SegmentationImage(alt_data)
         segm.remove_border_labels(border_width=1, relabel=True)
@@ -284,7 +309,7 @@ class TestSegmentationImage:
                              [7, 0, 0, 0, 0, 5],
                              [7, 7, 0, 5, 5, 5],
                              [7, 7, 0, 0, 5, 5]])
-        segm = SegmentationImage(self.data)
+        segm = SegmentationImage(self.data.copy())
         mask = np.zeros(segm.data.shape, dtype=bool)
         mask[0, :] = True
         segm.remove_masked_labels(mask)
@@ -297,18 +322,36 @@ class TestSegmentationImage:
                              [7, 0, 0, 0, 0, 5],
                              [7, 7, 0, 5, 5, 5],
                              [7, 7, 0, 0, 5, 5]])
-        segm = SegmentationImage(self.data)
+        segm = SegmentationImage(self.data.copy())
         mask = np.zeros(segm.data.shape, dtype=bool)
         mask[0, :] = True
         segm.remove_masked_labels(mask, partial_overlap=False)
         assert_allclose(segm.data, ref_data)
 
     def test_remove_masked_segments_mask_shape(self):
-        segm = SegmentationImage(np.ones((5, 5)))
+        segm = SegmentationImage(np.ones((5, 5), dtype=int))
         mask = np.zeros((3, 3), dtype=bool)
         with pytest.raises(ValueError):
             segm.remove_masked_labels(mask)
 
+    def test_make_source_mask(self):
+        segm_array = np.zeros((7, 7)).astype(int)
+        segm_array[3, 3] = 1
+        segm = SegmentationImage(segm_array)
+        footprint = circular_footprint(radius=3)
+        mask = segm.make_source_mask(footprint=footprint)
+        expected = np.array([[0, 0, 0, 1, 0, 0, 0],
+                             [0, 1, 1, 1, 1, 1, 0],
+                             [0, 1, 1, 1, 1, 1, 0],
+                             [1, 1, 1, 1, 1, 1, 1],
+                             [0, 1, 1, 1, 1, 1, 0],
+                             [0, 1, 1, 1, 1, 1, 0],
+                             [0, 0, 0, 1, 0, 0, 0]])
+        assert_equal(mask.astype(int), expected)
+
+        mask = segm.make_source_mask(footprint=None)
+        assert_equal(mask, segm.data.astype(bool))
+
     def test_outline_segments(self):
         segm_array = np.zeros((5, 5)).astype(int)
         segm_array[1:4, 1:4] = 2
@@ -327,3 +370,39 @@ class TestSegmentationImage:
         assert isinstance(segm_outlines, np.ma.MaskedArray)
         assert np.ma.count(segm_outlines) == 8
         assert np.ma.count_masked(segm_outlines) == 17
+
+    @pytest.mark.skipif('not HAS_MATPLOTLIB')
+    def test_imshow(self):
+        axim = self.segm.imshow(figsize=(5, 5))
+        from matplotlib.image import AxesImage
+        assert isinstance(axim, AxesImage)
+
+
+class CustomSegm(SegmentationImage):
+    @lazyproperty
+    def value(self):
+        return np.median(self.data)
+
+
+@pytest.mark.skipif('not HAS_SCIPY')
+def test_subclass():
+    """
+    Test that cached properties are reset in SegmentationImage
+    subclasses.
+    """
+    data = np.array([[1, 1, 0, 0, 4, 4],
+                     [0, 0, 0, 0, 0, 4],
+                     [0, 0, 3, 3, 0, 0],
+                     [7, 0, 0, 0, 0, 5],
+                     [7, 7, 0, 5, 5, 5],
+                     [7, 7, 0, 0, 5, 5]])
+    segm = CustomSegm(data)
+    _ = segm.slices, segm.labels, segm.value, segm.areas
+
+    data2 = np.array([[10, 10, 0, 40],
+                      [0, 0, 0, 40],
+                      [70, 70, 0, 0],
+                      [70, 70, 0, 1]])
+    segm.data = data2
+    assert len(segm.__dict__) == 2
+    assert_equal(segm.areas, [1, 2, 2, 4])
