@@ -8,7 +8,7 @@ import importlib
 # Note that in some cases the package names are different from the
 # pip-install name (e.g.k scikit-image -> skimage).
 optional_deps = ['scipy', 'matplotlib', 'skimage', 'sklearn', 'gwcs',
-                 'bottleneck']
+                 'bottleneck', 'tqdm']
 deps = {key.upper(): key for key in optional_deps}
 __all__ = [f'HAS_{pkg}' for pkg in deps]
 
