@@ -149,10 +149,9 @@ def calc_total_error(data, bkg_error, effective_gain):
         count_units = [u.electron, u.photon]
         datagain_unit = data.unit * effective_gain.unit
         if datagain_unit not in count_units:
-            raise u.UnitsError('(data * effective_gain) has units of "{0}", '
-                               'but it must have count units (e.g., '
-                               'u.electron or u.photon).'
-                               .format(datagain_unit))
+            raise u.UnitsError('(data * effective_gain) has units of '
+                               f'{datagain_unit}, but it must have count '
+                               'units (e.g., u.electron or u.photon).')
 
     if not isiterable(effective_gain):
         effective_gain = np.zeros(data.shape) + effective_gain
@@ -170,7 +169,10 @@ def calc_total_error(data, bkg_error, effective_gain):
         effective_gain = effective_gain.value
 
     # do not include source variance where effective_gain = 0
-    source_variance = np.where(effective_gain != 0, data / effective_gain, 0)
+    source_variance = data.copy()
+    mask = effective_gain != 0
+    source_variance[mask] /= effective_gain[mask]
+    source_variance[~mask] = 0.0
 
     # do not include source variance where data is negative (note that
     # effective_gain cannot be negative)
